// EDD file for SCA06
// File name:	SCA06_Vars.inc
// Date:		17/2/2012
// Firmware Version:	1,20

VARIABLE g_wParNumber
{
	LABEL		"Parameter Number";
	CLASS		LOCAL;
	TYPE		UNSIGNED_INTEGER(2);
}

COMMAND WRITE_PAR_NUMBER
{
	SLOT 0;
	INDEX 48;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST { g_wParNumber }
		REPLY { }

	}
}

VARIABLE P0002
{
	LABEL "P0002 Motor Speed     |es|P0002 Velocidad Motor ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -9999;
		MAX_VALUE 9999;
	}
	CONSTANT_UNIT "rpm";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0002
	}
}

COMMAND READ_P0002
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0002 }
	}
}

METHOD SET_PAR_NUMBER_0002
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 2;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0003
{
	LABEL "P0003 Motor Current   |es|P0003 Corriente Motor ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE -999.9;
		MAX_VALUE 999.9;
	}
	CONSTANT_UNIT "A";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0003
	}
}

COMMAND READ_P0003
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0003 }
	}
}

METHOD SET_PAR_NUMBER_0003
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 3;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0004
{
	LABEL "P0004 DC Link Voltage (Ud)|es|P0004 Tensin Bus CC";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999;
	}
	CONSTANT_UNIT "V";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0004
	}
}

COMMAND READ_P0004
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0004 }
	}
}

METHOD SET_PAR_NUMBER_0004
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 4;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0006
{
	LABEL "P0006 Drive Status      |es|P0006 Estado Convertidor";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Ready|es|Ready (Pronto)" },
		{ 1, "Run  |es|Run(Ejecucin)" },
		{ 2, "Fault  |es|Subtensin" },
		{ 3, "Undervoltage|es|Falla" },
		{ 4, "Autotuning|es|Autoajuste" },
		{ 5, "STOP on|es|" },
		{ 6, "STO on|es|" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0006
	}
}

COMMAND READ_P0006
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0006 }
	}
}

METHOD SET_PAR_NUMBER_0006
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 6;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0008
{
	LABEL "P0008 DI3 to DI1 Status|es|P0008 Estado DI5...DI1";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0002, "DI1|es|DI1" },
		{ 0x0004, "DI2|es|DI2" },
		{ 0x0008, "DI3|es|DI3" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0008
	}
}

COMMAND READ_P0008
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0008 }
	}
}

METHOD SET_PAR_NUMBER_0008
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 8;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0009
{
	LABEL "P0009 DI101 to DI106 Status|es|P0009 Estado DI10...DI6";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0002, "DI101|es|DI6" },
		{ 0x0004, "DI102|es|DI7" },
		{ 0x0008, "DI103|es|DI8" },
		{ 0x0010, "DI104|es|DI9" },
		{ 0x0020, "DI105|es|DI10" },
		{ 0x0040, "DI106|es|DI10" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0009
	}
}

COMMAND READ_P0009
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0009 }
	}
}

METHOD SET_PAR_NUMBER_0009
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 9;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0010
{
	LABEL "P0010 DI107 to DI112 Status|es|P0010 Estado DI15...DI11";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0002, "DI107|es|DI11" },
		{ 0x0004, "DI108|es|DI12" },
		{ 0x0008, "DI109|es|DI13" },
		{ 0x0010, "DI110|es|DI14" },
		{ 0x0020, "DI111|es|DI15" },
		{ 0x0040, "DI112|es|DI15" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0010
	}
}

COMMAND READ_P0010
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0010 }
	}
}

METHOD SET_PAR_NUMBER_0010
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 10;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0011
{
	LABEL "P0011 DI201 to DI206 Status|es|P0011 Estado DI20...DI16";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0002, "DI201|es|DI16" },
		{ 0x0004, "DI202|es|DI17" },
		{ 0x0008, "DI203|es|DI18" },
		{ 0x0010, "DI204|es|DI19" },
		{ 0x0020, "DI205|es|DI20" },
		{ 0x0040, "DI206|es|DI20" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0011
	}
}

COMMAND READ_P0011
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0011 }
	}
}

METHOD SET_PAR_NUMBER_0011
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 11;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0012
{
	LABEL "P0012 DI207 to DI212 Status|es|P0012 Estado DI25...DI21";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0002, "DI207|es|DI21" },
		{ 0x0004, "DI208|es|DI22" },
		{ 0x0008, "DI209|es|DI23" },
		{ 0x0010, "DI210|es|DI24" },
		{ 0x0020, "DI211|es|DI25" },
		{ 0x0040, "DI212|es|DI25" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0012
	}
}

COMMAND READ_P0012
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0012 }
	}
}

METHOD SET_PAR_NUMBER_0012
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 12;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0013
{
	LABEL "P0013 DI301 to DI306 Status|es|P0013 Estado DI30...DI26";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0002, "DI301|es|DI26" },
		{ 0x0004, "DI302|es|DI27" },
		{ 0x0008, "DI303|es|DI28" },
		{ 0x0010, "DI304|es|DI29" },
		{ 0x0020, "DI305|es|DI30" },
		{ 0x0040, "DI306|es|DI30" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0013
	}
}

COMMAND READ_P0013
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0013 }
	}
}

METHOD SET_PAR_NUMBER_0013
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 13;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0014
{
	LABEL "P0014 DI307 to DI312 Status|es|P0014 Estado DI35...DI31";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0002, "DI307|es|DI31" },
		{ 0x0004, "DI308|es|DI32" },
		{ 0x0008, "DI309|es|DI33" },
		{ 0x0010, "DI310|es|DI34" },
		{ 0x0020, "DI311|es|DI35" },
		{ 0x0040, "DI312|es|DI35" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0014
	}
}

COMMAND READ_P0014
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0014 }
	}
}

METHOD SET_PAR_NUMBER_0014
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 14;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0015
{
	LABEL "P0015 DO1 Status|es|P0015 Estado DO6...DO1";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0002, "DO1|es|DO1" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0015
	}
}

COMMAND READ_P0015
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0015 }
	}
}

METHOD SET_PAR_NUMBER_0015
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 15;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0016
{
	LABEL "P0016 DO101 to DO106 Status|es|P0016 Estado DO9...DO6";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0002, "DO101|es|DO6" },
		{ 0x0004, "DO102|es|DO7" },
		{ 0x0008, "DO103|es|DO8" },
		{ 0x0010, "DO104|es|DO9" },
		{ 0x0020, "D0105|es|" },
		{ 0x0040, "D0106|es|" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0016
	}
}

COMMAND READ_P0016
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0016 }
	}
}

METHOD SET_PAR_NUMBER_0016
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 16;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0017
{
	LABEL "P0017 DO201 to DO206 Status|es|P0017 Estado DO9...DO6";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0002, "DO201|es|DO6" },
		{ 0x0004, "DO202|es|DO7" },
		{ 0x0008, "DO203|es|DO8" },
		{ 0x0010, "DO204|es|DO9" },
		{ 0x0020, "D0205|es|" },
		{ 0x0040, "D0206|es|" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0017
	}
}

COMMAND READ_P0017
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0017 }
	}
}

METHOD SET_PAR_NUMBER_0017
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 17;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0018
{
	LABEL "P0018 DO301 to DO306 Status|es|P0018 Estado DO9...DO6";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0002, "DO301|es|DO6" },
		{ 0x0004, "DO302|es|DO7" },
		{ 0x0008, "DO303|es|DO8" },
		{ 0x0010, "DO304|es|DO9" },
		{ 0x0020, "DO305|es|DO9" },
		{ 0x0040, "DO306|es|DO9" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0018
	}
}

COMMAND READ_P0018
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0018 }
	}
}

METHOD SET_PAR_NUMBER_0018
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 18;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0021
{
	LABEL "P0021 Internal Air Temperature|es|P0021 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1000;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0021
	}
}

COMMAND READ_P0021
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0021 }
	}
}

METHOD SET_PAR_NUMBER_0021
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 21;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0022
{
	LABEL "P0022 Dissipator Temperature|es|P0022 Temperatura Disipador";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1000;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0022
	}
}

COMMAND READ_P0022
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0022 }
	}
}

METHOD SET_PAR_NUMBER_0022
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 22;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0023
{
	LABEL "P0023 Software Version|es|P0023 Versin Software ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
		DEFAULT_VALUE 1.2;
		MIN_VALUE 0;
		MAX_VALUE 655.35;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0023
	}
}

COMMAND READ_P0023
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0023 }
	}
}

METHOD SET_PAR_NUMBER_0023
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 23;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0024
{
	LABEL "P0024 Bootloader Version|es|P0024 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 655.35;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0024
	}
}

COMMAND READ_P0024
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0024 }
	}
}

METHOD SET_PAR_NUMBER_0024
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 24;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0025
{
	LABEL "P0025 FPGA Project Version|es|P0025 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 655.35;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0025
	}
}

COMMAND READ_P0025
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0025 }
	}
}

METHOD SET_PAR_NUMBER_0025
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 25;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0030
{
	LABEL "P0030 Present Alarm|es|P0030 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 2000;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0030
	}
}

COMMAND READ_P0030
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0030 }
	}
}

METHOD SET_PAR_NUMBER_0030
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 30;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0031
{
	LABEL "P0031 Last Alarm|es|P0031 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 2000;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0031
	}
}

COMMAND READ_P0031
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0031 }
	}
}

METHOD SET_PAR_NUMBER_0031
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 31;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0032
{
	LABEL "P0032 Last alarm Day.Month|es|P0032 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 31.12;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0032
	}
}

COMMAND READ_P0032
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0032 }
	}
}

METHOD SET_PAR_NUMBER_0032
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 32;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0033
{
	LABEL "P0033 Last alarm year|es|P0033 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 4096;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0033
	}
}

COMMAND READ_P0033
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0033 }
	}
}

METHOD SET_PAR_NUMBER_0033
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 33;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0034
{
	LABEL "P0034 Last alarm Hour.Min|es|P0034 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 23.59;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0034
	}
}

COMMAND READ_P0034
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0034 }
	}
}

METHOD SET_PAR_NUMBER_0034
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 34;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0035
{
	LABEL "P0035 Present Fault|es|P0035 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 2000;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0035
	}
}

COMMAND READ_P0035
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0035 }
	}
}

METHOD SET_PAR_NUMBER_0035
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 35;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0036
{
	LABEL "P0036 Last Fault|es|P0036 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 2000;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0036
	}
}

COMMAND READ_P0036
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0036 }
	}
}

METHOD SET_PAR_NUMBER_0036
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 36;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0037
{
	LABEL "P0037 Last Fault Day.Month|es|P0037 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 12.99;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0037
	}
}

COMMAND READ_P0037
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0037 }
	}
}

METHOD SET_PAR_NUMBER_0037
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 37;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0038
{
	LABEL "P0038 Last fault year|es|P0038 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 3123;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0038
	}
}

COMMAND READ_P0038
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0038 }
	}
}

METHOD SET_PAR_NUMBER_0038
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 38;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0039
{
	LABEL "P0039 Last fault Hour.Min|es|P0039 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 59.59;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0039
	}
}

COMMAND READ_P0039
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0039 }
	}
}

METHOD SET_PAR_NUMBER_0039
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 39;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0040
{
	LABEL "P0040 Second fault|es|P0040 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 2000;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0040
	}
}

COMMAND READ_P0040
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0040 }
	}
}

METHOD SET_PAR_NUMBER_0040
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 40;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0041
{
	LABEL "P0041 Second fault Day.Month|es|P0041 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 12.99;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0041
	}
}

COMMAND READ_P0041
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0041 }
	}
}

METHOD SET_PAR_NUMBER_0041
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 41;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0042
{
	LABEL "P0042 Second fault year|es|P0042 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 3123;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0042
	}
}

COMMAND READ_P0042
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0042 }
	}
}

METHOD SET_PAR_NUMBER_0042
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 42;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0043
{
	LABEL "P0043 Second fault Hour.Min|es|P0043 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 59.59;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0043
	}
}

COMMAND READ_P0043
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0043 }
	}
}

METHOD SET_PAR_NUMBER_0043
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 43;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0044
{
	LABEL "P0044 Third fault|es|P0044 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 2000;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0044
	}
}

COMMAND READ_P0044
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0044 }
	}
}

METHOD SET_PAR_NUMBER_0044
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 44;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0045
{
	LABEL "P0045 Third fault Day.Month|es|P0045 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 12.99;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0045
	}
}

COMMAND READ_P0045
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0045 }
	}
}

METHOD SET_PAR_NUMBER_0045
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 45;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0046
{
	LABEL "P0046 Third fault year|es|P0046 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 3123;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0046
	}
}

COMMAND READ_P0046
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0046 }
	}
}

METHOD SET_PAR_NUMBER_0046
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 46;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0047
{
	LABEL "P0047 Third fault Hour.Min|es|P0047 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 59.59;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0047
	}
}

COMMAND READ_P0047
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0047 }
	}
}

METHOD SET_PAR_NUMBER_0047
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 47;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0048
{
	LABEL "P0048 Lag fault|es|P0048 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 16383;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0048
	}
}

COMMAND READ_P0048
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0048 }
	}
}

METHOD SET_PAR_NUMBER_0048
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 48;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0050
{
	LABEL "P0050 Real Axis: Actual Position|es|P0050 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 16383;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0050
	}
}

COMMAND READ_P0050
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0050 }
	}
}

METHOD SET_PAR_NUMBER_0050
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 50;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0052
{
	LABEL "P0052 fractions of revolution|es|P0052 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -16383;
		MAX_VALUE 16383;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0052
	}
}

COMMAND READ_P0052
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0052 }
	}
}

METHOD SET_PAR_NUMBER_0052
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 52;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0053
{
	LABEL "P0053 number of revolutions|es|P0053 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0053
	}
}

COMMAND READ_P0053
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0053 }
	}
}

METHOD SET_PAR_NUMBER_0053
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 53;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0056
{
	LABEL "P0056 Standart Counter - Low|es|P0056 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0056
	}
}

COMMAND READ_P0056
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0056 }
	}
}

METHOD SET_PAR_NUMBER_0056
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 56;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0057
{
	LABEL "P0057 Standart Counter - High|es|P0057 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0057
	}
}

COMMAND READ_P0057
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0057 }
	}
}

METHOD SET_PAR_NUMBER_0057
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 57;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0058
{
	LABEL "P0058 Counter 1 - Low|es|P0058 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0058
	}
}

COMMAND READ_P0058
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0058 }
	}
}

METHOD SET_PAR_NUMBER_0058
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 58;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0059
{
	LABEL "P0059 Counter 1 - High|es|P0059 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0059
	}
}

COMMAND READ_P0059
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0059 }
	}
}

METHOD SET_PAR_NUMBER_0059
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 59;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0060
{
	LABEL "P0060 Counter 2 - Low|es|P0060 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0060
	}
}

COMMAND READ_P0060
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0060 }
	}
}

METHOD SET_PAR_NUMBER_0060
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 60;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0061
{
	LABEL "P0061 Counter 2 - High|es|P0061 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0061
	}
}

COMMAND READ_P0061
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0061 }
	}
}

METHOD SET_PAR_NUMBER_0061
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 61;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0066
{
	LABEL "P0066 AI1 Value       |es|P0066 Valor de AI1    ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -8192;
		MAX_VALUE 8191;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0066
	}
}

COMMAND READ_P0066
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0066 }
	}
}

METHOD SET_PAR_NUMBER_0066
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 66;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0067
{
	LABEL "P0067 AI2 Value       |es|P0067 Valor de AI2    ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -8192;
		MAX_VALUE 8191;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0067
	}
}

COMMAND READ_P0067
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0067 }
	}
}

METHOD SET_PAR_NUMBER_0067
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 67;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0070
{
	LABEL "P0070 CAN controller Status|es|P0070 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|es|" },
		{ 1, "Reserved|es|" },
		{ 2, "CAN Enabled|es|" },
		{ 3, "Warning|es|" },
		{ 4, "Error Passive|es|" },
		{ 5, "Bus Off|es|" },
		{ 6, "No Bus Power|es|" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0070
	}
}

COMMAND READ_P0070
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0070 }
	}
}

METHOD SET_PAR_NUMBER_0070
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 70;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0071
{
	LABEL "P0071 Received CAN Telegrams|es|P0071 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0071
	}
}

COMMAND READ_P0071
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0071 }
	}
}

METHOD SET_PAR_NUMBER_0071
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 71;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0072
{
	LABEL "P0072 Transmitted CAN Telegrams|es|P0072 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0072
	}
}

COMMAND READ_P0072
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0072 }
	}
}

METHOD SET_PAR_NUMBER_0072
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 72;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0073
{
	LABEL "P0073 Bus Off Counter|es|P0073 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0073
	}
}

COMMAND READ_P0073
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0073 }
	}
}

METHOD SET_PAR_NUMBER_0073
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 73;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0074
{
	LABEL "P0074 CAN Lost Messages|es|P0074 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0074
	}
}

COMMAND READ_P0074
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0074 }
	}
}

METHOD SET_PAR_NUMBER_0074
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 74;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0075
{
	LABEL "P0075 CANopen Communication Status|es|P0075 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|es|" },
		{ 1, "Reserved|es|" },
		{ 2, "Commumication Enabled|es|" },
		{ 3, "Error Control Enabled|es|" },
		{ 4, "Node Guarding Error|es|" },
		{ 5, "Heartbeat Error|es|" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0075
	}
}

COMMAND READ_P0075
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0075 }
	}
}

METHOD SET_PAR_NUMBER_0075
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 75;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0076
{
	LABEL "P0076 CANopen Node State|es|P0076 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|es|" },
		{ 1, "Initialization|es|" },
		{ 2, "Stopped|es|" },
		{ 3, "Operational|es|" },
		{ 4, "PreOperational|es|" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0076
	}
}

COMMAND READ_P0076
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0076 }
	}
}

METHOD SET_PAR_NUMBER_0076
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 76;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0080
{
	LABEL "P0080 Virtual Axis Speed|es|P0080 Velocidad Motor ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -9999;
		MAX_VALUE 9999;
	}
	CONSTANT_UNIT "rpm";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0080
	}
}

COMMAND READ_P0080
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0080 }
	}
}

METHOD SET_PAR_NUMBER_0080
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 80;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0082
{
	LABEL "P0082 Virtual Axis - fractions of revolution|es|P0082 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -16383;
		MAX_VALUE 16383;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0082
	}
}

COMMAND READ_P0082
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0082 }
	}
}

METHOD SET_PAR_NUMBER_0082
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 82;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0083
{
	LABEL "P0083 Virtual Axis - numbers of revolutions |es|P0083 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0083
	}
}

COMMAND READ_P0083
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0083 }
	}
}

METHOD SET_PAR_NUMBER_0083
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 83;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0084
{
	LABEL "P0084 Day of week|es|P0084 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 6;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0084
	}
}

COMMAND READ_P0084
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0084 }
	}
}

METHOD SET_PAR_NUMBER_0084
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 84;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0085
{
	LABEL "P0085 Day  |es|P0085 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1;
		MIN_VALUE 1;
		MAX_VALUE 31;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0085
	}
}

COMMAND READ_P0085
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0085 }
	}
}

METHOD SET_PAR_NUMBER_0085
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 85;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0086
{
	LABEL "P0086 Month|es|P0086 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1;
		MIN_VALUE 1;
		MAX_VALUE 12;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0086
	}
}

COMMAND READ_P0086
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0086 }
	}
}

METHOD SET_PAR_NUMBER_0086
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 86;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0087
{
	LABEL "P0087 Year|es|P0087 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 2009;
		MIN_VALUE 0;
		MAX_VALUE 4095;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0087
	}
}

COMMAND READ_P0087
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0087 }
	}
}

METHOD SET_PAR_NUMBER_0087
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 87;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0088
{
	LABEL "P0088 Hous|es|P0088 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 23;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0088
	}
}

COMMAND READ_P0088
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0088 }
	}
}

METHOD SET_PAR_NUMBER_0088
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 88;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0089
{
	LABEL "P0089 Minutes|es|P0089 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 59;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0089
	}
}

COMMAND READ_P0089
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0089 }
	}
}

METHOD SET_PAR_NUMBER_0089
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 89;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0090
{
	LABEL "P0090 Seconds|es|P0090 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 59;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0090
	}
}

COMMAND READ_P0090
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0090 }
	}
}

METHOD SET_PAR_NUMBER_0090
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 90;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0091
{
	LABEL "P0091 Slot 1 ID|es|P0091 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0091
	}
}

COMMAND READ_P0091
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0091 }
	}
}

METHOD SET_PAR_NUMBER_0091
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 91;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0092
{
	LABEL "P0092 Slot 2 ID|es|P0092 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0092
	}
}

COMMAND READ_P0092
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0092 }
	}
}

METHOD SET_PAR_NUMBER_0092
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 92;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0093
{
	LABEL "P0093 Slot 3 ID|es|P0093 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0093
	}
}

COMMAND READ_P0093
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0093 }
	}
}

METHOD SET_PAR_NUMBER_0093
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 93;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0095
{
	LABEL "P0095 Opcional Card |es|P0095 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1000;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0095
	}
}

COMMAND READ_P0095
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0095 }
	}
}

METHOD SET_PAR_NUMBER_0095
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 95;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0097
{
	LABEL "P0097 Nominal Current|es|P0097 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999.9;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0097
	}
}

COMMAND READ_P0097
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0097 }
	}
}

METHOD SET_PAR_NUMBER_0097
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 97;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0098
{
	LABEL "P0098 Line Rated Voltage |es|P0098 Tensin Nominal Red";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 2, "220 V|es|220 V" },
		{ 3, "380 V|es|380 V" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0098
	}
}

COMMAND READ_P0098
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0098 }
	}
}

METHOD SET_PAR_NUMBER_0098
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 98;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0099
{
	LABEL "P0099 Enable|es|P0099 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disable|es|" },
		{ 1, "Enable|es|" },
		{ 2, "Enable without save the parameter|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0099
	}
}

COMMAND READ_P0099
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0099 }
	}
}

METHOD SET_PAR_NUMBER_0099
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 99;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0099 LIKE READ_P0099
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 99, P0099 }
		REPLY { }
	}
}

VARIABLE P0105
{
	LABEL "P0105 STOP Function Ramp |es|P0105 Tiempo Aceleracin  ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 200;
		MIN_VALUE 0;
		MAX_VALUE 32767;
	}
	CONSTANT_UNIT "ms/krpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0105
	}
}

COMMAND READ_P0105
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0105 }
	}
}

METHOD SET_PAR_NUMBER_0105
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 105;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0105 LIKE READ_P0105
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 105, P0105 }
		REPLY { }
	}
}

VARIABLE P0111
{
	LABEL "P0111 Rotation Direction|es|P0111 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "standart|es|" },
		{ 1, "inverted|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0111
	}
}

COMMAND READ_P0111
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0111 }
	}
}

METHOD SET_PAR_NUMBER_0111
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 111;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0111 LIKE READ_P0111
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 111, P0111 }
		REPLY { }
	}
}

VARIABLE P0119
{
	LABEL "P0119 Current Reference|es|P0119 Referencia Corriente";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE -3276.7;
		MAX_VALUE 3276.7;
	}
	CONSTANT_UNIT "A";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0119
	}
}

COMMAND READ_P0119
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0119 }
	}
}

METHOD SET_PAR_NUMBER_0119
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 119;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0119 LIKE READ_P0119
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 119, P0119 }
		REPLY { }
	}
}

VARIABLE P0121
{
	LABEL "P0121 Speed Reference|es|P0121 Referencia Velocidad";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -9999;
		MAX_VALUE 9999;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0121
	}
}

COMMAND READ_P0121
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0121 }
	}
}

METHOD SET_PAR_NUMBER_0121
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 121;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0121 LIKE READ_P0121
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 121, P0121 }
		REPLY { }
	}
}

VARIABLE P0126
{
	LABEL "P0126 Limit position Enable|es|P0126 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|es|" },
		{ 1, "Enabled|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0126
	}
}

COMMAND READ_P0126
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0126 }
	}
}

METHOD SET_PAR_NUMBER_0126
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 126;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0126 LIKE READ_P0126
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 126, P0126 }
		REPLY { }
	}
}

VARIABLE P0127
{
	LABEL "P0127 Position lower limit - fractions of revolution|es|P0127 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE -16383;
		MIN_VALUE -16383;
		MAX_VALUE 16383;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0127
	}
}

COMMAND READ_P0127
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0127 }
	}
}

METHOD SET_PAR_NUMBER_0127
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 127;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0127 LIKE READ_P0127
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 127, P0127 }
		REPLY { }
	}
}

VARIABLE P0128
{
	LABEL "P0128 Position lower limit - number of revolutions|es|P0128 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE -32768;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0128
	}
}

COMMAND READ_P0128
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0128 }
	}
}

METHOD SET_PAR_NUMBER_0128
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 128;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0128 LIKE READ_P0128
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 128, P0128 }
		REPLY { }
	}
}

VARIABLE P0129
{
	LABEL "P0129 Position higher limit - fractions of revolution|es|P0129 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 16383;
		MIN_VALUE -16383;
		MAX_VALUE 16383;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0129
	}
}

COMMAND READ_P0129
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0129 }
	}
}

METHOD SET_PAR_NUMBER_0129
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 129;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0129 LIKE READ_P0129
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 129, P0129 }
		REPLY { }
	}
}

VARIABLE P0130
{
	LABEL "P0130 Position higher limit - number of revolutions|es|P0130 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 32767;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0130
	}
}

COMMAND READ_P0130
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0130 }
	}
}

METHOD SET_PAR_NUMBER_0130
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 130;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0130 LIKE READ_P0130
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 130, P0130 }
		REPLY { }
	}
}

VARIABLE P0131
{
	LABEL "P0131 Current lower limit|es|P0131 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE -100;
		MIN_VALUE -100;
		MAX_VALUE 0;
	}
	CONSTANT_UNIT "A";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0131
	}
}

COMMAND READ_P0131
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0131 }
	}
}

METHOD SET_PAR_NUMBER_0131
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 131;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0131 LIKE READ_P0131
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 131, P0131 }
		REPLY { }
	}
}

VARIABLE P0132
{
	LABEL "P0132 Current higher limit|es|P0132 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 100;
		MIN_VALUE 0;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "A";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0132
	}
}

COMMAND READ_P0132
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0132 }
	}
}

METHOD SET_PAR_NUMBER_0132
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 132;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0132 LIKE READ_P0132
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 132, P0132 }
		REPLY { }
	}
}

VARIABLE P0133
{
	LABEL "P0133 Speed lower limit|es|P0133 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE -9999;
		MIN_VALUE -9999;
		MAX_VALUE 0;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0133
	}
}

COMMAND READ_P0133
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0133 }
	}
}

METHOD SET_PAR_NUMBER_0133
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 133;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0133 LIKE READ_P0133
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 133, P0133 }
		REPLY { }
	}
}

VARIABLE P0134
{
	LABEL "P0134 Speed higher limit|es|P0134 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 9999;
		MIN_VALUE 0;
		MAX_VALUE 9999;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0134
	}
}

COMMAND READ_P0134
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0134 }
	}
}

METHOD SET_PAR_NUMBER_0134
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 134;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0134 LIKE READ_P0134
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 134, P0134 }
		REPLY { }
	}
}

VARIABLE P0136
{
	LABEL "P0136 Idynamic/Inominal|es|P0136 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 300;
		MIN_VALUE 0;
		MAX_VALUE 400;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0136
	}
}

COMMAND READ_P0136
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0136 }
	}
}

METHOD SET_PAR_NUMBER_0136
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 136;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0136 LIKE READ_P0136
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 136, P0136 }
		REPLY { }
	}
}

VARIABLE P0154
{
	LABEL "P0154 Breaking Resistor|es|P0154 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 30;
		MIN_VALUE 0;
		MAX_VALUE 1000;
	}
	CONSTANT_UNIT "ohm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0154
	}
}

COMMAND READ_P0154
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0154 }
	}
}

METHOD SET_PAR_NUMBER_0154
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 154;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0154 LIKE READ_P0154
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 154, P0154 }
		REPLY { }
	}
}

VARIABLE P0155
{
	LABEL "P0155 Breaking Resistor Average Power|es|P0155 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 200;
		MIN_VALUE 0;
		MAX_VALUE 10000;
	}
	CONSTANT_UNIT "W";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0155
	}
}

COMMAND READ_P0155
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0155 }
	}
}

METHOD SET_PAR_NUMBER_0155
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 155;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0155 LIKE READ_P0155
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 155, P0155 }
		REPLY { }
	}
}

VARIABLE P0156
{
	LABEL "P0156 Breaking Resistor Maximum Energy|es|P0156 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 2200;
		MIN_VALUE 0;
		MAX_VALUE 10000;
	}
	CONSTANT_UNIT "J";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0156
	}
}

COMMAND READ_P0156
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0156 }
	}
}

METHOD SET_PAR_NUMBER_0156
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 156;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0156 LIKE READ_P0156
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 156, P0156 }
		REPLY { }
	}
}

VARIABLE P0159
{
	LABEL "P0159 Kp Position Regulator|es|P0159 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 50;
		MIN_VALUE 0;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0159
	}
}

COMMAND READ_P0159
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0159 }
	}
}

METHOD SET_PAR_NUMBER_0159
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 159;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0159 LIKE READ_P0159
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 159, P0159 }
		REPLY { }
	}
}

VARIABLE P0161
{
	LABEL "P0161 Kp PID Speed|es|P0161 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 4000;
		MIN_VALUE 0;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0161
	}
}

COMMAND READ_P0161
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0161 }
	}
}

METHOD SET_PAR_NUMBER_0161
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 161;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0161 LIKE READ_P0161
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 161, P0161 }
		REPLY { }
	}
}

VARIABLE P0162
{
	LABEL "P0162 Ki PID Speed|es|P0162 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 50;
		MIN_VALUE 0;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0162
	}
}

COMMAND READ_P0162
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0162 }
	}
}

METHOD SET_PAR_NUMBER_0162
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 162;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0162 LIKE READ_P0162
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 162, P0162 }
		REPLY { }
	}
}

VARIABLE P0163
{
	LABEL "P0163 Kd PID Speed|es|P0163 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0163
	}
}

COMMAND READ_P0163
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0163 }
	}
}

METHOD SET_PAR_NUMBER_0163
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 163;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0163 LIKE READ_P0163
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 163, P0163 }
		REPLY { }
	}
}

VARIABLE P0192
{
	LABEL "P0192 RTC Update|es|P0192 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0192
	}
}

COMMAND READ_P0192
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0192 }
	}
}

METHOD SET_PAR_NUMBER_0192
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 192;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0192 LIKE READ_P0192
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 192, P0192 }
		REPLY { }
	}
}

VARIABLE P0193
{
	LABEL "P0193 Day of week|es|P0193 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 6;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0193
	}
}

COMMAND READ_P0193
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0193 }
	}
}

METHOD SET_PAR_NUMBER_0193
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 193;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0193 LIKE READ_P0193
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 193, P0193 }
		REPLY { }
	}
}

VARIABLE P0194
{
	LABEL "P0194 Day  |es|P0194 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1;
		MIN_VALUE 1;
		MAX_VALUE 31;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0194
	}
}

COMMAND READ_P0194
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0194 }
	}
}

METHOD SET_PAR_NUMBER_0194
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 194;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0194 LIKE READ_P0194
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 194, P0194 }
		REPLY { }
	}
}

VARIABLE P0195
{
	LABEL "P0195 Month|es|P0195 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1;
		MIN_VALUE 1;
		MAX_VALUE 12;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0195
	}
}

COMMAND READ_P0195
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0195 }
	}
}

METHOD SET_PAR_NUMBER_0195
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 195;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0195 LIKE READ_P0195
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 195, P0195 }
		REPLY { }
	}
}

VARIABLE P0196
{
	LABEL "P0196 Year|es|P0196 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 2011;
		MIN_VALUE 0;
		MAX_VALUE 4095;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0196
	}
}

COMMAND READ_P0196
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0196 }
	}
}

METHOD SET_PAR_NUMBER_0196
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 196;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0196 LIKE READ_P0196
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 196, P0196 }
		REPLY { }
	}
}

VARIABLE P0197
{
	LABEL "P0197 Hous|es|P0197 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 23;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0197
	}
}

COMMAND READ_P0197
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0197 }
	}
}

METHOD SET_PAR_NUMBER_0197
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 197;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0197 LIKE READ_P0197
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 197, P0197 }
		REPLY { }
	}
}

VARIABLE P0198
{
	LABEL "P0198 Minutes|es|P0198 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 59;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0198
	}
}

COMMAND READ_P0198
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0198 }
	}
}

METHOD SET_PAR_NUMBER_0198
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 198;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0198 LIKE READ_P0198
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 198, P0198 }
		REPLY { }
	}
}

VARIABLE P0199
{
	LABEL "P0199 Seconds|es|P0199 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 59;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0199
	}
}

COMMAND READ_P0199
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0199 }
	}
}

METHOD SET_PAR_NUMBER_0199
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 199;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0199 LIKE READ_P0199
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 199, P0199 }
		REPLY { }
	}
}

VARIABLE P0200
{
	LABEL "P0200 Password|es|P0200 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Inactive|es|" },
		{ 1, "Active|es|" },
		{ 2, "User password change|es|" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0200
	}
}

COMMAND READ_P0200
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0200 }
	}
}

METHOD SET_PAR_NUMBER_0200
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 200;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0200 LIKE READ_P0200
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 200, P0200 }
		REPLY { }
	}
}

VARIABLE P0202
{
	LABEL "P0202 Operation Mode|es|P0202 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 1, "Torque Mode|es|" },
		{ 2, "Speed Mode|es|" },
		{ 3, "No function|es|" },
		{ 4, "Ladder Mode|es|" },
		{ 5, "CANopen|es|" },
		{ 6, "Profibus DP|es|" }
		DEFAULT_VALUE 2;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0202
	}
}

COMMAND READ_P0202
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0202 }
	}
}

METHOD SET_PAR_NUMBER_0202
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 202;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0202 LIKE READ_P0202
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 202, P0202 }
		REPLY { }
	}
}

VARIABLE P0209
{
	LABEL "P0209 Position/speed feedback source|es|P0209 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "internal motor sensor|es|" },
		{ 1, "fast inputs counter|es|" },
		{ 2, "encoder 1 input counter|es|" },
		{ 3, "encoder 2 input counter|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0209
	}
}

COMMAND READ_P0209
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0209 }
	}
}

METHOD SET_PAR_NUMBER_0209
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 209;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0209 LIKE READ_P0209
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 209, P0209 }
		REPLY { }
	}
}

VARIABLE P0210
{
	LABEL "P0210 External feedback gear ratio:Numerator|es|P0210 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1;
		MIN_VALUE 1;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0210
	}
}

COMMAND READ_P0210
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0210 }
	}
}

METHOD SET_PAR_NUMBER_0210
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 210;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0210 LIKE READ_P0210
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 210, P0210 }
		REPLY { }
	}
}

VARIABLE P0211
{
	LABEL "P0211 External feedback gear ratio:Denominator|es|P0211 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1;
		MIN_VALUE 1;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0211
	}
}

COMMAND READ_P0211
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0211 }
	}
}

METHOD SET_PAR_NUMBER_0211
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 211;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0211 LIKE READ_P0211
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 211, P0211 }
		REPLY { }
	}
}

VARIABLE P0213
{
	LABEL "P0213 External feedback Rotation Direction|es|P0213 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "direct|es|" },
		{ 1, "inverted|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0213
	}
}

COMMAND READ_P0213
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0213 }
	}
}

METHOD SET_PAR_NUMBER_0213
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 213;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0213 LIKE READ_P0213
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 213, P0213 }
		REPLY { }
	}
}

VARIABLE P0214
{
	LABEL "P0214 External feedback loss protection|es|P0214 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1000;
		MIN_VALUE 0;
		MAX_VALUE 9999;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0214
	}
}

COMMAND READ_P0214
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0214 }
	}
}

METHOD SET_PAR_NUMBER_0214
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 214;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0214 LIKE READ_P0214
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 214, P0214 }
		REPLY { }
	}
}

VARIABLE P0217
{
	LABEL "P0217 Single/Three phase Supply|es|P0217 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1;
		MIN_VALUE 0;
		MAX_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0217
	}
}

COMMAND READ_P0217
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0217 }
	}
}

METHOD SET_PAR_NUMBER_0217
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 217;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0217 LIKE READ_P0217
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 217, P0217 }
		REPLY { }
	}
}

VARIABLE P0219
{
	LABEL "P0219 Fault Reset|es|P0219 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|es|" },
		{ 1, "Reset|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0219
	}
}

COMMAND READ_P0219
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0219 }
	}
}

METHOD SET_PAR_NUMBER_0219
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 219;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0219 LIKE READ_P0219
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 219, P0219 }
		REPLY { }
	}
}

VARIABLE P0221
{
	LABEL "P0221 Battery Alarm|es|P0221 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0221
	}
}

COMMAND READ_P0221
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0221 }
	}
}

METHOD SET_PAR_NUMBER_0221
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 221;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0221 LIKE READ_P0221
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 221, P0221 }
		REPLY { }
	}
}

VARIABLE P0230
{
	LABEL "P0230 Option Ixt|es|P0230 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Generates F00005|es|" },
		{ 1, "Limits Is rms = Inom|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0230
	}
}

COMMAND READ_P0230
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0230 }
	}
}

METHOD SET_PAR_NUMBER_0230
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 230;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0230 LIKE READ_P0230
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 230, P0230 }
		REPLY { }
	}
}

VARIABLE P0232
{
	LABEL "P0232 AI1 Function|es|P0232 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|es|" },
		{ 1, "Current Reference|es|" },
		{ 2, "Speed Reference|es|" },
		{ 3, "No function|es|" },
		{ 4, "Enabled|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0232
	}
}

COMMAND READ_P0232
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0232 }
	}
}

METHOD SET_PAR_NUMBER_0232
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 232;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0232 LIKE READ_P0232
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 232, P0232 }
		REPLY { }
	}
}

VARIABLE P0233
{
	LABEL "P0233 AI1 Gain|es|P0233 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.001;
		DEFAULT_VALUE 1;
		MIN_VALUE -32.768;
		MAX_VALUE 32.767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0233
	}
}

COMMAND READ_P0233
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0233 }
	}
}

METHOD SET_PAR_NUMBER_0233
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 233;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0233 LIKE READ_P0233
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 233, P0233 }
		REPLY { }
	}
}

VARIABLE P0235
{
	LABEL "P0235 AI1 Offset|es|P0235 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0235
	}
}

COMMAND READ_P0235
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0235 }
	}
}

METHOD SET_PAR_NUMBER_0235
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 235;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0235 LIKE READ_P0235
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 235, P0235 }
		REPLY { }
	}
}

VARIABLE P0236
{
	LABEL "P0236 AI1 Filter|es|P0236 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 150;
		MIN_VALUE 0;
		MAX_VALUE 4000;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0236
	}
}

COMMAND READ_P0236
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0236 }
	}
}

METHOD SET_PAR_NUMBER_0236
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 236;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0236 LIKE READ_P0236
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 236, P0236 }
		REPLY { }
	}
}

VARIABLE P0237
{
	LABEL "P0237 AI2 Function|es|P0237 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|es|" },
		{ 1, "Current Reference|es|" },
		{ 2, "Speed Reference|es|" },
		{ 3, "No function|es|" },
		{ 4, "Enabled|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0237
	}
}

COMMAND READ_P0237
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0237 }
	}
}

METHOD SET_PAR_NUMBER_0237
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 237;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0237 LIKE READ_P0237
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 237, P0237 }
		REPLY { }
	}
}

VARIABLE P0238
{
	LABEL "P0238 AI2 Gain|es|P0238 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.001;
		DEFAULT_VALUE 1;
		MIN_VALUE -32.768;
		MAX_VALUE 32.767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0238
	}
}

COMMAND READ_P0238
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0238 }
	}
}

METHOD SET_PAR_NUMBER_0238
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 238;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0238 LIKE READ_P0238
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 238, P0238 }
		REPLY { }
	}
}

VARIABLE P0239
{
	LABEL "P0239 AI2 Signal|es|P0239 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "(-10 a +10)V/(0 a 20)mA|es|" },
		{ 1, "(4 a 20)mA|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0239
	}
}

COMMAND READ_P0239
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0239 }
	}
}

METHOD SET_PAR_NUMBER_0239
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 239;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0239 LIKE READ_P0239
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 239, P0239 }
		REPLY { }
	}
}

VARIABLE P0240
{
	LABEL "P0240 AI2 Offset|es|P0240 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0240
	}
}

COMMAND READ_P0240
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0240 }
	}
}

METHOD SET_PAR_NUMBER_0240
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 240;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0240 LIKE READ_P0240
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 240, P0240 }
		REPLY { }
	}
}

VARIABLE P0241
{
	LABEL "P0241 AI2 Filter|es|P0241 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 150;
		MIN_VALUE 0;
		MAX_VALUE 4000;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0241
	}
}

COMMAND READ_P0241
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0241 }
	}
}

METHOD SET_PAR_NUMBER_0241
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 241;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0241 LIKE READ_P0241
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 241, P0241 }
		REPLY { }
	}
}

VARIABLE P0261
{
	LABEL "P0261 EANx Function - AD1|es|P0261 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 48;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0261
	}
}

COMMAND READ_P0261
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0261 }
	}
}

METHOD SET_PAR_NUMBER_0261
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 261;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0261 LIKE READ_P0261
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 5, P0261 }
		REPLY { }
	}
}

VARIABLE P0262
{
	LABEL "P0262 EANx Gain - AD1|es|P0262 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.001;
		DEFAULT_VALUE 1;
		MIN_VALUE -32.768;
		MAX_VALUE 32.767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0262
	}
}

COMMAND READ_P0262
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0262 }
	}
}

METHOD SET_PAR_NUMBER_0262
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 262;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0262 LIKE READ_P0262
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 6, P0262 }
		REPLY { }
	}
}

VARIABLE P0263
{
	LABEL "P0263 EANx Offset - AD1|es|P0263 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.001;
		DEFAULT_VALUE 0;
		MIN_VALUE -9.999;
		MAX_VALUE 9.999;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0263
	}
}

COMMAND READ_P0263
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0263 }
	}
}

METHOD SET_PAR_NUMBER_0263
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 263;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0263 LIKE READ_P0263
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 7, P0263 }
		REPLY { }
	}
}

VARIABLE P0265
{
	LABEL "P0265 EANx Function - AD2|es|P0265 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 48;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0265
	}
}

COMMAND READ_P0265
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0265 }
	}
}

METHOD SET_PAR_NUMBER_0265
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 265;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0265 LIKE READ_P0265
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 9, P0265 }
		REPLY { }
	}
}

VARIABLE P0266
{
	LABEL "P0266 EANx Gain - AD2|es|P0266 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.001;
		DEFAULT_VALUE 1;
		MIN_VALUE -32.768;
		MAX_VALUE 32.767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0266
	}
}

COMMAND READ_P0266
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0266 }
	}
}

METHOD SET_PAR_NUMBER_0266
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 266;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0266 LIKE READ_P0266
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 10, P0266 }
		REPLY { }
	}
}

VARIABLE P0267
{
	LABEL "P0267 EANx Offset - AD2|es|P0267 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.001;
		DEFAULT_VALUE 0;
		MIN_VALUE -9.999;
		MAX_VALUE 9.999;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0267
	}
}

COMMAND READ_P0267
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0267 }
	}
}

METHOD SET_PAR_NUMBER_0267
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 267;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0267 LIKE READ_P0267
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 11, P0267 }
		REPLY { }
	}
}

VARIABLE P0271
{
	LABEL "P0271 EANx Function - AD3|es|P0271 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 48;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0271
	}
}

COMMAND READ_P0271
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0271 }
	}
}

METHOD SET_PAR_NUMBER_0271
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 271;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0271 LIKE READ_P0271
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 15, P0271 }
		REPLY { }
	}
}

VARIABLE P0272
{
	LABEL "P0272 EANx Gain - AD3|es|P0272 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.001;
		DEFAULT_VALUE 1;
		MIN_VALUE -32.768;
		MAX_VALUE 32.767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0272
	}
}

COMMAND READ_P0272
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0272 }
	}
}

METHOD SET_PAR_NUMBER_0272
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 272;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0272 LIKE READ_P0272
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 16, P0272 }
		REPLY { }
	}
}

VARIABLE P0273
{
	LABEL "P0273 EANx Offset - AD3|es|P0273 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.001;
		DEFAULT_VALUE 0;
		MIN_VALUE -9.999;
		MAX_VALUE 9.999;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0273
	}
}

COMMAND READ_P0273
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0273 }
	}
}

METHOD SET_PAR_NUMBER_0273
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 273;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0273 LIKE READ_P0273
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 17, P0273 }
		REPLY { }
	}
}

VARIABLE P0275
{
	LABEL "P0275 EANx Function - AD4|es|P0275 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 48;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0275
	}
}

COMMAND READ_P0275
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0275 }
	}
}

METHOD SET_PAR_NUMBER_0275
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 275;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0275 LIKE READ_P0275
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 19, P0275 }
		REPLY { }
	}
}

VARIABLE P0276
{
	LABEL "P0276 EANx Gain - AD4|es|P0276 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.001;
		DEFAULT_VALUE 1;
		MIN_VALUE -32.768;
		MAX_VALUE 32.767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0276
	}
}

COMMAND READ_P0276
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0276 }
	}
}

METHOD SET_PAR_NUMBER_0276
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 276;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0276 LIKE READ_P0276
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 20, P0276 }
		REPLY { }
	}
}

VARIABLE P0277
{
	LABEL "P0277 EANx Offset - AD4|es|P0277 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.001;
		DEFAULT_VALUE 0;
		MIN_VALUE -9.999;
		MAX_VALUE 9.999;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0277
	}
}

COMMAND READ_P0277
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0277 }
	}
}

METHOD SET_PAR_NUMBER_0277
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 277;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0277 LIKE READ_P0277
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 21, P0277 }
		REPLY { }
	}
}

VARIABLE P0280
{
	LABEL "P0280 DO1 Function|es|P0280 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Stop Function|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "Servo Ready|es|" },
		{ 6, "No Fault|es|" },
		{ 7, "No function|es|" },
		{ 8, "Written by Ladder|es|" },
		{ 9, "Written by CAN|es|" },
		{ 10, "No function|es|" },
		{ 11, "Output activated|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0280
	}
}

COMMAND READ_P0280
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0280 }
	}
}

METHOD SET_PAR_NUMBER_0280
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 280;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0280 LIKE READ_P0280
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 24, P0280 }
		REPLY { }
	}
}

VARIABLE P0281
{
	LABEL "P0281 DO101 Function|es|P0281 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Stop Function|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "Servo Ready|es|" },
		{ 6, "No Fault|es|" },
		{ 7, "No function|es|" },
		{ 8, "Written by Ladder|es|" },
		{ 9, "Written by CAN|es|" },
		{ 10, "No function|es|" },
		{ 11, "Output activated|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0281
	}
}

COMMAND READ_P0281
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0281 }
	}
}

METHOD SET_PAR_NUMBER_0281
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 281;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0281 LIKE READ_P0281
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 25, P0281 }
		REPLY { }
	}
}

VARIABLE P0282
{
	LABEL "P0282 DO102 Function|es|P0282 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Stop Function|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "Servo Ready|es|" },
		{ 6, "No Fault|es|" },
		{ 7, "No function|es|" },
		{ 8, "Written by Ladder|es|" },
		{ 9, "Written by CAN|es|" },
		{ 10, "No function|es|" },
		{ 11, "Output activated|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0282
	}
}

COMMAND READ_P0282
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0282 }
	}
}

METHOD SET_PAR_NUMBER_0282
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 282;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0282 LIKE READ_P0282
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 26, P0282 }
		REPLY { }
	}
}

VARIABLE P0283
{
	LABEL "P0283 DO103 Function|es|P0283 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Stop Function|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "Servo Ready|es|" },
		{ 6, "No Fault|es|" },
		{ 7, "No function|es|" },
		{ 8, "Written by Ladder|es|" },
		{ 9, "Written by CAN|es|" },
		{ 10, "No function|es|" },
		{ 11, "Output activated|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0283
	}
}

COMMAND READ_P0283
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0283 }
	}
}

METHOD SET_PAR_NUMBER_0283
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 283;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0283 LIKE READ_P0283
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 27, P0283 }
		REPLY { }
	}
}

VARIABLE P0284
{
	LABEL "P0284 DO104 Function|es|P0284 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Stop Function|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "Servo Ready|es|" },
		{ 6, "No Fault|es|" },
		{ 7, "No function|es|" },
		{ 8, "Written by Ladder|es|" },
		{ 9, "Written by CAN|es|" },
		{ 10, "No function|es|" },
		{ 11, "Output activated|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0284
	}
}

COMMAND READ_P0284
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0284 }
	}
}

METHOD SET_PAR_NUMBER_0284
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 284;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0284 LIKE READ_P0284
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 28, P0284 }
		REPLY { }
	}
}

VARIABLE P0285
{
	LABEL "P0285 DO105 Function|es|P0285 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Stop Function|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "Servo Ready|es|" },
		{ 6, "No Fault|es|" },
		{ 7, "No function|es|" },
		{ 8, "Written by Ladder|es|" },
		{ 9, "Written by CAN|es|" },
		{ 10, "No function|es|" },
		{ 11, "Output activated|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0285
	}
}

COMMAND READ_P0285
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0285 }
	}
}

METHOD SET_PAR_NUMBER_0285
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 285;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0285 LIKE READ_P0285
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 29, P0285 }
		REPLY { }
	}
}

VARIABLE P0286
{
	LABEL "P0286 DO106 Function|es|P0286 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Stop Function|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "Servo Ready|es|" },
		{ 6, "No Fault|es|" },
		{ 7, "No function|es|" },
		{ 8, "Written by Ladder|es|" },
		{ 9, "Written by CAN|es|" },
		{ 10, "No function|es|" },
		{ 11, "Output activated|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0286
	}
}

COMMAND READ_P0286
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0286 }
	}
}

METHOD SET_PAR_NUMBER_0286
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 286;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0286 LIKE READ_P0286
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 30, P0286 }
		REPLY { }
	}
}

VARIABLE P0287
{
	LABEL "P0287 DO201 Function|es|P0287 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Stop Function|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "Servo Ready|es|" },
		{ 6, "No Fault|es|" },
		{ 7, "No function|es|" },
		{ 8, "Written by Ladder|es|" },
		{ 9, "Written by CAN|es|" },
		{ 10, "No function|es|" },
		{ 11, "Output activated|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0287
	}
}

COMMAND READ_P0287
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0287 }
	}
}

METHOD SET_PAR_NUMBER_0287
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 287;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0287 LIKE READ_P0287
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 31, P0287 }
		REPLY { }
	}
}

VARIABLE P0288
{
	LABEL "P0288 DO202 Function|es|P0288 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Stop Function|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "Servo Ready|es|" },
		{ 6, "No Fault|es|" },
		{ 7, "No function|es|" },
		{ 8, "Written by Ladder|es|" },
		{ 9, "Written by CAN|es|" },
		{ 10, "No function|es|" },
		{ 11, "Output activated|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0288
	}
}

COMMAND READ_P0288
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0288 }
	}
}

METHOD SET_PAR_NUMBER_0288
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 288;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0288 LIKE READ_P0288
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 32, P0288 }
		REPLY { }
	}
}

VARIABLE P0289
{
	LABEL "P0289 DO203 Function|es|P0289 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Stop Function|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "Servo Ready|es|" },
		{ 6, "No Fault|es|" },
		{ 7, "No function|es|" },
		{ 8, "Written by Ladder|es|" },
		{ 9, "Written by CAN|es|" },
		{ 10, "No function|es|" },
		{ 11, "Output activated|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0289
	}
}

COMMAND READ_P0289
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0289 }
	}
}

METHOD SET_PAR_NUMBER_0289
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 289;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0289 LIKE READ_P0289
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 33, P0289 }
		REPLY { }
	}
}

VARIABLE P0290
{
	LABEL "P0290 DO204 Function|es|P0290 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Stop Function|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "Servo Ready|es|" },
		{ 6, "No Fault|es|" },
		{ 7, "No function|es|" },
		{ 8, "Written by Ladder|es|" },
		{ 9, "Written by CAN|es|" },
		{ 10, "No function|es|" },
		{ 11, "Output activated|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0290
	}
}

COMMAND READ_P0290
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0290 }
	}
}

METHOD SET_PAR_NUMBER_0290
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 290;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0290 LIKE READ_P0290
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 34, P0290 }
		REPLY { }
	}
}

VARIABLE P0291
{
	LABEL "P0291 DO205 Function|es|P0291 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Stop Function|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "Servo Ready|es|" },
		{ 6, "No Fault|es|" },
		{ 7, "No function|es|" },
		{ 8, "Written by Ladder|es|" },
		{ 9, "Written by CAN|es|" },
		{ 10, "No function|es|" },
		{ 11, "Output activated|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0291
	}
}

COMMAND READ_P0291
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0291 }
	}
}

METHOD SET_PAR_NUMBER_0291
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 291;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0291 LIKE READ_P0291
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 35, P0291 }
		REPLY { }
	}
}

VARIABLE P0292
{
	LABEL "P0292 DO206 Function|es|P0292 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Stop Function|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "Servo Ready|es|" },
		{ 6, "No Fault|es|" },
		{ 7, "No function|es|" },
		{ 8, "Written by Ladder|es|" },
		{ 9, "Written by CAN|es|" },
		{ 10, "No function|es|" },
		{ 11, "Output activated|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0292
	}
}

COMMAND READ_P0292
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0292 }
	}
}

METHOD SET_PAR_NUMBER_0292
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 292;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0292 LIKE READ_P0292
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 36, P0292 }
		REPLY { }
	}
}

VARIABLE P0293
{
	LABEL "P0293 DO301 Function|es|P0293 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Stop Function|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "Servo Ready|es|" },
		{ 6, "No Fault|es|" },
		{ 7, "No function|es|" },
		{ 8, "Written by Ladder|es|" },
		{ 9, "Written by CAN|es|" },
		{ 10, "No function|es|" },
		{ 11, "Output activated|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0293
	}
}

COMMAND READ_P0293
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0293 }
	}
}

METHOD SET_PAR_NUMBER_0293
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 293;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0293 LIKE READ_P0293
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 37, P0293 }
		REPLY { }
	}
}

VARIABLE P0294
{
	LABEL "P0294 DO302 Function|es|P0294 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Stop Function|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "Servo Ready|es|" },
		{ 6, "No Fault|es|" },
		{ 7, "No function|es|" },
		{ 8, "Written by Ladder|es|" },
		{ 9, "Written by CAN|es|" },
		{ 10, "No function|es|" },
		{ 11, "Output activated|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0294
	}
}

COMMAND READ_P0294
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0294 }
	}
}

METHOD SET_PAR_NUMBER_0294
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 294;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0294 LIKE READ_P0294
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 38, P0294 }
		REPLY { }
	}
}

VARIABLE P0295
{
	LABEL "P0295 DO303 Function|es|P0295 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Stop Function|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "Servo Ready|es|" },
		{ 6, "No Fault|es|" },
		{ 7, "No function|es|" },
		{ 8, "Written by Ladder|es|" },
		{ 9, "Written by CAN|es|" },
		{ 10, "No function|es|" },
		{ 11, "Output activated|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0295
	}
}

COMMAND READ_P0295
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0295 }
	}
}

METHOD SET_PAR_NUMBER_0295
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 295;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0295 LIKE READ_P0295
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 39, P0295 }
		REPLY { }
	}
}

VARIABLE P0296
{
	LABEL "P0296 DO304 Function|es|P0296 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Stop Function|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "Servo Ready|es|" },
		{ 6, "No Fault|es|" },
		{ 7, "No function|es|" },
		{ 8, "Written by Ladder|es|" },
		{ 9, "Written by CAN|es|" },
		{ 10, "No function|es|" },
		{ 11, "Output activated|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0296
	}
}

COMMAND READ_P0296
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0296 }
	}
}

METHOD SET_PAR_NUMBER_0296
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 296;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0296 LIKE READ_P0296
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 40, P0296 }
		REPLY { }
	}
}

VARIABLE P0297
{
	LABEL "P0297 DO305 Function|es|P0297 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Stop Function|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "Servo Ready|es|" },
		{ 6, "No Fault|es|" },
		{ 7, "No function|es|" },
		{ 8, "Written by Ladder|es|" },
		{ 9, "Written by CAN|es|" },
		{ 10, "No function|es|" },
		{ 11, "Output activated|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0297
	}
}

COMMAND READ_P0297
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0297 }
	}
}

METHOD SET_PAR_NUMBER_0297
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 297;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0297 LIKE READ_P0297
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 41, P0297 }
		REPLY { }
	}
}

VARIABLE P0298
{
	LABEL "P0298 DO306 Function|es|P0298 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Stop Function|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "Servo Ready|es|" },
		{ 6, "No Fault|es|" },
		{ 7, "No function|es|" },
		{ 8, "Written by Ladder|es|" },
		{ 9, "Written by CAN|es|" },
		{ 10, "No function|es|" },
		{ 11, "Output activated|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0298
	}
}

COMMAND READ_P0298
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0298 }
	}
}

METHOD SET_PAR_NUMBER_0298
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 298;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0298 LIKE READ_P0298
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 42, P0298 }
		REPLY { }
	}
}

VARIABLE P0300
{
	LABEL "P0300 DI1 Function|es|P0300 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "Standart Counter|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "Load position by DI1 rising edge|es|" },
		{ 9, "Load position by DI1 falling edge|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0300
	}
}

COMMAND READ_P0300
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0300 }
	}
}

METHOD SET_PAR_NUMBER_0300
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 300;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0300 LIKE READ_P0300
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 44, P0300 }
		REPLY { }
	}
}

VARIABLE P0301
{
	LABEL "P0301 DI2 Function|es|P0301 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "Standart Counter|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "Load position by DI1 rising edge|es|" },
		{ 9, "Load position by DI1 falling edge|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0301
	}
}

COMMAND READ_P0301
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0301 }
	}
}

METHOD SET_PAR_NUMBER_0301
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 301;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0301 LIKE READ_P0301
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 45, P0301 }
		REPLY { }
	}
}

VARIABLE P0302
{
	LABEL "P0302 DI3 Function|es|P0302 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "Standart Counter|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "Load position by DI1 rising edge|es|" },
		{ 9, "Load position by DI1 falling edge|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0302
	}
}

COMMAND READ_P0302
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0302 }
	}
}

METHOD SET_PAR_NUMBER_0302
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 302;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0302 LIKE READ_P0302
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 46, P0302 }
		REPLY { }
	}
}

VARIABLE P0303
{
	LABEL "P0303 DI101 Function|es|P0303 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0303
	}
}

COMMAND READ_P0303
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0303 }
	}
}

METHOD SET_PAR_NUMBER_0303
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 303;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0303 LIKE READ_P0303
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 47, P0303 }
		REPLY { }
	}
}

VARIABLE P0304
{
	LABEL "P0304 DI102 Function|es|P0304 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0304
	}
}

COMMAND READ_P0304
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0304 }
	}
}

METHOD SET_PAR_NUMBER_0304
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 304;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0304 LIKE READ_P0304
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 48, P0304 }
		REPLY { }
	}
}

VARIABLE P0305
{
	LABEL "P0305 DI103 Function|es|P0305 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0305
	}
}

COMMAND READ_P0305
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0305 }
	}
}

METHOD SET_PAR_NUMBER_0305
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 305;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0305 LIKE READ_P0305
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 49, P0305 }
		REPLY { }
	}
}

VARIABLE P0306
{
	LABEL "P0306 DI104 Function|es|P0306 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0306
	}
}

COMMAND READ_P0306
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0306 }
	}
}

METHOD SET_PAR_NUMBER_0306
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 306;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0306 LIKE READ_P0306
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 50, P0306 }
		REPLY { }
	}
}

VARIABLE P0307
{
	LABEL "P0307 DI105 Function|es|P0307 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0307
	}
}

COMMAND READ_P0307
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0307 }
	}
}

METHOD SET_PAR_NUMBER_0307
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 307;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0307 LIKE READ_P0307
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 51, P0307 }
		REPLY { }
	}
}

VARIABLE P0308
{
	LABEL "P0308 DI106 Function|es|P0308 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0308
	}
}

COMMAND READ_P0308
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0308 }
	}
}

METHOD SET_PAR_NUMBER_0308
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 308;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0308 LIKE READ_P0308
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 52, P0308 }
		REPLY { }
	}
}

VARIABLE P0309
{
	LABEL "P0309 DI107 Function|es|P0309 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0309
	}
}

COMMAND READ_P0309
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0309 }
	}
}

METHOD SET_PAR_NUMBER_0309
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 309;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0309 LIKE READ_P0309
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 53, P0309 }
		REPLY { }
	}
}

VARIABLE P0310
{
	LABEL "P0310 DI108 Function|es|P0310 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0310
	}
}

COMMAND READ_P0310
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0310 }
	}
}

METHOD SET_PAR_NUMBER_0310
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 310;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0310 LIKE READ_P0310
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 54, P0310 }
		REPLY { }
	}
}

VARIABLE P0311
{
	LABEL "P0311 DI109 Function|es|P0311 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0311
	}
}

COMMAND READ_P0311
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0311 }
	}
}

METHOD SET_PAR_NUMBER_0311
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 311;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0311 LIKE READ_P0311
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 55, P0311 }
		REPLY { }
	}
}

VARIABLE P0312
{
	LABEL "P0312 DI110 Function|es|P0312 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0312
	}
}

COMMAND READ_P0312
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0312 }
	}
}

METHOD SET_PAR_NUMBER_0312
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 312;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0312 LIKE READ_P0312
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 56, P0312 }
		REPLY { }
	}
}

VARIABLE P0313
{
	LABEL "P0313 DI111 Function|es|P0313 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0313
	}
}

COMMAND READ_P0313
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0313 }
	}
}

METHOD SET_PAR_NUMBER_0313
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 313;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0313 LIKE READ_P0313
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 57, P0313 }
		REPLY { }
	}
}

VARIABLE P0314
{
	LABEL "P0314 DI112 Function|es|P0314 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0314
	}
}

COMMAND READ_P0314
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0314 }
	}
}

METHOD SET_PAR_NUMBER_0314
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 314;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0314 LIKE READ_P0314
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 58, P0314 }
		REPLY { }
	}
}

VARIABLE P0315
{
	LABEL "P0315 DI201 Function|es|P0315 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0315
	}
}

COMMAND READ_P0315
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0315 }
	}
}

METHOD SET_PAR_NUMBER_0315
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 315;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0315 LIKE READ_P0315
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 59, P0315 }
		REPLY { }
	}
}

VARIABLE P0316
{
	LABEL "P0316 DI202 Function|es|P0316 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0316
	}
}

COMMAND READ_P0316
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0316 }
	}
}

METHOD SET_PAR_NUMBER_0316
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 316;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0316 LIKE READ_P0316
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 60, P0316 }
		REPLY { }
	}
}

VARIABLE P0317
{
	LABEL "P0317 DI203 Function|es|P0317 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0317
	}
}

COMMAND READ_P0317
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0317 }
	}
}

METHOD SET_PAR_NUMBER_0317
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 317;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0317 LIKE READ_P0317
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 61, P0317 }
		REPLY { }
	}
}

VARIABLE P0318
{
	LABEL "P0318 DI204 Function|es|P0318 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0318
	}
}

COMMAND READ_P0318
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0318 }
	}
}

METHOD SET_PAR_NUMBER_0318
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 318;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0318 LIKE READ_P0318
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 62, P0318 }
		REPLY { }
	}
}

VARIABLE P0319
{
	LABEL "P0319 DI205 Function|es|P0319 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0319
	}
}

COMMAND READ_P0319
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0319 }
	}
}

METHOD SET_PAR_NUMBER_0319
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 319;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0319 LIKE READ_P0319
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 63, P0319 }
		REPLY { }
	}
}

VARIABLE P0320
{
	LABEL "P0320 DI206 Function|es|P0320 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0320
	}
}

COMMAND READ_P0320
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0320 }
	}
}

METHOD SET_PAR_NUMBER_0320
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 320;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0320 LIKE READ_P0320
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 64, P0320 }
		REPLY { }
	}
}

VARIABLE P0321
{
	LABEL "P0321 DI207 Function|es|P0321 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0321
	}
}

COMMAND READ_P0321
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0321 }
	}
}

METHOD SET_PAR_NUMBER_0321
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 321;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0321 LIKE READ_P0321
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 65, P0321 }
		REPLY { }
	}
}

VARIABLE P0322
{
	LABEL "P0322 DI208 Function|es|P0322 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0322
	}
}

COMMAND READ_P0322
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0322 }
	}
}

METHOD SET_PAR_NUMBER_0322
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 322;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0322 LIKE READ_P0322
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 66, P0322 }
		REPLY { }
	}
}

VARIABLE P0323
{
	LABEL "P0323 DI209 Function|es|P0323 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0323
	}
}

COMMAND READ_P0323
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0323 }
	}
}

METHOD SET_PAR_NUMBER_0323
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 323;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0323 LIKE READ_P0323
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 67, P0323 }
		REPLY { }
	}
}

VARIABLE P0324
{
	LABEL "P0324 DI210 Function|es|P0324 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0324
	}
}

COMMAND READ_P0324
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0324 }
	}
}

METHOD SET_PAR_NUMBER_0324
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 324;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0324 LIKE READ_P0324
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 68, P0324 }
		REPLY { }
	}
}

VARIABLE P0325
{
	LABEL "P0325 DI211 Function|es|P0325 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0325
	}
}

COMMAND READ_P0325
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0325 }
	}
}

METHOD SET_PAR_NUMBER_0325
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 325;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0325 LIKE READ_P0325
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 69, P0325 }
		REPLY { }
	}
}

VARIABLE P0326
{
	LABEL "P0326 DI212 Function|es|P0326 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0326
	}
}

COMMAND READ_P0326
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0326 }
	}
}

METHOD SET_PAR_NUMBER_0326
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 326;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0326 LIKE READ_P0326
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 70, P0326 }
		REPLY { }
	}
}

VARIABLE P0327
{
	LABEL "P0327 DI301 Function|es|P0327 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0327
	}
}

COMMAND READ_P0327
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0327 }
	}
}

METHOD SET_PAR_NUMBER_0327
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 327;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0327 LIKE READ_P0327
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 71, P0327 }
		REPLY { }
	}
}

VARIABLE P0328
{
	LABEL "P0328 DI302 Function|es|P0328 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0328
	}
}

COMMAND READ_P0328
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0328 }
	}
}

METHOD SET_PAR_NUMBER_0328
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 328;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0328 LIKE READ_P0328
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 72, P0328 }
		REPLY { }
	}
}

VARIABLE P0329
{
	LABEL "P0329 DI303 Function|es|P0329 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0329
	}
}

COMMAND READ_P0329
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0329 }
	}
}

METHOD SET_PAR_NUMBER_0329
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 329;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0329 LIKE READ_P0329
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 73, P0329 }
		REPLY { }
	}
}

VARIABLE P0330
{
	LABEL "P0330 DI304 Function|es|P0330 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0330
	}
}

COMMAND READ_P0330
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0330 }
	}
}

METHOD SET_PAR_NUMBER_0330
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 330;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0330 LIKE READ_P0330
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 74, P0330 }
		REPLY { }
	}
}

VARIABLE P0331
{
	LABEL "P0331 DI305 Function|es|P0331 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0331
	}
}

COMMAND READ_P0331
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0331 }
	}
}

METHOD SET_PAR_NUMBER_0331
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 331;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0331 LIKE READ_P0331
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 75, P0331 }
		REPLY { }
	}
}

VARIABLE P0332
{
	LABEL "P0332 DI306 Function|es|P0332 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0332
	}
}

COMMAND READ_P0332
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0332 }
	}
}

METHOD SET_PAR_NUMBER_0332
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 332;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0332 LIKE READ_P0332
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 76, P0332 }
		REPLY { }
	}
}

VARIABLE P0333
{
	LABEL "P0333 DI307 Function|es|P0333 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0333
	}
}

COMMAND READ_P0333
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0333 }
	}
}

METHOD SET_PAR_NUMBER_0333
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 333;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0333 LIKE READ_P0333
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 77, P0333 }
		REPLY { }
	}
}

VARIABLE P0334
{
	LABEL "P0334 DI308 Function|es|P0334 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0334
	}
}

COMMAND READ_P0334
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0334 }
	}
}

METHOD SET_PAR_NUMBER_0334
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 334;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0334 LIKE READ_P0334
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 78, P0334 }
		REPLY { }
	}
}

VARIABLE P0335
{
	LABEL "P0335 DI309 Function|es|P0335 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0335
	}
}

COMMAND READ_P0335
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0335 }
	}
}

METHOD SET_PAR_NUMBER_0335
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 335;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0335 LIKE READ_P0335
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 79, P0335 }
		REPLY { }
	}
}

VARIABLE P0336
{
	LABEL "P0336 DI310 Function|es|P0336 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0336
	}
}

COMMAND READ_P0336
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0336 }
	}
}

METHOD SET_PAR_NUMBER_0336
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 336;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0336 LIKE READ_P0336
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 80, P0336 }
		REPLY { }
	}
}

VARIABLE P0337
{
	LABEL "P0337 DI311 Function|es|P0337 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0337
	}
}

COMMAND READ_P0337
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0337 }
	}
}

METHOD SET_PAR_NUMBER_0337
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 337;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0337 LIKE READ_P0337
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 81, P0337 }
		REPLY { }
	}
}

VARIABLE P0338
{
	LABEL "P0338 DI312 Function|es|P0338 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No function|es|" },
		{ 1, "Enable/Disable|es|" },
		{ 2, "Active High Stop Function|es|" },
		{ 3, "Active low Stop Function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Error Reset|es|" },
		{ 7, "Rotation Direction|es|" },
		{ 8, "No function|es|" },
		{ 9, "No function|es|" },
		{ 10, "No function|es|" },
		{ 11, "No function|es|" },
		{ 12, "Active High Clockwise Limit Switch|es|" },
		{ 13, "Active low Clockwise Limit Switch|es|" },
		{ 14, "Active High Counterclockwise Limit Switch|es|" },
		{ 15, "Active Low Counterclockwise Limit Switch|es|" },
		{ 20, "External Error|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0338
	}
}

COMMAND READ_P0338
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0338 }
	}
}

METHOD SET_PAR_NUMBER_0338
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 338;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0338 LIKE READ_P0338
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 82, P0338 }
		REPLY { }
	}
}

VARIABLE P0340
{
	LABEL "P0340 Number of Pulses of Encoder Simulator|es|P0340 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1024;
		MIN_VALUE 0;
		MAX_VALUE 4096;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0340
	}
}

COMMAND READ_P0340
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0340 }
	}
}

METHOD SET_PAR_NUMBER_0340
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 340;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0340 LIKE READ_P0340
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 84, P0340 }
		REPLY { }
	}
}

VARIABLE P0341
{
	LABEL "P0341 Null pulse position|es|P0341 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1;
		MIN_VALUE 1;
		MAX_VALUE 4096;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0341
	}
}

COMMAND READ_P0341
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0341 }
	}
}

METHOD SET_PAR_NUMBER_0341
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 341;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0341 LIKE READ_P0341
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 85, P0341 }
		REPLY { }
	}
}

VARIABLE P0342
{
	LABEL "P0342 Selects sequence A <-> B|es|P0342 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Sequence from A to B|es|" },
		{ 1, "Sequence from B to A|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0342
	}
}

COMMAND READ_P0342
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0342 }
	}
}

METHOD SET_PAR_NUMBER_0342
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 342;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0342 LIKE READ_P0342
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 86, P0342 }
		REPLY { }
	}
}

VARIABLE P0352
{
	LABEL "P0352 Fan control|es|P0352 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Turn on by temperature|es|" },
		{ 1, "Turn on while P0352 = 1|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0352
	}
}

COMMAND READ_P0352
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0352 }
	}
}

METHOD SET_PAR_NUMBER_0352
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 352;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0352 LIKE READ_P0352
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 96, P0352 }
		REPLY { }
	}
}

VARIABLE P0385
{
	LABEL "P0385 Servomotor Model|es|P0385 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No model selected|es|" },
		{ 1, "Reserved|es|" },
		{ 2, "Reserved|es|" },
		{ 3, "SWA 562-2,5-20|es|" },
		{ 4, "SWA 562-3,8-20|es|" },
		{ 5, "SWA 562-6,1-20|es|" },
		{ 6, "SWA 562-8,0-20|es|" },
		{ 7, "SWA 712-9,3-20|es|" },
		{ 8, "SWA 712-13-20|es|" },
		{ 9, "SWA 712-15-20|es|" },
		{ 10, "SWA 712-19-20|es|" },
		{ 11, "SWA 712-22-20|es|" },
		{ 12, "SWA 712-25-20|es|" },
		{ 13, "Reserved|es|" },
		{ 14, "Reserved|es|" },
		{ 15, "Reserved|es|" },
		{ 16, "SWA 712-13-25|es|" },
		{ 17, "Reserved|es|" },
		{ 18, "Reserved|es|" },
		{ 19, "SWA 402-0,8-30|es|" },
		{ 20, "SWA 402-1,6-30|es|" },
		{ 21, "SWA 402-2,6-30|es|" },
		{ 22, "SWA 562-2,5-30|es|" },
		{ 23, "SWA 562-4,0-30|es|" },
		{ 24, "SWA 562-6,1-30|es|" },
		{ 25, "SWA 562-7,0-30|es|" },
		{ 26, "SWA 712-9,3-30|es|" },
		{ 27, "SWA 712-13-30|es|" },
		{ 28, "SWA 712-15-30|es|" },
		{ 29, "SWA 712-19-30|es|" },
		{ 30, "Reserved|es|" },
		{ 31, "Reserved|es|" },
		{ 32, "Reserved|es|" },
		{ 33, "Reserved|es|" },
		{ 34, "Reserved|es|" },
		{ 35, "Reserved|es|" },
		{ 36, "Reserved|es|" },
		{ 37, "SWA 402-1,6-60|es|" },
		{ 38, "SWA 402-2,6-60|es|" },
		{ 39, "SWA 562-2,5-60|es|" },
		{ 40, "SWA 562-3,6-60|es|" },
		{ 41, "SWA 562-5,5-60|es|" },
		{ 42, "SWA 562-6,5-60|es|" },
		{ 43, "Reserved|es|" },
		{ 44, "Reserved|es|" },
		{ 45, "Reserved|es|" },
		{ 46, "Reserved|es|" },
		{ 47, "Reserved|es|" },
		{ 48, "Reserved|es|" },
		{ 49, "Reserved|es|" },
		{ 50, "Reserved|es|" },
		{ 51, "Reserved|es|" },
		{ 52, "Reserved|es|" },
		{ 53, "Reserved|es|" },
		{ 54, "Reserved|es|" },
		{ 55, "SWA 564-6,1-20|es|" },
		{ 56, "SWA 564-8,0-20|es|" },
		{ 57, "SWA 714-9,3-20|es|" },
		{ 58, "SWA 714-13-20|es|" },
		{ 59, "SWA 714-15-20|es|" },
		{ 60, "SWA 714-19-20|es|" },
		{ 61, "SWA 714-22-20|es|" },
		{ 62, "SWA 714-25-20|es|" },
		{ 63, "Reserved|es|" },
		{ 64, "Reserved|es|" },
		{ 65, "SWA 714-40-20|es|" },
		{ 66, "Reserved|es|" },
		{ 67, "Reserved|es|" },
		{ 68, "SWA 1004-50-28|es|" },
		{ 69, "Reserved|es|" },
		{ 70, "Reserved|es|" },
		{ 71, "Reserved|es|" },
		{ 72, "Reserved|es|" },
		{ 73, "SWA 564-4,0-30|es|" },
		{ 74, "SWA 564-6,1-30|es|" },
		{ 75, "SWA 564-7,0-30|es|" },
		{ 76, "SWA 714-9,3-30|es|" },
		{ 77, "SWA 714-13-30|es|" },
		{ 78, "SWA 714-15-30|es|" },
		{ 79, "SWA 714-19-30|es|" },
		{ 80, "Reserved|es|" },
		{ 81, "Reserved|es|" },
		{ 82, "SWA 714-34-30|es|" },
		{ 83, "Reserved|es|" },
		{ 84, "Reserved|es|" },
		{ 85, "Reserved|es|" },
		{ 86, "Reserved|es|" },
		{ 87, "Reserved|es|" },
		{ 88, "SWA 404-2,6-60|es|" },
		{ 89, "SWA 564-2,5-60|es|" },
		{ 90, "SWA 564-3,6-60|es|" },
		{ 91, "SWA 564-5,5-60|es|" },
		{ 92, "SWA 564-6,5-60|es|" },
		{ 93, "Reserved|es|" },
		{ 94, "Reserved|es|" },
		{ 95, "Reserved|es|" },
		{ 96, "Reserved|es|" },
		{ 97, "Reserved|es|" },
		{ 98, "Reserved|es|" },
		{ 99, "Reserved|es|" }
		DEFAULT_VALUE 24;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0385
	}
}

COMMAND READ_P0385
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0385 }
	}
}

METHOD SET_PAR_NUMBER_0385
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 385;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0385 LIKE READ_P0385
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 129, P0385 }
		REPLY { }
	}
}

VARIABLE P0390
{
	LABEL "P0390 Iq reference filter|es|P0390 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 4000;
		MIN_VALUE 0;
		MAX_VALUE 4000;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0390
	}
}

COMMAND READ_P0390
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0390 }
	}
}

METHOD SET_PAR_NUMBER_0390
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 390;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0390 LIKE READ_P0390
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 134, P0390 }
		REPLY { }
	}
}

VARIABLE P0392
{
	LABEL "P0392 Kp current Iq gain|es|P0392 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 2351;
		MIN_VALUE 0;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0392
	}
}

COMMAND READ_P0392
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0392 }
	}
}

METHOD SET_PAR_NUMBER_0392
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 392;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0392 LIKE READ_P0392
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 136, P0392 }
		REPLY { }
	}
}

VARIABLE P0393
{
	LABEL "P0393 Ki current Iq gain|es|P0393 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 250;
		MIN_VALUE 0;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0393
	}
}

COMMAND READ_P0393
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0393 }
	}
}

METHOD SET_PAR_NUMBER_0393
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 393;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0393 LIKE READ_P0393
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 137, P0393 }
		REPLY { }
	}
}

VARIABLE P0395
{
	LABEL "P0395 Kp current Id gain|es|P0395 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 2724;
		MIN_VALUE 0;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0395
	}
}

COMMAND READ_P0395
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0395 }
	}
}

METHOD SET_PAR_NUMBER_0395
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 395;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0395 LIKE READ_P0395
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 139, P0395 }
		REPLY { }
	}
}

VARIABLE P0396
{
	LABEL "P0396 Ki current Id gain|es|P0396 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 500;
		MIN_VALUE 0;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0396
	}
}

COMMAND READ_P0396
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0396 }
	}
}

METHOD SET_PAR_NUMBER_0396
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 396;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0396 LIKE READ_P0396
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 140, P0396 }
		REPLY { }
	}
}

VARIABLE P0398
{
	LABEL "P0398 Phase compensation|es|P0398 Referencia Corriente";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 8192;
		MIN_VALUE -32767;
		MAX_VALUE 32767;
	}
	CONSTANT_UNIT "A";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0398
	}
}

COMMAND READ_P0398
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0398 }
	}
}

METHOD SET_PAR_NUMBER_0398
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 398;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0398 LIKE READ_P0398
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 142, P0398 }
		REPLY { }
	}
}

VARIABLE P0399
{
	LABEL "P0399 Resolver Offset|es|P0399 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0399
	}
}

COMMAND READ_P0399
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0399 }
	}
}

METHOD SET_PAR_NUMBER_0399
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 399;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0399 LIKE READ_P0399
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 143, P0399 }
		REPLY { }
	}
}

VARIABLE P0401
{
	LABEL "P0401 Motor nom. current|es|P0401 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 8.5;
		MIN_VALUE 0;
		MAX_VALUE 999.9;
	}
	CONSTANT_UNIT "A";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0401
	}
}

COMMAND READ_P0401
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0401 }
	}
}

METHOD SET_PAR_NUMBER_0401
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 401;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0401 LIKE READ_P0401
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 145, P0401 }
		REPLY { }
	}
}

VARIABLE P0402
{
	LABEL "P0402 Motor nom. speed|es|P0402 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 3000;
		MIN_VALUE 0;
		MAX_VALUE 9999;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0402
	}
}

COMMAND READ_P0402
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0402 }
	}
}

METHOD SET_PAR_NUMBER_0402
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 402;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0402 LIKE READ_P0402
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 146, P0402 }
		REPLY { }
	}
}

VARIABLE P0407
{
	LABEL "P0407 p/2: pole pair numb.|es|P0407 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 4;
		MIN_VALUE 0;
		MAX_VALUE 16;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0407
	}
}

COMMAND READ_P0407
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0407 }
	}
}

METHOD SET_PAR_NUMBER_0407
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 407;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0407 LIKE READ_P0407
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 151, P0407 }
		REPLY { }
	}
}

VARIABLE P0409
{
	LABEL "P0409 rs|es|P0409 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
		DEFAULT_VALUE 1.2;
		MIN_VALUE 0;
		MAX_VALUE 32.767;
	}
	CONSTANT_UNIT "Ohm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0409
	}
}

COMMAND READ_P0409
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0409 }
	}
}

METHOD SET_PAR_NUMBER_0409
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 409;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0409 LIKE READ_P0409
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 153, P0409 }
		REPLY { }
	}
}

VARIABLE P0414
{
	LABEL "P0414 lq|es|P0414 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
		DEFAULT_VALUE 7.09;
		MIN_VALUE 0;
		MAX_VALUE 327.67;
	}
	CONSTANT_UNIT "mH";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0414
	}
}

COMMAND READ_P0414
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0414 }
	}
}

METHOD SET_PAR_NUMBER_0414
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 414;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0414 LIKE READ_P0414
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 158, P0414 }
		REPLY { }
	}
}

VARIABLE P0415
{
	LABEL "P0415 ld|es|P0415 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
		DEFAULT_VALUE 5.98;
		MIN_VALUE 0;
		MAX_VALUE 327.67;
	}
	CONSTANT_UNIT "mH";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0415
	}
}

COMMAND READ_P0415
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0415 }
	}
}

METHOD SET_PAR_NUMBER_0415
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 415;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0415 LIKE READ_P0415
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 159, P0415 }
		REPLY { }
	}
}

VARIABLE P0416
{
	LABEL "P0416 ke|es|P0416 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 51.2;
		MIN_VALUE 0;
		MAX_VALUE 3276.7;
	}
	CONSTANT_UNIT "V/krpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0416
	}
}

COMMAND READ_P0416
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0416 }
	}
}

METHOD SET_PAR_NUMBER_0416
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 416;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0416 LIKE READ_P0416
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 160, P0416 }
		REPLY { }
	}
}

VARIABLE P0417
{
	LABEL "P0417 kt|es|P0417 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
		DEFAULT_VALUE 0.718;
		MIN_VALUE 0;
		MAX_VALUE 32.767;
	}
	CONSTANT_UNIT "Nm/A";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0417
	}
}

COMMAND READ_P0417
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0417 }
	}
}

METHOD SET_PAR_NUMBER_0417
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 417;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0417 LIKE READ_P0417
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 161, P0417 }
		REPLY { }
	}
}

VARIABLE P0418
{
	LABEL "P0418 Jm|es|P0418 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
		DEFAULT_VALUE 0.497;
		MIN_VALUE 0;
		MAX_VALUE 32.767;
	}
	CONSTANT_UNIT "g.m^2";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0418
	}
}

COMMAND READ_P0418
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0418 }
	}
}

METHOD SET_PAR_NUMBER_0418
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 418;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0418 LIKE READ_P0418
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 162, P0418 }
		REPLY { }
	}
}

VARIABLE P0421
{
	LABEL "P0421 Jl|es|P0421 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 327.67;
	}
	CONSTANT_UNIT "g.m^2";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0421
	}
}

COMMAND READ_P0421
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0421 }
	}
}

METHOD SET_PAR_NUMBER_0421
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 421;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0422
{
	LABEL "P0422 Reserved|es|P0422 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 327.67;
	}
	CONSTANT_UNIT "g.m^2";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0422
	}
}

COMMAND READ_P0422
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0422 }
	}
}

METHOD SET_PAR_NUMBER_0422
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 422;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0423
{
	LABEL "P0423 Reserved|es|P0423 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 3276.7;
	}
	CONSTANT_UNIT "g.m^2";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0423
	}
}

COMMAND READ_P0423
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0423 }
	}
}

METHOD SET_PAR_NUMBER_0423
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 423;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0424
{
	LABEL "P0424 Reserved|es|P0424 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 3276.7;
	}
	CONSTANT_UNIT "g.m^2";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0424
	}
}

COMMAND READ_P0424
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0424 }
	}
}

METHOD SET_PAR_NUMBER_0424
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 424;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0490
{
	LABEL "P0490 Load Absolute position|es|P0490 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0490
	}
}

COMMAND READ_P0490
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0490 }
	}
}

METHOD SET_PAR_NUMBER_0490
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 490;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0490 LIKE READ_P0490
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 234, P0490 }
		REPLY { }
	}
}

VARIABLE P0492
{
	LABEL "P0492 User reference: fractions of revolution|es|P0492 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -16383;
		MAX_VALUE 16383;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0492
	}
}

COMMAND READ_P0492
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0492 }
	}
}

METHOD SET_PAR_NUMBER_0492
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 492;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0492 LIKE READ_P0492
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 236, P0492 }
		REPLY { }
	}
}

VARIABLE P0493
{
	LABEL "P0493 User reference: number of revolutions|es|P0493 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0493
	}
}

COMMAND READ_P0493
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0493 }
	}
}

METHOD SET_PAR_NUMBER_0493
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 493;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0493 LIKE READ_P0493
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 237, P0493 }
		REPLY { }
	}
}

VARIABLE P0500
{
	LABEL "P0500 Count Mode: Standart Counter|es|P0500 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|es|" },
		{ 1, "Quadrature|es|" },
		{ 2, "Pulse and direction|es|" },
		{ 3, "PulseA+/PulseB-|es|" },
		{ 4, "PulseA+|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0500
	}
}

COMMAND READ_P0500
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0500 }
	}
}

METHOD SET_PAR_NUMBER_0500
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 500;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0500 LIKE READ_P0500
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 244, P0500 }
		REPLY { }
	}
}

VARIABLE P0502
{
	LABEL "P0502 Load counter|es|P0502 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0502
	}
}

COMMAND READ_P0502
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0502 }
	}
}

METHOD SET_PAR_NUMBER_0502
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 502;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0502 LIKE READ_P0502
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 246, P0502 }
		REPLY { }
	}
}

VARIABLE P0503
{
	LABEL "P0503 Counter Value - Low|es|P0503 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0503
	}
}

COMMAND READ_P0503
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0503 }
	}
}

METHOD SET_PAR_NUMBER_0503
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 503;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0503 LIKE READ_P0503
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 247, P0503 }
		REPLY { }
	}
}

VARIABLE P0504
{
	LABEL "P0504 Counter Value - High|es|P0504 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0504
	}
}

COMMAND READ_P0504
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0504 }
	}
}

METHOD SET_PAR_NUMBER_0504
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 504;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0504 LIKE READ_P0504
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 248, P0504 }
		REPLY { }
	}
}

VARIABLE P0506
{
	LABEL "P0506 Counter number of pulses/turns|es|P0506 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1024;
		MIN_VALUE 1;
		MAX_VALUE 65535;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0506
	}
}

COMMAND READ_P0506
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0506 }
	}
}

METHOD SET_PAR_NUMBER_0506
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 506;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0506 LIKE READ_P0506
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 250, P0506 }
		REPLY { }
	}
}

VARIABLE P0507
{
	LABEL "P0507 Counter speed filter|es|P0507 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 500;
		MIN_VALUE 1;
		MAX_VALUE 4000;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0507
	}
}

COMMAND READ_P0507
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0507 }
	}
}

METHOD SET_PAR_NUMBER_0507
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 507;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0507 LIKE READ_P0507
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 251, P0507 }
		REPLY { }
	}
}

VARIABLE P0510
{
	LABEL "P0510 Count Mode: Counter 1|es|P0510 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|es|" },
		{ 1, "Quadrature|es|" },
		{ 2, "Pulse and direction|es|" },
		{ 3, "PulseA+/PulseB-|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0510
	}
}

COMMAND READ_P0510
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0510 }
	}
}

METHOD SET_PAR_NUMBER_0510
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 510;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0510 LIKE READ_P0510
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 254, P0510 }
		REPLY { }
	}
}

VARIABLE P0511
{
	LABEL "P0511 Null Pulse 1 options|es|P0511 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|es|" },
		{ 1, "Counter Reset|es|" },
		{ 2, "Load counter 1 by Z1 rising edge|es|" },
		{ 3, "Load counter 1 by Z1 falling edge|es|" },
		{ 4, "Load counter 2 by Z1 rising edge|es|" },
		{ 5, "Load counter 2 by Z1 falling edge|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0511
	}
}

COMMAND READ_P0511
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0511 }
	}
}

METHOD SET_PAR_NUMBER_0511
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 511;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0511 LIKE READ_P0511
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 255, P0511 }
		REPLY { }
	}
}

VARIABLE P0512
{
	LABEL "P0512 Load Counter 1 value|es|P0512 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0512
	}
}

COMMAND READ_P0512
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0512 }
	}
}

METHOD SET_PAR_NUMBER_0512
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 512;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0512 LIKE READ_P0512
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 0, P0512 }
		REPLY { }
	}
}

VARIABLE P0513
{
	LABEL "P0513 Counter 1 value - Low|es|P0513 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0513
	}
}

COMMAND READ_P0513
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0513 }
	}
}

METHOD SET_PAR_NUMBER_0513
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 513;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0513 LIKE READ_P0513
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 1, P0513 }
		REPLY { }
	}
}

VARIABLE P0514
{
	LABEL "P0514 Counter 1 value - High|es|P0514 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0514
	}
}

COMMAND READ_P0514
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0514 }
	}
}

METHOD SET_PAR_NUMBER_0514
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 514;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0514 LIKE READ_P0514
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 2, P0514 }
		REPLY { }
	}
}

VARIABLE P0516
{
	LABEL "P0516 Counter 1 number of pulses/turns|es|P0516 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1024;
		MIN_VALUE 1;
		MAX_VALUE 65535;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0516
	}
}

COMMAND READ_P0516
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0516 }
	}
}

METHOD SET_PAR_NUMBER_0516
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 516;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0516 LIKE READ_P0516
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 4, P0516 }
		REPLY { }
	}
}

VARIABLE P0517
{
	LABEL "P0517 Counter1 speed filter|es|P0517 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 500;
		MIN_VALUE 1;
		MAX_VALUE 4000;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0517
	}
}

COMMAND READ_P0517
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0517 }
	}
}

METHOD SET_PAR_NUMBER_0517
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 517;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0517 LIKE READ_P0517
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 5, P0517 }
		REPLY { }
	}
}

VARIABLE P0519
{
	LABEL "P0519 Error Enable|es|P0519 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disable|es|" },
		{ 1, "Alarm Enable|es|" },
		{ 2, "Fault Enable|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0519
	}
}

COMMAND READ_P0519
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0519 }
	}
}

METHOD SET_PAR_NUMBER_0519
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 519;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0519 LIKE READ_P0519
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 7, P0519 }
		REPLY { }
	}
}

VARIABLE P0520
{
	LABEL "P0520 Count Mode: Counter 2|es|P0520 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|es|" },
		{ 1, "Quadrature|es|" },
		{ 2, "Pulse and direction|es|" },
		{ 3, "PulseA+/PulseB-|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0520
	}
}

COMMAND READ_P0520
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0520 }
	}
}

METHOD SET_PAR_NUMBER_0520
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 520;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0520 LIKE READ_P0520
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 8, P0520 }
		REPLY { }
	}
}

VARIABLE P0521
{
	LABEL "P0521 Null Pulse 2 options|es|P0521 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|es|" },
		{ 1, "Counter Reset|es|" },
		{ 2, "Load counter 2 by Z2 rising edge|es|" },
		{ 3, "Load counter 2 by Z2 falling edge|es|" },
		{ 4, "Load counter 1 by Z2 rising edge|es|" },
		{ 5, "Load counter 1 by Z2 falling edge|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0521
	}
}

COMMAND READ_P0521
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0521 }
	}
}

METHOD SET_PAR_NUMBER_0521
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 521;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0521 LIKE READ_P0521
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 9, P0521 }
		REPLY { }
	}
}

VARIABLE P0522
{
	LABEL "P0522 Load Counter 2 value|es|P0522 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0522
	}
}

COMMAND READ_P0522
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0522 }
	}
}

METHOD SET_PAR_NUMBER_0522
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 522;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0522 LIKE READ_P0522
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 10, P0522 }
		REPLY { }
	}
}

VARIABLE P0523
{
	LABEL "P0523 Counter 2 value - Low|es|P0523 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0523
	}
}

COMMAND READ_P0523
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0523 }
	}
}

METHOD SET_PAR_NUMBER_0523
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 523;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0523 LIKE READ_P0523
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 11, P0523 }
		REPLY { }
	}
}

VARIABLE P0524
{
	LABEL "P0524 Counter 2 value - High|es|P0524 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0524
	}
}

COMMAND READ_P0524
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0524 }
	}
}

METHOD SET_PAR_NUMBER_0524
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 524;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0524 LIKE READ_P0524
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 12, P0524 }
		REPLY { }
	}
}

VARIABLE P0526
{
	LABEL "P0526 Counter 2 number of pulses/turns|es|P0526 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1024;
		MIN_VALUE 1;
		MAX_VALUE 65535;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0526
	}
}

COMMAND READ_P0526
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0526 }
	}
}

METHOD SET_PAR_NUMBER_0526
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 526;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0526 LIKE READ_P0526
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 14, P0526 }
		REPLY { }
	}
}

VARIABLE P0527
{
	LABEL "P0527 Counter 2 speed filter|es|P0527 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 500;
		MIN_VALUE 1;
		MAX_VALUE 4000;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0527
	}
}

COMMAND READ_P0527
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0527 }
	}
}

METHOD SET_PAR_NUMBER_0527
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 527;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0527 LIKE READ_P0527
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 15, P0527 }
		REPLY { }
	}
}

VARIABLE P0529
{
	LABEL "P0529 Error Enable|es|P0529 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|es|" },
		{ 1, "Alarm Enable|es|" },
		{ 2, "Fault Enable|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0529
	}
}

COMMAND READ_P0529
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0529 }
	}
}

METHOD SET_PAR_NUMBER_0529
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 529;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0529 LIKE READ_P0529
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 17, P0529 }
		REPLY { }
	}
}

VARIABLE P0531
{
	LABEL "P0531 Stop function:level or edge|es|P0531 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "stop activation by level|es|" },
		{ 1, "stop activation by edge|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0531
	}
}

COMMAND READ_P0531
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0531 }
	}
}

METHOD SET_PAR_NUMBER_0531
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 531;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0531 LIKE READ_P0531
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 19, P0531 }
		REPLY { }
	}
}

VARIABLE P0550
{
	LABEL "P0550 Trigger 1 Signal Source|es|P0550 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|es|" },
		{ 1, "AI1_filt|es|" },
		{ 2, "AI2_filt|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Speed|es|" },
		{ 7, "Number of revolutions|es|" },
		{ 8, "Fractions of revolution|es|" },
		{ 9, "Ele.Position|es|" },
		{ 10, "iq  |es|" },
		{ 11, "id|es|" },
		{ 12, "Vq|es|" },
		{ 13, "Vd|es|" },
		{ 14, "No function|es|" },
		{ 15, "iv|es|" },
		{ 16, "iw|es|" },
		{ 17, "Vu|es|" },
		{ 18, "Vv|es|" },
		{ 19, "Vw|es|" },
		{ 20, "Vlink|es|" },
		{ 21, "No function|es|" },
		{ 22, "iq_ref|es|" },
		{ 23, "id_ref|es|" },
		{ 24, "No function|es|" },
		{ 25, "No function|es|" },
		{ 26, "No function|es|" },
		{ 27, "Jerke_ref - Real Axis|es|" },
		{ 28, "Accel_ref - Real Axis|es|" },
		{ 29, "w_ref - Real Axis|es|" },
		{ 30, "theta_ref - Real Axis|es|" },
		{ 31, "No function|es|" },
		{ 32, "No function|es|" },
		{ 33, "No function|es|" },
		{ 34, "Jerke_ref - Virtual Axis|es|" },
		{ 35, "Accel_ref - Virtual Axis|es|" },
		{ 36, "w_ref - Virtual Axis|es|" },
		{ 37, "theta_ref - Virtual Axis|es|" },
		{ 38, "No function|es|" },
		{ 39, "No function|es|" },
		{ 40, "No function|es|" },
		{ 41, "No function|es|" },
		{ 42, "No function|es|" },
		{ 43, "No function|es|" },
		{ 44, "No function|es|" },
		{ 45, "No function|es|" },
		{ 46, "No function|es|" },
		{ 47, "No function|es|" },
		{ 48, "No function|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0550
	}
}

COMMAND READ_P0550
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0550 }
	}
}

METHOD SET_PAR_NUMBER_0550
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 550;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0550 LIKE READ_P0550
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 38, P0550 }
		REPLY { }
	}
}

VARIABLE P0551
{
	LABEL "P0551 Trigger 1 Value|es|P0551 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0551
	}
}

COMMAND READ_P0551
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0551 }
	}
}

METHOD SET_PAR_NUMBER_0551
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 551;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0551 LIKE READ_P0551
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 39, P0551 }
		REPLY { }
	}
}

VARIABLE P0552
{
	LABEL "P0552 Trigger 1 Condition|es|P0552 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Higher or equal than reference value|es|" },
		{ 1, "Lower or equal than reference value|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0552
	}
}

COMMAND READ_P0552
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0552 }
	}
}

METHOD SET_PAR_NUMBER_0552
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 552;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0552 LIKE READ_P0552
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 40, P0552 }
		REPLY { }
	}
}

VARIABLE P0553
{
	LABEL "P0553 Trigger 2 Signal Source |es|P0553 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disable|es|" },
		{ 1, "AI1_filt|es|" },
		{ 2, "AI2_filt|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Speed|es|" },
		{ 7, "Number of revolutions|es|" },
		{ 8, "Fractions of revolution|es|" },
		{ 9, "Ele.Position|es|" },
		{ 10, "iq  |es|" },
		{ 11, "id|es|" },
		{ 12, "Vq|es|" },
		{ 13, "Vd|es|" },
		{ 14, "No function|es|" },
		{ 15, "iv|es|" },
		{ 16, "iw|es|" },
		{ 17, "Vu|es|" },
		{ 18, "Vv|es|" },
		{ 19, "Vw|es|" },
		{ 20, "Vlink|es|" },
		{ 21, "No function|es|" },
		{ 22, "iq_ref|es|" },
		{ 23, "id_ref|es|" },
		{ 24, "No function|es|" },
		{ 25, "No function|es|" },
		{ 26, "No function|es|" },
		{ 27, "Jerke_ref - Real Axis|es|" },
		{ 28, "Accel_ref - Real Axis|es|" },
		{ 29, "w_ref - Real Axis|es|" },
		{ 30, "theta_ref - Real Axis|es|" },
		{ 31, "No function|es|" },
		{ 32, "No function|es|" },
		{ 33, "No function|es|" },
		{ 34, "Jerke_ref - Virtual Axis|es|" },
		{ 35, "Accel_ref - Virtual Axis|es|" },
		{ 36, "w_ref - Virtual Axis|es|" },
		{ 37, "theta_ref - Virtual Axis|es|" },
		{ 38, "No function|es|" },
		{ 39, "No function|es|" },
		{ 40, "No function|es|" },
		{ 41, "No function|es|" },
		{ 42, "No function|es|" },
		{ 43, "No function|es|" },
		{ 44, "No function|es|" },
		{ 45, "No function|es|" },
		{ 46, "No function|es|" },
		{ 47, "No function|es|" },
		{ 48, "No function|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0553
	}
}

COMMAND READ_P0553
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0553 }
	}
}

METHOD SET_PAR_NUMBER_0553
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 553;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0553 LIKE READ_P0553
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 41, P0553 }
		REPLY { }
	}
}

VARIABLE P0554
{
	LABEL "P0554 Trigger 2 Value|es|P0554 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0554
	}
}

COMMAND READ_P0554
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0554 }
	}
}

METHOD SET_PAR_NUMBER_0554
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 554;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0554 LIKE READ_P0554
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 42, P0554 }
		REPLY { }
	}
}

VARIABLE P0555
{
	LABEL "P0555 Trigger 2 condition|es|P0555 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Higher or equal than reference value|es|" },
		{ 1, "Lower or equal than reference value|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0555
	}
}

COMMAND READ_P0555
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0555 }
	}
}

METHOD SET_PAR_NUMBER_0555
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 555;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0555 LIKE READ_P0555
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 43, P0555 }
		REPLY { }
	}
}

VARIABLE P0556
{
	LABEL "P0556 Trigger 3 Signal Source (parameters)|es|P0556 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0556
	}
}

COMMAND READ_P0556
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0556 }
	}
}

METHOD SET_PAR_NUMBER_0556
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 556;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0556 LIKE READ_P0556
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 44, P0556 }
		REPLY { }
	}
}

VARIABLE P0557
{
	LABEL "P0557 Trigger 3 Value|es|P0557 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0557
	}
}

COMMAND READ_P0557
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0557 }
	}
}

METHOD SET_PAR_NUMBER_0557
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 557;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0557 LIKE READ_P0557
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 45, P0557 }
		REPLY { }
	}
}

VARIABLE P0558
{
	LABEL "P0558 Trigger 3 condition|es|P0558 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Higher or equal than reference value|es|" },
		{ 1, "Lower or equal than reference value|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0558
	}
}

COMMAND READ_P0558
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0558 }
	}
}

METHOD SET_PAR_NUMBER_0558
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 558;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0558 LIKE READ_P0558
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 46, P0558 }
		REPLY { }
	}
}

VARIABLE P0559
{
	LABEL "P0559 Pre-trigger|es|P0559 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 100;
		MIN_VALUE 0;
		MAX_VALUE 100;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0559
	}
}

COMMAND READ_P0559
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0559 }
	}
}

METHOD SET_PAR_NUMBER_0559
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 559;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0559 LIKE READ_P0559
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 47, P0559 }
		REPLY { }
	}
}

VARIABLE P0560
{
	LABEL "P0560 Logic between triggers|es|P0560 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "OR|es|" },
		{ 1, "AND|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0560
	}
}

COMMAND READ_P0560
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0560 }
	}
}

METHOD SET_PAR_NUMBER_0560
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 560;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0560 LIKE READ_P0560
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 48, P0560 }
		REPLY { }
	}
}

VARIABLE P0561
{
	LABEL "P0561 CH1: Trace channel 1|es|P0561 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disable|es|" },
		{ 1, "Analog Input 1|es|" },
		{ 2, "Analog Input 2|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Speed|es|" },
		{ 7, "No function|es|" },
		{ 8, "Mec.Position|es|" },
		{ 9, "Ele.Position|es|" },
		{ 10, "iq|es|" },
		{ 11, "id|es|" },
		{ 12, "Vq|es|" },
		{ 13, "Vd|es|" },
		{ 14, "No function|es|" },
		{ 15, "iv|es|" },
		{ 16, "iw|es|" },
		{ 17, "Vu|es|" },
		{ 18, "Vv|es|" },
		{ 19, "Vw|es|" },
		{ 20, "V link DC|es|" },
		{ 21, "No function|es|" },
		{ 22, "Ref. iq|es|" },
		{ 23, "Ref. id|es|" },
		{ 24, "No function|es|" },
		{ 25, "No function|es|" },
		{ 26, "No function|es|" },
		{ 27, "Jerke reference(real)|es|" },
		{ 28, "Accel. reference(real)|es|" },
		{ 29, "Speed reference(real)|es|" },
		{ 30, "Position reference(real)|es|" },
		{ 31, "No function|es|" },
		{ 32, "Lag Error|es|" },
		{ 33, "No function|es|" },
		{ 34, "Jerke reference(virtual)|es|" },
		{ 35, "Accel. reference(virtual)|es|" },
		{ 36, "Speed reference(virtual)|es|" },
		{ 37, "Position reference(virtual)|es|" },
		{ 38, "No function|es|" },
		{ 39, "No function|es|" },
		{ 40, "No function|es|" },
		{ 41, "No function|es|" },
		{ 42, "No function|es|" },
		{ 43, "No function|es|" },
		{ 44, "No function|es|" },
		{ 45, "No function|es|" },
		{ 46, "Status Word|es|" },
		{ 47, "No function|es|" },
		{ 48, "No function|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0561
	}
}

COMMAND READ_P0561
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0561 }
	}
}

METHOD SET_PAR_NUMBER_0561
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 561;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0561 LIKE READ_P0561
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 49, P0561 }
		REPLY { }
	}
}

VARIABLE P0562
{
	LABEL "P0562 CH2: Trace Channel 2|es|P0562 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disable|es|" },
		{ 1, "Analog Input 1|es|" },
		{ 2, "Analog Input 2|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Speed|es|" },
		{ 7, "No function|es|" },
		{ 8, "Mec.Position|es|" },
		{ 9, "Ele.Position|es|" },
		{ 10, "iq|es|" },
		{ 11, "id|es|" },
		{ 12, "Vq|es|" },
		{ 13, "Vd|es|" },
		{ 14, "No function|es|" },
		{ 15, "iv|es|" },
		{ 16, "iw|es|" },
		{ 17, "Vu|es|" },
		{ 18, "Vv|es|" },
		{ 19, "Vw|es|" },
		{ 20, "V link DC|es|" },
		{ 21, "No function|es|" },
		{ 22, "Ref. iq|es|" },
		{ 23, "Ref. id|es|" },
		{ 24, "No function|es|" },
		{ 25, "No function|es|" },
		{ 26, "No function|es|" },
		{ 27, "Jerke reference(real)|es|" },
		{ 28, "Accel. reference(real)|es|" },
		{ 29, "Speed reference(real)|es|" },
		{ 30, "Position reference(real)|es|" },
		{ 31, "No function|es|" },
		{ 32, "Lag Error|es|" },
		{ 33, "No function|es|" },
		{ 34, "Jerke reference(virtual)|es|" },
		{ 35, "Accel. reference(virtual)|es|" },
		{ 36, "Speed reference(virtual)|es|" },
		{ 37, "Position reference(virtual)|es|" },
		{ 38, "No function|es|" },
		{ 39, "No function|es|" },
		{ 40, "No function|es|" },
		{ 41, "No function|es|" },
		{ 42, "No function|es|" },
		{ 43, "No function|es|" },
		{ 44, "No function|es|" },
		{ 45, "No function|es|" },
		{ 46, "Status Word|es|" },
		{ 47, "No function|es|" },
		{ 48, "No function|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0562
	}
}

COMMAND READ_P0562
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0562 }
	}
}

METHOD SET_PAR_NUMBER_0562
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 562;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0562 LIKE READ_P0562
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 50, P0562 }
		REPLY { }
	}
}

VARIABLE P0563
{
	LABEL "P0563 CH3: Trace Channel 3|es|P0563 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disable|es|" },
		{ 1, "Analog Input 1|es|" },
		{ 2, "Analog Input 2|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Speed|es|" },
		{ 7, "No function|es|" },
		{ 8, "Mec.Position|es|" },
		{ 9, "Ele.Position|es|" },
		{ 10, "iq|es|" },
		{ 11, "id|es|" },
		{ 12, "Vq|es|" },
		{ 13, "Vd|es|" },
		{ 14, "No function|es|" },
		{ 15, "iv|es|" },
		{ 16, "iw|es|" },
		{ 17, "Vu|es|" },
		{ 18, "Vv|es|" },
		{ 19, "Vw|es|" },
		{ 20, "V link DC|es|" },
		{ 21, "No function|es|" },
		{ 22, "Ref. iq|es|" },
		{ 23, "Ref. id|es|" },
		{ 24, "No function|es|" },
		{ 25, "No function|es|" },
		{ 26, "No function|es|" },
		{ 27, "Jerke reference(real)|es|" },
		{ 28, "Accel. reference(real)|es|" },
		{ 29, "Speed reference(real)|es|" },
		{ 30, "Position reference(real)|es|" },
		{ 31, "No function|es|" },
		{ 32, "Lag Error|es|" },
		{ 33, "No function|es|" },
		{ 34, "Jerke reference(virtual)|es|" },
		{ 35, "Accel. reference(virtual)|es|" },
		{ 36, "Speed reference(virtual)|es|" },
		{ 37, "Position reference(virtual)|es|" },
		{ 38, "No function|es|" },
		{ 39, "No function|es|" },
		{ 40, "No function|es|" },
		{ 41, "No function|es|" },
		{ 42, "No function|es|" },
		{ 43, "No function|es|" },
		{ 44, "No function|es|" },
		{ 45, "No function|es|" },
		{ 46, "Status Word|es|" },
		{ 47, "No function|es|" },
		{ 48, "No function|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0563
	}
}

COMMAND READ_P0563
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0563 }
	}
}

METHOD SET_PAR_NUMBER_0563
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 563;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0563 LIKE READ_P0563
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 51, P0563 }
		REPLY { }
	}
}

VARIABLE P0564
{
	LABEL "P0564 CH4: Trace Channel 4|es|P0564 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disable|es|" },
		{ 1, "Analog Input 1|es|" },
		{ 2, "Analog Input 2|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Speed|es|" },
		{ 7, "No function|es|" },
		{ 8, "Mec.Position|es|" },
		{ 9, "Ele.Position|es|" },
		{ 10, "iq|es|" },
		{ 11, "id|es|" },
		{ 12, "Vq|es|" },
		{ 13, "Vd|es|" },
		{ 14, "No function|es|" },
		{ 15, "iv|es|" },
		{ 16, "iw|es|" },
		{ 17, "Vu|es|" },
		{ 18, "Vv|es|" },
		{ 19, "Vw|es|" },
		{ 20, "V link DC|es|" },
		{ 21, "No function|es|" },
		{ 22, "Ref. iq|es|" },
		{ 23, "Ref. id|es|" },
		{ 24, "No function|es|" },
		{ 25, "No function|es|" },
		{ 26, "No function|es|" },
		{ 27, "Jerke reference(real)|es|" },
		{ 28, "Accel. reference(real)|es|" },
		{ 29, "Speed reference(real)|es|" },
		{ 30, "Position reference(real)|es|" },
		{ 31, "No function|es|" },
		{ 32, "Lag Error|es|" },
		{ 33, "No function|es|" },
		{ 34, "Jerke reference(virtual)|es|" },
		{ 35, "Accel. reference(virtual)|es|" },
		{ 36, "Speed reference(virtual)|es|" },
		{ 37, "Position reference(virtual)|es|" },
		{ 38, "No function|es|" },
		{ 39, "No function|es|" },
		{ 40, "No function|es|" },
		{ 41, "No function|es|" },
		{ 42, "No function|es|" },
		{ 43, "No function|es|" },
		{ 44, "No function|es|" },
		{ 45, "No function|es|" },
		{ 46, "Status Word|es|" },
		{ 47, "No function|es|" },
		{ 48, "No function|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0564
	}
}

COMMAND READ_P0564
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0564 }
	}
}

METHOD SET_PAR_NUMBER_0564
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 564;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0564 LIKE READ_P0564
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 52, P0564 }
		REPLY { }
	}
}

VARIABLE P0565
{
	LABEL "P0565 CH5: Trace Channel 5|es|P0565 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disable|es|" },
		{ 1, "Analog Input 1|es|" },
		{ 2, "Analog Input 2|es|" },
		{ 3, "No function|es|" },
		{ 4, "No function|es|" },
		{ 5, "No function|es|" },
		{ 6, "Speed|es|" },
		{ 7, "No function|es|" },
		{ 8, "Mec.Position|es|" },
		{ 9, "Ele.Position|es|" },
		{ 10, "iq|es|" },
		{ 11, "id|es|" },
		{ 12, "Vq|es|" },
		{ 13, "Vd|es|" },
		{ 14, "No function|es|" },
		{ 15, "iv|es|" },
		{ 16, "iw|es|" },
		{ 17, "Vu|es|" },
		{ 18, "Vv|es|" },
		{ 19, "Vw|es|" },
		{ 20, "V link DC|es|" },
		{ 21, "No function|es|" },
		{ 22, "Ref. iq|es|" },
		{ 23, "Ref. id|es|" },
		{ 24, "No function|es|" },
		{ 25, "No function|es|" },
		{ 26, "No function|es|" },
		{ 27, "Jerke reference(real)|es|" },
		{ 28, "Accel. reference(real)|es|" },
		{ 29, "Speed reference(real)|es|" },
		{ 30, "Position reference(real)|es|" },
		{ 31, "No function|es|" },
		{ 32, "Lag Error|es|" },
		{ 33, "No function|es|" },
		{ 34, "Jerke reference(virtual)|es|" },
		{ 35, "Accel. reference(virtual)|es|" },
		{ 36, "Speed reference(virtual)|es|" },
		{ 37, "Position reference(virtual)|es|" },
		{ 38, "No function|es|" },
		{ 39, "No function|es|" },
		{ 40, "No function|es|" },
		{ 41, "No function|es|" },
		{ 42, "No function|es|" },
		{ 43, "No function|es|" },
		{ 44, "No function|es|" },
		{ 45, "No function|es|" },
		{ 46, "Status Word|es|" },
		{ 47, "No function|es|" },
		{ 48, "No function|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0565
	}
}

COMMAND READ_P0565
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0565 }
	}
}

METHOD SET_PAR_NUMBER_0565
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 565;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0565 LIKE READ_P0565
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 53, P0565 }
		REPLY { }
	}
}

VARIABLE P0566
{
	LABEL "P0566 CH6: Trace Channel 6 (Pars)|es|P0566 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0566
	}
}

COMMAND READ_P0566
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0566 }
	}
}

METHOD SET_PAR_NUMBER_0566
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 566;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0566 LIKE READ_P0566
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 54, P0566 }
		REPLY { }
	}
}

VARIABLE P0568
{
	LABEL "P0568 Force Trigger|es|P0568 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No change|es|" },
		{ 1, "Signal is triggered|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0568
	}
}

COMMAND READ_P0568
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0568 }
	}
}

METHOD SET_PAR_NUMBER_0568
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 568;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0568 LIKE READ_P0568
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 56, P0568 }
		REPLY { }
	}
}

VARIABLE P0569
{
	LABEL "P0569 Sampling period|es|P0569 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1;
		MIN_VALUE 1;
		MAX_VALUE 1000;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0569
	}
}

COMMAND READ_P0569
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0569 }
	}
}

METHOD SET_PAR_NUMBER_0569
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 569;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0569 LIKE READ_P0569
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 57, P0569 }
		REPLY { }
	}
}

VARIABLE P0571
{
	LABEL "P0571 Start Trace function|es|P0571 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off |es|" },
		{ 1, "On|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0571
	}
}

COMMAND READ_P0571
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0571 }
	}
}

METHOD SET_PAR_NUMBER_0571
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 571;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0571 LIKE READ_P0571
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 59, P0571 }
		REPLY { }
	}
}

VARIABLE P0576
{
	LABEL "P0576 Trace function status|es|P0576 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Offline|es|" },
		{ 1, "Waiting|es|" },
		{ 2, "Triggered|es|" },
		{ 3, "Concluded|es|" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0576
	}
}

COMMAND READ_P0576
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0576 }
	}
}

METHOD SET_PAR_NUMBER_0576
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 576;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0577
{
	LABEL "P0577 Time Spent by Trace|es|P0577 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 32.767;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0577
	}
}

COMMAND READ_P0577
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0577 }
	}
}

METHOD SET_PAR_NUMBER_0577
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 577;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0580
{
	LABEL "P0580 Autotuning|es|P0580 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0580
	}
}

COMMAND READ_P0580
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0580 }
	}
}

METHOD SET_PAR_NUMBER_0580
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 580;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0580 LIKE READ_P0580
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 68, P0580 }
		REPLY { }
	}
}

VARIABLE P0582
{
	LABEL "P0582 Rotation Direction|es|P0582 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No rotation|es|" },
		{ 1, "Clockwise rotation|es|" },
		{ 2, "Counterclockwise rotation|es|" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0582
	}
}

COMMAND READ_P0582
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0582 }
	}
}

METHOD SET_PAR_NUMBER_0582
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 582;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0582 LIKE READ_P0582
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 70, P0582 }
		REPLY { }
	}
}

VARIABLE P0650
{
	LABEL "P0650 Serial Address 1|es|P0650 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1;
		MIN_VALUE 1;
		MAX_VALUE 247;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0650
	}
}

COMMAND READ_P0650
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0650 }
	}
}

METHOD SET_PAR_NUMBER_0650
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 650;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0650 LIKE READ_P0650
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 138, P0650 }
		REPLY { }
	}
}

VARIABLE P0652
{
	LABEL "P0652 Bit Rate of Serial 1|es|P0652 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "4800 bits/s|es|" },
		{ 1, "9600 bits/s|es|" },
		{ 2, "14400 bits/s|es|" },
		{ 3, "19200 bits/s|es|" },
		{ 4, "24000 bits/s|es|" },
		{ 5, "28800 bits/s|es|" },
		{ 6, "33600 bits/s|es|" },
		{ 7, "38400 bits/s|es|" },
		{ 8, "43200 bits/s|es|" },
		{ 9, "48000 bits/s|es|" },
		{ 10, "52800 bits/s|es|" },
		{ 11, "57600 bits/s|es|" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0652
	}
}

COMMAND READ_P0652
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0652 }
	}
}

METHOD SET_PAR_NUMBER_0652
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 652;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0652 LIKE READ_P0652
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 140, P0652 }
		REPLY { }
	}
}

VARIABLE P0653
{
	LABEL "P0653 Data bits, parity and stop bit of Serial 1|es|P0653 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "8bits, no parity, 1stop bit|es|" },
		{ 1, "8bits, Even parity, 1stop bit|es|" },
		{ 2, "8bits, Odd parity, 1stop bit|es|" },
		{ 3, "8bits, no parity, 2stop bit|es|" },
		{ 4, "8bits, Even parity, 2stop bit|es|" },
		{ 5, "8bits, Odd parity, 2stop bit|es|" },
		{ 6, "7bits, no parity, 1stop bit|es|" },
		{ 7, "7bits, Even parity, 1stop bit|es|" },
		{ 8, "7bits, Odd parity, 1stop bit|es|" },
		{ 9, "7bits, no parity, 2stop bit|es|" },
		{ 10, "7bits, Even parity, 2stop bit|es|" },
		{ 11, "7bits, Odd parity, 2stop bit|es|" }
		DEFAULT_VALUE 3;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0653
	}
}

COMMAND READ_P0653
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0653 }
	}
}

METHOD SET_PAR_NUMBER_0653
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 653;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0653 LIKE READ_P0653
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 141, P0653 }
		REPLY { }
	}
}

VARIABLE P0654
{
	LABEL "P0654 Serial 1 Protocol|es|P0654 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 1, "WegTP|es|" },
		{ 2, "ModBus|es|" }
		DEFAULT_VALUE 2;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0654
	}
}

COMMAND READ_P0654
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0654 }
	}
}

METHOD SET_PAR_NUMBER_0654
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 654;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0654 LIKE READ_P0654
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 142, P0654 }
		REPLY { }
	}
}

VARIABLE P0656
{
	LABEL "P0656 Serial Address 2|es|P0656 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1;
		MIN_VALUE 0;
		MAX_VALUE 247;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0656
	}
}

COMMAND READ_P0656
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0656 }
	}
}

METHOD SET_PAR_NUMBER_0656
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 656;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0656 LIKE READ_P0656
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 144, P0656 }
		REPLY { }
	}
}

VARIABLE P0658
{
	LABEL "P0658 Bit Rate of Serial 2|es|P0658 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "4800 bits/s|es|" },
		{ 1, "9600 bits/s|es|" },
		{ 2, "14400 bits/s|es|" },
		{ 3, "19200 bits/s|es|" },
		{ 4, "24000 bits/s|es|" },
		{ 5, "28800 bits/s|es|" },
		{ 6, "33600 bits/s|es|" },
		{ 7, "38400 bits/s|es|" },
		{ 8, "43200 bits/s|es|" },
		{ 9, "48000 bits/s|es|" },
		{ 10, "52800 bits/s|es|" },
		{ 11, "57600 bits/s|es|" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0658
	}
}

COMMAND READ_P0658
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0658 }
	}
}

METHOD SET_PAR_NUMBER_0658
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 658;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0658 LIKE READ_P0658
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 146, P0658 }
		REPLY { }
	}
}

VARIABLE P0659
{
	LABEL "P0659 Data bits, parity and stop bit of Serial 2|es|P0659 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "8bits, no parity, 1stop bit|es|" },
		{ 1, "8bits, Even parity, 1stop bit|es|" },
		{ 2, "8bits, Odd parity, 1stop bit|es|" },
		{ 3, "8bits, no parity, 2stop bit|es|" },
		{ 4, "8bits, Even parity, 2stop bit|es|" },
		{ 5, "8bits, Odd parity, 2stop bit|es|" },
		{ 6, "7bits, no parity, 1stop bit|es|" },
		{ 7, "7bits, Even parity, 1stop bit|es|" },
		{ 8, "7bits, Odd parity, 1stop bit|es|" },
		{ 9, "7bits, no parity, 2stop bit|es|" },
		{ 10, "7bits, Even parity, 2stop bit|es|" },
		{ 11, "7bits, Odd parity, 2stop bit|es|" }
		DEFAULT_VALUE 3;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0659
	}
}

COMMAND READ_P0659
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0659 }
	}
}

METHOD SET_PAR_NUMBER_0659
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 659;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0659 LIKE READ_P0659
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 147, P0659 }
		REPLY { }
	}
}

VARIABLE P0660
{
	LABEL "P0660 Serial 2 Protocol|es|P0660 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 1, "WegTP|es|" },
		{ 2, "ModBus|es|" }
		DEFAULT_VALUE 2;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0660
	}
}

COMMAND READ_P0660
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0660 }
	}
}

METHOD SET_PAR_NUMBER_0660
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 660;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0660 LIKE READ_P0660
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 148, P0660 }
		REPLY { }
	}
}

VARIABLE P0662
{
	LABEL "P0662 Communication Error Behavior|es|P0662 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Alarm|es|" },
		{ 1, "Fault|es|" },
		{ 2, "Alarm and STOP |es|" },
		{ 3, "Alarm and Disable|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0662
	}
}

COMMAND READ_P0662
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0662 }
	}
}

METHOD SET_PAR_NUMBER_0662
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 662;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0662 LIKE READ_P0662
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 150, P0662 }
		REPLY { }
	}
}

VARIABLE P0663
{
	LABEL "P0663 Timeout for communication|es|P0663 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999.9;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0663
	}
}

COMMAND READ_P0663
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0663 }
	}
}

METHOD SET_PAR_NUMBER_0663
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 663;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0663 LIKE READ_P0663
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 151, P0663 }
		REPLY { }
	}
}

VARIABLE P0664
{
	LABEL "P0664 Save parameters in non volatile memory|es|P0664 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "No save|es|" },
		{ 1, "Save parameters|es|" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0664
	}
}

COMMAND READ_P0664
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0664 }
	}
}

METHOD SET_PAR_NUMBER_0664
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 664;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0664 LIKE READ_P0664
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 152, P0664 }
		REPLY { }
	}
}

VARIABLE P0667
{
	LABEL "P0667 Parameters serial acess remapping|es|P0667 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Read/Write in parameters|es|" },
		{ 1, "Parameters acess remapping|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0667
	}
}

COMMAND READ_P0667
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0667 }
	}
}

METHOD SET_PAR_NUMBER_0667
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 667;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0667 LIKE READ_P0667
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 155, P0667 }
		REPLY { }
	}
}

VARIABLE P0700
{
	LABEL "P0700 CAN Protocol|es|P0700 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|es|" },
		{ 1, "CANopen|es|" },
		{ 2, "Reserved|es|" },
		{ 3, "Reserved|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0700
	}
}

COMMAND READ_P0700
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0700 }
	}
}

METHOD SET_PAR_NUMBER_0700
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 700;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0700 LIKE READ_P0700
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 188, P0700 }
		REPLY { }
	}
}

VARIABLE P0701
{
	LABEL "P0701 CAN Address |es|P0701 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 63;
		MIN_VALUE 0;
		MAX_VALUE 127;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0701
	}
}

COMMAND READ_P0701
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0701 }
	}
}

METHOD SET_PAR_NUMBER_0701
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 701;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0701 LIKE READ_P0701
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 189, P0701 }
		REPLY { }
	}
}

VARIABLE P0702
{
	LABEL "P0702 Baud rate|es|P0702 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "1 Mbit/s|es|" },
		{ 1, "800 Kbit/s|es|" },
		{ 2, "500 Kbit/s|es|" },
		{ 3, "250 Kbit/s|es|" },
		{ 4, "125 Kbit/s|es|" },
		{ 5, "100 Kbit/s|es|" },
		{ 6, "50 Kbit/s|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0702
	}
}

COMMAND READ_P0702
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0702 }
	}
}

METHOD SET_PAR_NUMBER_0702
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 702;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0702 LIKE READ_P0702
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 190, P0702 }
		REPLY { }
	}
}

VARIABLE P0703
{
	LABEL "P0703 Bus Off Reset|es|P0703 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Manual|es|" },
		{ 1, "Automatic|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0703
	}
}

COMMAND READ_P0703
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0703 }
	}
}

METHOD SET_PAR_NUMBER_0703
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 703;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0703 LIKE READ_P0703
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 191, P0703 }
		REPLY { }
	}
}

VARIABLE P0704
{
	LABEL "P0704 Follow Type|es|P0704 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|es|" },
		{ 1, "Real Master Follow |es|" },
		{ 2, "Virtual Master Follow|es|" },
		{ 3, "Slave Follow|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0704
	}
}

COMMAND READ_P0704
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0704 }
	}
}

METHOD SET_PAR_NUMBER_0704
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 704;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0704 LIKE READ_P0704
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 192, P0704 }
		REPLY { }
	}
}

VARIABLE P0705
{
	LABEL "P0705 Follow COB ID|es|P0705 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 385;
		MIN_VALUE 385;
		MAX_VALUE 511;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0705
	}
}

COMMAND READ_P0705
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0705 }
	}
}

METHOD SET_PAR_NUMBER_0705
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 705;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0705 LIKE READ_P0705
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 193, P0705 }
		REPLY { }
	}
}

VARIABLE P0706
{
	LABEL "P0706 Follow Period|es|P0706 Scan Time";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 1;
		MIN_VALUE 0.2;
		MAX_VALUE 5;
	}
	CONSTANT_UNIT "ms";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0706
	}
}

COMMAND READ_P0706
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0706 }
	}
}

METHOD SET_PAR_NUMBER_0706
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 706;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0706 LIKE READ_P0706
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 194, P0706 }
		REPLY { }
	}
}

VARIABLE P0740
{
	LABEL "P0740 Profibus Comm. Status|es|P0740 Estado Com. Profibus";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|es|Inactivo  " },
		{ 1, "Access Error|es|Error Acceso" },
		{ 2, "Offline|es|Offline" },
		{ 3, "Config. Error|es|Error Config." },
		{ 4, "Param. Error|es|Error Parm." },
		{ 5, "Clear Mode|es|Modo Clear" },
		{ 6, "Online|es|Online" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0740
	}
}

COMMAND READ_P0740
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0740 }
	}
}

METHOD SET_PAR_NUMBER_0740
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 740;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0741
{
	LABEL "P0741 Profibus Data Profile|es|P0741 Perfil Datos Profibus";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "PROFIdrive|es|PROFIdrive" },
		{ 1, "Manufacturer|es|Fabricante" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0741
	}
}

COMMAND READ_P0741
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0741 }
	}
}

METHOD SET_PAR_NUMBER_0741
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 741;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0741 LIKE READ_P0741
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 229, P0741 }
		REPLY { }
	}
}

VARIABLE P0742
{
	LABEL "P0742 Profibus Read Word #5|es|P0742 Lectura #10 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1249;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0742
	}
}

COMMAND READ_P0742
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0742 }
	}
}

METHOD SET_PAR_NUMBER_0742
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 742;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0742 LIKE READ_P0742
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 230, P0742 }
		REPLY { }
	}
}

VARIABLE P0743
{
	LABEL "P0743 Profibus Read Word #6|es|P0743 Lectura #10 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1249;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0743
	}
}

COMMAND READ_P0743
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0743 }
	}
}

METHOD SET_PAR_NUMBER_0743
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 743;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0743 LIKE READ_P0743
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 231, P0743 }
		REPLY { }
	}
}

VARIABLE P0744
{
	LABEL "P0744 Profibus Read Word #7|es|P0744 Lectura #3 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1249;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0744
	}
}

COMMAND READ_P0744
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0744 }
	}
}

METHOD SET_PAR_NUMBER_0744
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 744;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0744 LIKE READ_P0744
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 232, P0744 }
		REPLY { }
	}
}

VARIABLE P0745
{
	LABEL "P0745 Profibus Read Word #8|es|P0745 Lectura #4 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1249;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0745
	}
}

COMMAND READ_P0745
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0745 }
	}
}

METHOD SET_PAR_NUMBER_0745
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 745;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0745 LIKE READ_P0745
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 233, P0745 }
		REPLY { }
	}
}

VARIABLE P0746
{
	LABEL "P0746 Profibus Read Word #9|es|P0746 Lectura #5 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1249;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0746
	}
}

COMMAND READ_P0746
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0746 }
	}
}

METHOD SET_PAR_NUMBER_0746
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 746;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0746 LIKE READ_P0746
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 234, P0746 }
		REPLY { }
	}
}

VARIABLE P0747
{
	LABEL "P0747 Profibus Read Word#10|es|P0747 Lectura #6 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1249;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0747
	}
}

COMMAND READ_P0747
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0747 }
	}
}

METHOD SET_PAR_NUMBER_0747
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 747;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0747 LIKE READ_P0747
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 235, P0747 }
		REPLY { }
	}
}

VARIABLE P0748
{
	LABEL "P0748 Profibus Read Word#11|es|P0748 Lectura #7 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1249;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0748
	}
}

COMMAND READ_P0748
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0748 }
	}
}

METHOD SET_PAR_NUMBER_0748
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 748;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0748 LIKE READ_P0748
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 236, P0748 }
		REPLY { }
	}
}

VARIABLE P0749
{
	LABEL "P0749 Profibus Read Word#12|es|P0749 Lectura #8 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1249;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0749
	}
}

COMMAND READ_P0749
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0749 }
	}
}

METHOD SET_PAR_NUMBER_0749
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 749;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0749 LIKE READ_P0749
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 237, P0749 }
		REPLY { }
	}
}

VARIABLE P0750
{
	LABEL "P0750 Profibus Read Word#13|es|P0750 Lectura #9 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1249;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0750
	}
}

COMMAND READ_P0750
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0750 }
	}
}

METHOD SET_PAR_NUMBER_0750
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 750;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0750 LIKE READ_P0750
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 238, P0750 }
		REPLY { }
	}
}

VARIABLE P0751
{
	LABEL "P0751 Profibus Read Word#14|es|P0751 Lectura #10 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1249;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0751
	}
}

COMMAND READ_P0751
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0751 }
	}
}

METHOD SET_PAR_NUMBER_0751
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 751;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0751 LIKE READ_P0751
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 239, P0751 }
		REPLY { }
	}
}

VARIABLE P0752
{
	LABEL "P0752 Profibus Read Word#15|es|P0752 Lectura #10 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1249;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0752
	}
}

COMMAND READ_P0752
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0752 }
	}
}

METHOD SET_PAR_NUMBER_0752
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 752;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0752 LIKE READ_P0752
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 240, P0752 }
		REPLY { }
	}
}

VARIABLE P0753
{
	LABEL "P0753 Profibus Read Word#16|es|P0753 Lectura #10 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1249;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0753
	}
}

COMMAND READ_P0753
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0753 }
	}
}

METHOD SET_PAR_NUMBER_0753
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 753;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0753 LIKE READ_P0753
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 241, P0753 }
		REPLY { }
	}
}

VARIABLE P0754
{
	LABEL "P0754 Profibus Write Word#5|es|P0754 Escrita #10 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1249;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0754
	}
}

COMMAND READ_P0754
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0754 }
	}
}

METHOD SET_PAR_NUMBER_0754
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 754;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0754 LIKE READ_P0754
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 242, P0754 }
		REPLY { }
	}
}

VARIABLE P0755
{
	LABEL "P0755 Profibus Write Word#6|es|P0755 Escrita #10 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1249;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0755
	}
}

COMMAND READ_P0755
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0755 }
	}
}

METHOD SET_PAR_NUMBER_0755
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 755;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0755 LIKE READ_P0755
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 243, P0755 }
		REPLY { }
	}
}

VARIABLE P0756
{
	LABEL "P0756 Profibus Write Word#7|es|P0756 Escrita #3 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1249;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0756
	}
}

COMMAND READ_P0756
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0756 }
	}
}

METHOD SET_PAR_NUMBER_0756
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 756;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0756 LIKE READ_P0756
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 244, P0756 }
		REPLY { }
	}
}

VARIABLE P0757
{
	LABEL "P0757 Profibus Write Word#8|es|P0757 Escrita #4 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1249;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0757
	}
}

COMMAND READ_P0757
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0757 }
	}
}

METHOD SET_PAR_NUMBER_0757
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 757;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0757 LIKE READ_P0757
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 245, P0757 }
		REPLY { }
	}
}

VARIABLE P0758
{
	LABEL "P0758 Profibus Write Word#9|es|P0758 Escrita #5 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1249;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0758
	}
}

COMMAND READ_P0758
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0758 }
	}
}

METHOD SET_PAR_NUMBER_0758
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 758;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0758 LIKE READ_P0758
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 246, P0758 }
		REPLY { }
	}
}

VARIABLE P0759
{
	LABEL "P0759 Profibus WriteWord#10|es|P0759 Escrita #6 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1249;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0759
	}
}

COMMAND READ_P0759
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0759 }
	}
}

METHOD SET_PAR_NUMBER_0759
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 759;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0759 LIKE READ_P0759
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 247, P0759 }
		REPLY { }
	}
}

VARIABLE P0760
{
	LABEL "P0760 Profibus WriteWord#11|es|P0760 Escrita #7 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1249;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0760
	}
}

COMMAND READ_P0760
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0760 }
	}
}

METHOD SET_PAR_NUMBER_0760
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 760;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0760 LIKE READ_P0760
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 248, P0760 }
		REPLY { }
	}
}

VARIABLE P0761
{
	LABEL "P0761 Profibus WriteWord#12|es|P0761 Escrita #8 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1249;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0761
	}
}

COMMAND READ_P0761
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0761 }
	}
}

METHOD SET_PAR_NUMBER_0761
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 761;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0761 LIKE READ_P0761
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 249, P0761 }
		REPLY { }
	}
}

VARIABLE P0762
{
	LABEL "P0762 Profibus WriteWord#13|es|P0762 Escrita #9 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1249;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0762
	}
}

COMMAND READ_P0762
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0762 }
	}
}

METHOD SET_PAR_NUMBER_0762
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 762;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0762 LIKE READ_P0762
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 250, P0762 }
		REPLY { }
	}
}

VARIABLE P0763
{
	LABEL "P0763 Profibus WriteWord#14|es|P0763 Escrita #10 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1249;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0763
	}
}

COMMAND READ_P0763
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0763 }
	}
}

METHOD SET_PAR_NUMBER_0763
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 763;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0763 LIKE READ_P0763
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 251, P0763 }
		REPLY { }
	}
}

VARIABLE P0764
{
	LABEL "P0764 Profibus WriteWord#15|es|P0764 Escrita #10 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1249;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0764
	}
}

COMMAND READ_P0764
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0764 }
	}
}

METHOD SET_PAR_NUMBER_0764
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 764;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0764 LIKE READ_P0764
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 252, P0764 }
		REPLY { }
	}
}

VARIABLE P0765
{
	LABEL "P0765 Profibus WriteWord#16|es|P0765 Escrita #10 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1249;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0765
	}
}

COMMAND READ_P0765
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0765 }
	}
}

METHOD SET_PAR_NUMBER_0765
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 765;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0765 LIKE READ_P0765
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 253, P0765 }
		REPLY { }
	}
}

VARIABLE P0918
{
	LABEL "P0918 Profibus Address|es|P0918 Direccin Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1;
		MIN_VALUE 1;
		MAX_VALUE 126;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0918
	}
}

COMMAND READ_P0918
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0918 }
	}
}

METHOD SET_PAR_NUMBER_0918
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 918;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0918 LIKE READ_P0918
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 150, P0918 }
		REPLY { }
	}
}

VARIABLE P0922
{
	LABEL "P0922 Profibus Teleg. Sel.|es|P0922 Sel. Teleg. Profibus";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 2, "Std. Teleg. 1|es|Teleg. Std. 1" },
		{ 3, "Telegram 103|es|Telegrama 100" },
		{ 4, "Telegram 104|es|Telegrama 101" },
		{ 5, "Telegram 105|es|Telegrama 102" },
		{ 6, "Telegram 106|es|Telegrama 103" },
		{ 7, "Telegram 107|es|Telegrama 104" },
		{ 8, "Telegram 108|es|Telegrama 105" },
		{ 9, "Telegram 109|es|Telegrama 106" },
		{ 10, "Telegram 110|es|Telegrama 107" },
		{ 11, "Telegram 111|es|" },
		{ 12, "Telegram 112|es|" },
		{ 13, "Telegram 113|es|" },
		{ 14, "Telegram 114|es|" },
		{ 15, "Telegram 115|es|" },
		{ 16, "Telegram 116|es|" }
		DEFAULT_VALUE 2;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0922
	}
}

COMMAND READ_P0922
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0922 }
	}
}

METHOD SET_PAR_NUMBER_0922
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 922;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0922 LIKE READ_P0922
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 154, P0922 }
		REPLY { }
	}
}

VARIABLE P0944
{
	LABEL "P0944 Fault Message Counter|es|P0944 Contador de Fallas";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0944
	}
}

COMMAND READ_P0944
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0944 }
	}
}

METHOD SET_PAR_NUMBER_0944
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 944;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0947
{
	LABEL "P0947 Fault Number|es|P0947 Nmero de la Falla";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0947
	}
}

COMMAND READ_P0947
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0947 }
	}
}

METHOD SET_PAR_NUMBER_0947
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 947;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0963
{
	LABEL "P0963 Profibus Baud Rate|es|P0963 Tasa Comunic.Profibus";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "9.6 kbit/s|es|9.6 kbit/s" },
		{ 1, "19.2 kbit/s|es|19.2 kbit/s" },
		{ 2, "93.75  kbit/s|es|93.75  kbit/s" },
		{ 3, "187.5  kbit/s|es|187.5  kbit/s" },
		{ 4, "500 kbit/s|es|500 kbit/s" },
		{ 5, "Not Detected|es|No Detectada" },
		{ 6, "1500 kbit/s|es|1500 kbit/s" },
		{ 7, "3000 kbit/s|es|3000 kbit/s" },
		{ 8, "6000 kbit/s|es|6000 kbit/s" },
		{ 9, "12000 kbit/s|es|12000 kbit/s" },
		{ 10, "Reserved|es|Reservado" },
		{ 11, "45.45 kbit/s|es|45.45 kbit/s" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0963
	}
}

COMMAND READ_P0963
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0963 }
	}
}

METHOD SET_PAR_NUMBER_0963
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 963;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0964
{
	LABEL "P0964 Drive Unit Ident.|es|P0964 Identificacin Drive";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0964
	}
}

COMMAND READ_P0964
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0964 }
	}
}

METHOD SET_PAR_NUMBER_0964
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 964;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0965
{
	LABEL "P0965 Profile Ident. Number|es|P0965 Identificacin Perfil";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0965
	}
}

COMMAND READ_P0965
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0965 }
	}
}

METHOD SET_PAR_NUMBER_0965
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 965;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0967
{
	LABEL "P0967 Control Word 1|es|P0967 Palabra de Control 1";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0001, "ON|es|Desconecta" },
		{ 0x0002, "No Coast Stop|es|Deshab. Motor" },
		{ 0x0004, "No Quick Stop|es|Parada Rpida" },
		{ 0x0008, "Enable Operation|es|Parar Motor" },
		{ 0x0010, "Enable Ramp|es|Resetea Rampa" },
		{ 0x0020, "Reserved|es|Congela Rampa" },
		{ 0x0040, "Enable Setpoint|es|Cera Ref." },
		{ 0x0080, "Fault Acknowledge|es|Resetea Falla" },
		{ 0x0100, "Jog 1 ON|es|Jog 1" },
		{ 0x0200, "Reserved|es|Jog 2" },
		{ 0x0400, "Control By PLC|es|Sin PLC Ctrl." },
		{ 0xF800, "Reserved|es|Reservado" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0967
	}
}

COMMAND READ_P0967
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0967 }
	}
}

METHOD SET_PAR_NUMBER_0967
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 967;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0968
{
	LABEL "P0968 Status Word 1|es|P0968 Palabra de Status 1";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0001, "Ready To Switch On|es|NoPrep. p/ Conect." },
		{ 0x0002, "Ready To Operate|es|NoPrep. p/ Operar" },
		{ 0x0004, "Operation Enabled|es|Parado" },
		{ 0x0008, "Fault Present|es|Sin error" },
		{ 0x0010, "Coast Stop Not Activated|es|Deshabilitado" },
		{ 0x0020, "Quick Stop Not Activated|es|En parada rpida" },
		{ 0x0040, "Switching On Inhibited|es|Sin alimentacin" },
		{ 0x0080, "Warning Present|es|Sin alarma" },
		{ 0x0100, "Reserved|es|Vel. fuera del rango" },
		{ 0x0200, "Control Requested|es|Sin control va red" },
		{ 0xFC00, "Reserved|es|Reservado" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0968
	}
}

COMMAND READ_P0968
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0968 }
	}
}

METHOD SET_PAR_NUMBER_0968
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 968;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P1000
{
	LABEL "P1000 PLC State|es|P1000 Estado de la PLC";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "No Program|es|Sin Aplicacin" },
		{ 1, "Saving Program|es|Instal. Aplic." },
		{ 2, "Copy Mem.Card|es|Copy Mem.Card" },
		{ 3, "Invalid Prog.|es|Aplic. Incomp." },
		{ 4, "Stopped Prog.|es|Aplic. Parado" },
		{ 5, "Running Prog.|es|Aplic." }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1000
	}
}

COMMAND READ_P1000
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1000 }
	}
}

METHOD SET_PAR_NUMBER_1000
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1000;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P1001
{
	LABEL "P1001 Scan Time|es|P1001 Scan Time";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 6553.5;
	}
	CONSTANT_UNIT "ms";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1001
	}
}

COMMAND READ_P1001
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1001 }
	}
}

METHOD SET_PAR_NUMBER_1001
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1001;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P1003
{
	LABEL "P1003 Fractions of revolution by DI1|es|P1003 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -16383;
		MAX_VALUE 16383;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1003
	}
}

COMMAND READ_P1003
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1003 }
	}
}

METHOD SET_PAR_NUMBER_1003
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1003;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P1004
{
	LABEL "P1004 Number of revolutions by DI1|es|P1004 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1004
	}
}

COMMAND READ_P1004
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1004 }
	}
}

METHOD SET_PAR_NUMBER_1004
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1004;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P1007
{
	LABEL "P1007 Fractions of revolution by DI2|es|P1007 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -16383;
		MAX_VALUE 16383;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1007
	}
}

COMMAND READ_P1007
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1007 }
	}
}

METHOD SET_PAR_NUMBER_1007
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1007;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P1008
{
	LABEL "P1008 Number of revolutions by DI2|es|P1008 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1008
	}
}

COMMAND READ_P1008
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1008 }
	}
}

METHOD SET_PAR_NUMBER_1008
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1008;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P1011
{
	LABEL "P1011 Fractions of revolution by DI3|es|P1011 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -16383;
		MAX_VALUE 16383;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1011
	}
}

COMMAND READ_P1011
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1011 }
	}
}

METHOD SET_PAR_NUMBER_1011
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1011;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P1012
{
	LABEL "P1012 Number of revolutions by DI3|es|P1012 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1012
	}
}

COMMAND READ_P1012
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1012 }
	}
}

METHOD SET_PAR_NUMBER_1012
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1012;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P1014
{
	LABEL "P1014 Standart Counter (low) by DI3|es|P1014 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1014
	}
}

COMMAND READ_P1014
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1014 }
	}
}

METHOD SET_PAR_NUMBER_1014
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1014;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P1015
{
	LABEL "P1015 Standart Counter (high) by DI3|es|P1015 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1015
	}
}

COMMAND READ_P1015
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1015 }
	}
}

METHOD SET_PAR_NUMBER_1015
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1015;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P1016
{
	LABEL "P1016 Counter (low) by Z1|es|P1016 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1016
	}
}

COMMAND READ_P1016
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1016 }
	}
}

METHOD SET_PAR_NUMBER_1016
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1016;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P1017
{
	LABEL "P1017 Counter (high) by Z1|es|P1017 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1017
	}
}

COMMAND READ_P1017
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1017 }
	}
}

METHOD SET_PAR_NUMBER_1017
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1017;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P1018
{
	LABEL "P1018 Counter (low) by Z2|es|P1018 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1018
	}
}

COMMAND READ_P1018
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1018 }
	}
}

METHOD SET_PAR_NUMBER_1018
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1018;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P1019
{
	LABEL "P1019 Counter (high) by Z2|es|P1019 ";
	CLASS DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1019
	}
}

COMMAND READ_P1019
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1019 }
	}
}

METHOD SET_PAR_NUMBER_1019
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1019;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P1020
{
	LABEL "P1020 PLC Command|es|P1020 PLC Command";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Stop Prog.|es|Stop Prog." },
		{ 1, "Run Prog.|es|Run Prog." }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1020
	}
}

COMMAND READ_P1020
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1020 }
	}
}

METHOD SET_PAR_NUMBER_1020
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1020;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1020 LIKE READ_P1020
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 252, P1020 }
		REPLY { }
	}
}

VARIABLE P1021
{
	LABEL "P1021 Scan Time|es|P1021 Scan Time";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 1;
		MIN_VALUE 0.5;
		MAX_VALUE 200;
	}
	CONSTANT_UNIT "ms";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1021
	}
}

COMMAND READ_P1021
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1021 }
	}
}

METHOD SET_PAR_NUMBER_1021
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1021;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1021 LIKE READ_P1021
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 253, P1021 }
		REPLY { }
	}
}

VARIABLE P1022
{
	LABEL "P1022 PLC Watchdog|es|P1022 Scan Time";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 5;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1022
	}
}

COMMAND READ_P1022
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1022 }
	}
}

METHOD SET_PAR_NUMBER_1022
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1022;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1022 LIKE READ_P1022
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 254, P1022 }
		REPLY { }
	}
}

VARIABLE P1023
{
	LABEL "P1023 Control Mode on Power on|es|P1023 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 2, "Speed|es|" },
		{ 3, "Position|es|" }
		DEFAULT_VALUE 3;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1023
	}
}

COMMAND READ_P1023
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1023 }
	}
}

METHOD SET_PAR_NUMBER_1023
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1023;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1023 LIKE READ_P1023
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 255, P1023 }
		REPLY { }
	}
}

VARIABLE P1027
{
	LABEL "P1027 Ret. Markers Reset|es|P1027 Ret. Markers Reset";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|es|Disabled" },
		{ 1, "Reset Markers|es|Reset Markers" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1027
	}
}

COMMAND READ_P1027
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1027 }
	}
}

METHOD SET_PAR_NUMBER_1027
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1027;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1027 LIKE READ_P1027
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 3, P1027 }
		REPLY { }
	}
}

VARIABLE P1028
{
	LABEL "P1028 Load ladder|es|P1028 Ret. Markers Reset";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|es|Disabled" },
		{ 1, "Load user programm|es|Reset Markers" },
		{ 2, "Load parameters configuration|es|Reset Markers" },
		{ 3, "Load CANopen configuration|es|" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1028
	}
}

COMMAND READ_P1028
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1028 }
	}
}

METHOD SET_PAR_NUMBER_1028
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1028;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1028 LIKE READ_P1028
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 4, P1028 }
		REPLY { }
	}
}

VARIABLE P1031
{
	LABEL "P1031 Maximum stopped lag error|es|P1031 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 16383;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1031
	}
}

COMMAND READ_P1031
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1031 }
	}
}

METHOD SET_PAR_NUMBER_1031
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1031;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1031 LIKE READ_P1031
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 7, P1031 }
		REPLY { }
	}
}

VARIABLE P1032
{
	LABEL "P1032 Maximum following lag error|es|P1032 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 16383;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1032
	}
}

COMMAND READ_P1032
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1032 }
	}
}

METHOD SET_PAR_NUMBER_1032
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1032;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1032 LIKE READ_P1032
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 8, P1032 }
		REPLY { }
	}
}

VARIABLE P1035
{
	LABEL "P1035 CAM Speed Filter|es|P1035 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 500;
		MIN_VALUE 1;
		MAX_VALUE 4000;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1035
	}
}

COMMAND READ_P1035
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1035 }
	}
}

METHOD SET_PAR_NUMBER_1035
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1035;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1035 LIKE READ_P1035
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 11, P1035 }
		REPLY { }
	}
}

VARIABLE P1050
{
	LABEL "P1050 User Parameter|es|P1050 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1050
	}
}

COMMAND READ_P1050
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1050 }
	}
}

METHOD SET_PAR_NUMBER_1050
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1050;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1050 LIKE READ_P1050
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 26, P1050 }
		REPLY { }
	}
}

VARIABLE P1051
{
	LABEL "P1051 User Parameter|es|P1051 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1051
	}
}

COMMAND READ_P1051
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1051 }
	}
}

METHOD SET_PAR_NUMBER_1051
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1051;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1051 LIKE READ_P1051
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 27, P1051 }
		REPLY { }
	}
}

VARIABLE P1052
{
	LABEL "P1052 User Parameter|es|P1052 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1052
	}
}

COMMAND READ_P1052
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1052 }
	}
}

METHOD SET_PAR_NUMBER_1052
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1052;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1052 LIKE READ_P1052
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 28, P1052 }
		REPLY { }
	}
}

VARIABLE P1053
{
	LABEL "P1053 User Parameter|es|P1053 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1053
	}
}

COMMAND READ_P1053
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1053 }
	}
}

METHOD SET_PAR_NUMBER_1053
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1053;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1053 LIKE READ_P1053
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 29, P1053 }
		REPLY { }
	}
}

VARIABLE P1054
{
	LABEL "P1054 User Parameter|es|P1054 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1054
	}
}

COMMAND READ_P1054
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1054 }
	}
}

METHOD SET_PAR_NUMBER_1054
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1054;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1054 LIKE READ_P1054
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 30, P1054 }
		REPLY { }
	}
}

VARIABLE P1055
{
	LABEL "P1055 User Parameter|es|P1055 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1055
	}
}

COMMAND READ_P1055
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1055 }
	}
}

METHOD SET_PAR_NUMBER_1055
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1055;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1055 LIKE READ_P1055
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 31, P1055 }
		REPLY { }
	}
}

VARIABLE P1056
{
	LABEL "P1056 User Parameter|es|P1056 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1056
	}
}

COMMAND READ_P1056
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1056 }
	}
}

METHOD SET_PAR_NUMBER_1056
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1056;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1056 LIKE READ_P1056
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 32, P1056 }
		REPLY { }
	}
}

VARIABLE P1057
{
	LABEL "P1057 User Parameter|es|P1057 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1057
	}
}

COMMAND READ_P1057
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1057 }
	}
}

METHOD SET_PAR_NUMBER_1057
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1057;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1057 LIKE READ_P1057
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 33, P1057 }
		REPLY { }
	}
}

VARIABLE P1058
{
	LABEL "P1058 User Parameter|es|P1058 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1058
	}
}

COMMAND READ_P1058
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1058 }
	}
}

METHOD SET_PAR_NUMBER_1058
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1058;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1058 LIKE READ_P1058
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 34, P1058 }
		REPLY { }
	}
}

VARIABLE P1059
{
	LABEL "P1059 User Parameter|es|P1059 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1059
	}
}

COMMAND READ_P1059
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1059 }
	}
}

METHOD SET_PAR_NUMBER_1059
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1059;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1059 LIKE READ_P1059
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 35, P1059 }
		REPLY { }
	}
}

VARIABLE P1060
{
	LABEL "P1060 User Parameter|es|P1060 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1060
	}
}

COMMAND READ_P1060
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1060 }
	}
}

METHOD SET_PAR_NUMBER_1060
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1060;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1060 LIKE READ_P1060
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 36, P1060 }
		REPLY { }
	}
}

VARIABLE P1061
{
	LABEL "P1061 User Parameter|es|P1061 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1061
	}
}

COMMAND READ_P1061
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1061 }
	}
}

METHOD SET_PAR_NUMBER_1061
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1061;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1061 LIKE READ_P1061
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 37, P1061 }
		REPLY { }
	}
}

VARIABLE P1062
{
	LABEL "P1062 User Parameter|es|P1062 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1062
	}
}

COMMAND READ_P1062
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1062 }
	}
}

METHOD SET_PAR_NUMBER_1062
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1062;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1062 LIKE READ_P1062
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 38, P1062 }
		REPLY { }
	}
}

VARIABLE P1063
{
	LABEL "P1063 User Parameter|es|P1063 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1063
	}
}

COMMAND READ_P1063
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1063 }
	}
}

METHOD SET_PAR_NUMBER_1063
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1063;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1063 LIKE READ_P1063
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 39, P1063 }
		REPLY { }
	}
}

VARIABLE P1064
{
	LABEL "P1064 User Parameter|es|P1064 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1064
	}
}

COMMAND READ_P1064
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1064 }
	}
}

METHOD SET_PAR_NUMBER_1064
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1064;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1064 LIKE READ_P1064
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 40, P1064 }
		REPLY { }
	}
}

VARIABLE P1065
{
	LABEL "P1065 User Parameter|es|P1065 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1065
	}
}

COMMAND READ_P1065
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1065 }
	}
}

METHOD SET_PAR_NUMBER_1065
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1065;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1065 LIKE READ_P1065
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 41, P1065 }
		REPLY { }
	}
}

VARIABLE P1066
{
	LABEL "P1066 User Parameter|es|P1066 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1066
	}
}

COMMAND READ_P1066
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1066 }
	}
}

METHOD SET_PAR_NUMBER_1066
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1066;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1066 LIKE READ_P1066
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 42, P1066 }
		REPLY { }
	}
}

VARIABLE P1067
{
	LABEL "P1067 User Parameter|es|P1067 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1067
	}
}

COMMAND READ_P1067
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1067 }
	}
}

METHOD SET_PAR_NUMBER_1067
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1067;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1067 LIKE READ_P1067
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 43, P1067 }
		REPLY { }
	}
}

VARIABLE P1068
{
	LABEL "P1068 User Parameter|es|P1068 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1068
	}
}

COMMAND READ_P1068
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1068 }
	}
}

METHOD SET_PAR_NUMBER_1068
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1068;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1068 LIKE READ_P1068
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 44, P1068 }
		REPLY { }
	}
}

VARIABLE P1069
{
	LABEL "P1069 User Parameter|es|P1069 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1069
	}
}

COMMAND READ_P1069
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1069 }
	}
}

METHOD SET_PAR_NUMBER_1069
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1069;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1069 LIKE READ_P1069
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 45, P1069 }
		REPLY { }
	}
}

VARIABLE P1070
{
	LABEL "P1070 User Parameter|es|P1070 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1070
	}
}

COMMAND READ_P1070
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1070 }
	}
}

METHOD SET_PAR_NUMBER_1070
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1070;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1070 LIKE READ_P1070
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 46, P1070 }
		REPLY { }
	}
}

VARIABLE P1071
{
	LABEL "P1071 User Parameter|es|P1071 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1071
	}
}

COMMAND READ_P1071
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1071 }
	}
}

METHOD SET_PAR_NUMBER_1071
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1071;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1071 LIKE READ_P1071
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 47, P1071 }
		REPLY { }
	}
}

VARIABLE P1072
{
	LABEL "P1072 User Parameter|es|P1072 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1072
	}
}

COMMAND READ_P1072
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1072 }
	}
}

METHOD SET_PAR_NUMBER_1072
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1072;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1072 LIKE READ_P1072
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 48, P1072 }
		REPLY { }
	}
}

VARIABLE P1073
{
	LABEL "P1073 User Parameter|es|P1073 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1073
	}
}

COMMAND READ_P1073
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1073 }
	}
}

METHOD SET_PAR_NUMBER_1073
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1073;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1073 LIKE READ_P1073
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 49, P1073 }
		REPLY { }
	}
}

VARIABLE P1074
{
	LABEL "P1074 User Parameter|es|P1074 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1074
	}
}

COMMAND READ_P1074
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1074 }
	}
}

METHOD SET_PAR_NUMBER_1074
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1074;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1074 LIKE READ_P1074
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 50, P1074 }
		REPLY { }
	}
}

VARIABLE P1075
{
	LABEL "P1075 User Parameter|es|P1075 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1075
	}
}

COMMAND READ_P1075
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1075 }
	}
}

METHOD SET_PAR_NUMBER_1075
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1075;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1075 LIKE READ_P1075
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 51, P1075 }
		REPLY { }
	}
}

VARIABLE P1076
{
	LABEL "P1076 User Parameter|es|P1076 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1076
	}
}

COMMAND READ_P1076
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1076 }
	}
}

METHOD SET_PAR_NUMBER_1076
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1076;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1076 LIKE READ_P1076
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 52, P1076 }
		REPLY { }
	}
}

VARIABLE P1077
{
	LABEL "P1077 User Parameter|es|P1077 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1077
	}
}

COMMAND READ_P1077
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1077 }
	}
}

METHOD SET_PAR_NUMBER_1077
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1077;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1077 LIKE READ_P1077
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 53, P1077 }
		REPLY { }
	}
}

VARIABLE P1078
{
	LABEL "P1078 User Parameter|es|P1078 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1078
	}
}

COMMAND READ_P1078
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1078 }
	}
}

METHOD SET_PAR_NUMBER_1078
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1078;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1078 LIKE READ_P1078
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 54, P1078 }
		REPLY { }
	}
}

VARIABLE P1079
{
	LABEL "P1079 User Parameter|es|P1079 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1079
	}
}

COMMAND READ_P1079
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1079 }
	}
}

METHOD SET_PAR_NUMBER_1079
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1079;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1079 LIKE READ_P1079
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 55, P1079 }
		REPLY { }
	}
}

VARIABLE P1080
{
	LABEL "P1080 User Parameter|es|P1080 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1080
	}
}

COMMAND READ_P1080
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1080 }
	}
}

METHOD SET_PAR_NUMBER_1080
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1080;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1080 LIKE READ_P1080
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 56, P1080 }
		REPLY { }
	}
}

VARIABLE P1081
{
	LABEL "P1081 User Parameter|es|P1081 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1081
	}
}

COMMAND READ_P1081
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1081 }
	}
}

METHOD SET_PAR_NUMBER_1081
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1081;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1081 LIKE READ_P1081
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 57, P1081 }
		REPLY { }
	}
}

VARIABLE P1082
{
	LABEL "P1082 User Parameter|es|P1082 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1082
	}
}

COMMAND READ_P1082
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1082 }
	}
}

METHOD SET_PAR_NUMBER_1082
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1082;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1082 LIKE READ_P1082
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 58, P1082 }
		REPLY { }
	}
}

VARIABLE P1083
{
	LABEL "P1083 User Parameter|es|P1083 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1083
	}
}

COMMAND READ_P1083
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1083 }
	}
}

METHOD SET_PAR_NUMBER_1083
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1083;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1083 LIKE READ_P1083
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 59, P1083 }
		REPLY { }
	}
}

VARIABLE P1084
{
	LABEL "P1084 User Parameter|es|P1084 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1084
	}
}

COMMAND READ_P1084
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1084 }
	}
}

METHOD SET_PAR_NUMBER_1084
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1084;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1084 LIKE READ_P1084
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 60, P1084 }
		REPLY { }
	}
}

VARIABLE P1085
{
	LABEL "P1085 User Parameter|es|P1085 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1085
	}
}

COMMAND READ_P1085
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1085 }
	}
}

METHOD SET_PAR_NUMBER_1085
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1085;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1085 LIKE READ_P1085
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 61, P1085 }
		REPLY { }
	}
}

VARIABLE P1086
{
	LABEL "P1086 User Parameter|es|P1086 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1086
	}
}

COMMAND READ_P1086
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1086 }
	}
}

METHOD SET_PAR_NUMBER_1086
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1086;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1086 LIKE READ_P1086
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 62, P1086 }
		REPLY { }
	}
}

VARIABLE P1087
{
	LABEL "P1087 User Parameter|es|P1087 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1087
	}
}

COMMAND READ_P1087
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1087 }
	}
}

METHOD SET_PAR_NUMBER_1087
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1087;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1087 LIKE READ_P1087
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 63, P1087 }
		REPLY { }
	}
}

VARIABLE P1088
{
	LABEL "P1088 User Parameter|es|P1088 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1088
	}
}

COMMAND READ_P1088
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1088 }
	}
}

METHOD SET_PAR_NUMBER_1088
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1088;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1088 LIKE READ_P1088
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 64, P1088 }
		REPLY { }
	}
}

VARIABLE P1089
{
	LABEL "P1089 User Parameter|es|P1089 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1089
	}
}

COMMAND READ_P1089
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1089 }
	}
}

METHOD SET_PAR_NUMBER_1089
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1089;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1089 LIKE READ_P1089
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 65, P1089 }
		REPLY { }
	}
}

VARIABLE P1090
{
	LABEL "P1090 User Parameter|es|P1090 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1090
	}
}

COMMAND READ_P1090
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1090 }
	}
}

METHOD SET_PAR_NUMBER_1090
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1090;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1090 LIKE READ_P1090
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 66, P1090 }
		REPLY { }
	}
}

VARIABLE P1091
{
	LABEL "P1091 User Parameter|es|P1091 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1091
	}
}

COMMAND READ_P1091
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1091 }
	}
}

METHOD SET_PAR_NUMBER_1091
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1091;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1091 LIKE READ_P1091
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 67, P1091 }
		REPLY { }
	}
}

VARIABLE P1092
{
	LABEL "P1092 User Parameter|es|P1092 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1092
	}
}

COMMAND READ_P1092
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1092 }
	}
}

METHOD SET_PAR_NUMBER_1092
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1092;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1092 LIKE READ_P1092
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 68, P1092 }
		REPLY { }
	}
}

VARIABLE P1093
{
	LABEL "P1093 User Parameter|es|P1093 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1093
	}
}

COMMAND READ_P1093
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1093 }
	}
}

METHOD SET_PAR_NUMBER_1093
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1093;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1093 LIKE READ_P1093
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 69, P1093 }
		REPLY { }
	}
}

VARIABLE P1094
{
	LABEL "P1094 User Parameter|es|P1094 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1094
	}
}

COMMAND READ_P1094
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1094 }
	}
}

METHOD SET_PAR_NUMBER_1094
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1094;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1094 LIKE READ_P1094
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 70, P1094 }
		REPLY { }
	}
}

VARIABLE P1095
{
	LABEL "P1095 User Parameter|es|P1095 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1095
	}
}

COMMAND READ_P1095
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1095 }
	}
}

METHOD SET_PAR_NUMBER_1095
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1095;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1095 LIKE READ_P1095
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 71, P1095 }
		REPLY { }
	}
}

VARIABLE P1096
{
	LABEL "P1096 User Parameter|es|P1096 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1096
	}
}

COMMAND READ_P1096
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1096 }
	}
}

METHOD SET_PAR_NUMBER_1096
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1096;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1096 LIKE READ_P1096
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 72, P1096 }
		REPLY { }
	}
}

VARIABLE P1097
{
	LABEL "P1097 User Parameter|es|P1097 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1097
	}
}

COMMAND READ_P1097
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1097 }
	}
}

METHOD SET_PAR_NUMBER_1097
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1097;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1097 LIKE READ_P1097
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 73, P1097 }
		REPLY { }
	}
}

VARIABLE P1098
{
	LABEL "P1098 User Parameter|es|P1098 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1098
	}
}

COMMAND READ_P1098
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1098 }
	}
}

METHOD SET_PAR_NUMBER_1098
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1098;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1098 LIKE READ_P1098
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 74, P1098 }
		REPLY { }
	}
}

VARIABLE P1099
{
	LABEL "P1099 User Parameter|es|P1099 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1099
	}
}

COMMAND READ_P1099
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1099 }
	}
}

METHOD SET_PAR_NUMBER_1099
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1099;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1099 LIKE READ_P1099
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 75, P1099 }
		REPLY { }
	}
}

VARIABLE P1100
{
	LABEL "P1100 User Parameter|es|P1100 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1100
	}
}

COMMAND READ_P1100
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1100 }
	}
}

METHOD SET_PAR_NUMBER_1100
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1100;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1100 LIKE READ_P1100
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 76, P1100 }
		REPLY { }
	}
}

VARIABLE P1101
{
	LABEL "P1101 User Parameter|es|P1101 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1101
	}
}

COMMAND READ_P1101
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1101 }
	}
}

METHOD SET_PAR_NUMBER_1101
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1101;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1101 LIKE READ_P1101
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 77, P1101 }
		REPLY { }
	}
}

VARIABLE P1102
{
	LABEL "P1102 User Parameter|es|P1102 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1102
	}
}

COMMAND READ_P1102
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1102 }
	}
}

METHOD SET_PAR_NUMBER_1102
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1102;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1102 LIKE READ_P1102
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 78, P1102 }
		REPLY { }
	}
}

VARIABLE P1103
{
	LABEL "P1103 User Parameter|es|P1103 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1103
	}
}

COMMAND READ_P1103
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1103 }
	}
}

METHOD SET_PAR_NUMBER_1103
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1103;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1103 LIKE READ_P1103
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 79, P1103 }
		REPLY { }
	}
}

VARIABLE P1104
{
	LABEL "P1104 User Parameter|es|P1104 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1104
	}
}

COMMAND READ_P1104
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1104 }
	}
}

METHOD SET_PAR_NUMBER_1104
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1104;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1104 LIKE READ_P1104
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 80, P1104 }
		REPLY { }
	}
}

VARIABLE P1105
{
	LABEL "P1105 User Parameter|es|P1105 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1105
	}
}

COMMAND READ_P1105
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1105 }
	}
}

METHOD SET_PAR_NUMBER_1105
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1105;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1105 LIKE READ_P1105
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 81, P1105 }
		REPLY { }
	}
}

VARIABLE P1106
{
	LABEL "P1106 User Parameter|es|P1106 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1106
	}
}

COMMAND READ_P1106
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1106 }
	}
}

METHOD SET_PAR_NUMBER_1106
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1106;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1106 LIKE READ_P1106
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 82, P1106 }
		REPLY { }
	}
}

VARIABLE P1107
{
	LABEL "P1107 User Parameter|es|P1107 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1107
	}
}

COMMAND READ_P1107
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1107 }
	}
}

METHOD SET_PAR_NUMBER_1107
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1107;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1107 LIKE READ_P1107
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 83, P1107 }
		REPLY { }
	}
}

VARIABLE P1108
{
	LABEL "P1108 User Parameter|es|P1108 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1108
	}
}

COMMAND READ_P1108
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1108 }
	}
}

METHOD SET_PAR_NUMBER_1108
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1108;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1108 LIKE READ_P1108
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 84, P1108 }
		REPLY { }
	}
}

VARIABLE P1109
{
	LABEL "P1109 User Parameter|es|P1109 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1109
	}
}

COMMAND READ_P1109
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1109 }
	}
}

METHOD SET_PAR_NUMBER_1109
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1109;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1109 LIKE READ_P1109
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 85, P1109 }
		REPLY { }
	}
}

VARIABLE P1110
{
	LABEL "P1110 User Parameter|es|P1110 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1110
	}
}

COMMAND READ_P1110
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1110 }
	}
}

METHOD SET_PAR_NUMBER_1110
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1110;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1110 LIKE READ_P1110
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 86, P1110 }
		REPLY { }
	}
}

VARIABLE P1111
{
	LABEL "P1111 User Parameter|es|P1111 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1111
	}
}

COMMAND READ_P1111
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1111 }
	}
}

METHOD SET_PAR_NUMBER_1111
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1111;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1111 LIKE READ_P1111
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 87, P1111 }
		REPLY { }
	}
}

VARIABLE P1112
{
	LABEL "P1112 User Parameter|es|P1112 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1112
	}
}

COMMAND READ_P1112
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1112 }
	}
}

METHOD SET_PAR_NUMBER_1112
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1112;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1112 LIKE READ_P1112
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 88, P1112 }
		REPLY { }
	}
}

VARIABLE P1113
{
	LABEL "P1113 User Parameter|es|P1113 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1113
	}
}

COMMAND READ_P1113
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1113 }
	}
}

METHOD SET_PAR_NUMBER_1113
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1113;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1113 LIKE READ_P1113
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 89, P1113 }
		REPLY { }
	}
}

VARIABLE P1114
{
	LABEL "P1114 User Parameter|es|P1114 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1114
	}
}

COMMAND READ_P1114
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1114 }
	}
}

METHOD SET_PAR_NUMBER_1114
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1114;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1114 LIKE READ_P1114
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 90, P1114 }
		REPLY { }
	}
}

VARIABLE P1115
{
	LABEL "P1115 User Parameter|es|P1115 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1115
	}
}

COMMAND READ_P1115
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1115 }
	}
}

METHOD SET_PAR_NUMBER_1115
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1115;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1115 LIKE READ_P1115
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 91, P1115 }
		REPLY { }
	}
}

VARIABLE P1116
{
	LABEL "P1116 User Parameter|es|P1116 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1116
	}
}

COMMAND READ_P1116
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1116 }
	}
}

METHOD SET_PAR_NUMBER_1116
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1116;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1116 LIKE READ_P1116
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 92, P1116 }
		REPLY { }
	}
}

VARIABLE P1117
{
	LABEL "P1117 User Parameter|es|P1117 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1117
	}
}

COMMAND READ_P1117
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1117 }
	}
}

METHOD SET_PAR_NUMBER_1117
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1117;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1117 LIKE READ_P1117
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 93, P1117 }
		REPLY { }
	}
}

VARIABLE P1118
{
	LABEL "P1118 User Parameter|es|P1118 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1118
	}
}

COMMAND READ_P1118
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1118 }
	}
}

METHOD SET_PAR_NUMBER_1118
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1118;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1118 LIKE READ_P1118
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 94, P1118 }
		REPLY { }
	}
}

VARIABLE P1119
{
	LABEL "P1119 User Parameter|es|P1119 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1119
	}
}

COMMAND READ_P1119
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1119 }
	}
}

METHOD SET_PAR_NUMBER_1119
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1119;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1119 LIKE READ_P1119
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 95, P1119 }
		REPLY { }
	}
}

VARIABLE P1120
{
	LABEL "P1120 User Parameter|es|P1120 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1120
	}
}

COMMAND READ_P1120
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1120 }
	}
}

METHOD SET_PAR_NUMBER_1120
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1120;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1120 LIKE READ_P1120
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 96, P1120 }
		REPLY { }
	}
}

VARIABLE P1121
{
	LABEL "P1121 User Parameter|es|P1121 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1121
	}
}

COMMAND READ_P1121
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1121 }
	}
}

METHOD SET_PAR_NUMBER_1121
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1121;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1121 LIKE READ_P1121
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 97, P1121 }
		REPLY { }
	}
}

VARIABLE P1122
{
	LABEL "P1122 User Parameter|es|P1122 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1122
	}
}

COMMAND READ_P1122
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1122 }
	}
}

METHOD SET_PAR_NUMBER_1122
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1122;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1122 LIKE READ_P1122
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 98, P1122 }
		REPLY { }
	}
}

VARIABLE P1123
{
	LABEL "P1123 User Parameter|es|P1123 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1123
	}
}

COMMAND READ_P1123
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1123 }
	}
}

METHOD SET_PAR_NUMBER_1123
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1123;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1123 LIKE READ_P1123
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 99, P1123 }
		REPLY { }
	}
}

VARIABLE P1124
{
	LABEL "P1124 User Parameter|es|P1124 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1124
	}
}

COMMAND READ_P1124
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1124 }
	}
}

METHOD SET_PAR_NUMBER_1124
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1124;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1124 LIKE READ_P1124
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 100, P1124 }
		REPLY { }
	}
}

VARIABLE P1125
{
	LABEL "P1125 User Parameter|es|P1125 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1125
	}
}

COMMAND READ_P1125
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1125 }
	}
}

METHOD SET_PAR_NUMBER_1125
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1125;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1125 LIKE READ_P1125
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 101, P1125 }
		REPLY { }
	}
}

VARIABLE P1126
{
	LABEL "P1126 User Parameter|es|P1126 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1126
	}
}

COMMAND READ_P1126
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1126 }
	}
}

METHOD SET_PAR_NUMBER_1126
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1126;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1126 LIKE READ_P1126
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 102, P1126 }
		REPLY { }
	}
}

VARIABLE P1127
{
	LABEL "P1127 User Parameter|es|P1127 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1127
	}
}

COMMAND READ_P1127
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1127 }
	}
}

METHOD SET_PAR_NUMBER_1127
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1127;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1127 LIKE READ_P1127
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 103, P1127 }
		REPLY { }
	}
}

VARIABLE P1128
{
	LABEL "P1128 User Parameter|es|P1128 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1128
	}
}

COMMAND READ_P1128
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1128 }
	}
}

METHOD SET_PAR_NUMBER_1128
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1128;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1128 LIKE READ_P1128
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 104, P1128 }
		REPLY { }
	}
}

VARIABLE P1129
{
	LABEL "P1129 User Parameter|es|P1129 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1129
	}
}

COMMAND READ_P1129
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1129 }
	}
}

METHOD SET_PAR_NUMBER_1129
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1129;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1129 LIKE READ_P1129
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 105, P1129 }
		REPLY { }
	}
}

VARIABLE P1130
{
	LABEL "P1130 User Parameter|es|P1130 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1130
	}
}

COMMAND READ_P1130
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1130 }
	}
}

METHOD SET_PAR_NUMBER_1130
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1130;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1130 LIKE READ_P1130
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 106, P1130 }
		REPLY { }
	}
}

VARIABLE P1131
{
	LABEL "P1131 User Parameter|es|P1131 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1131
	}
}

COMMAND READ_P1131
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1131 }
	}
}

METHOD SET_PAR_NUMBER_1131
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1131;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1131 LIKE READ_P1131
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 107, P1131 }
		REPLY { }
	}
}

VARIABLE P1132
{
	LABEL "P1132 User Parameter|es|P1132 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1132
	}
}

COMMAND READ_P1132
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1132 }
	}
}

METHOD SET_PAR_NUMBER_1132
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1132;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1132 LIKE READ_P1132
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 108, P1132 }
		REPLY { }
	}
}

VARIABLE P1133
{
	LABEL "P1133 User Parameter|es|P1133 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1133
	}
}

COMMAND READ_P1133
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1133 }
	}
}

METHOD SET_PAR_NUMBER_1133
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1133;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1133 LIKE READ_P1133
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 109, P1133 }
		REPLY { }
	}
}

VARIABLE P1134
{
	LABEL "P1134 User Parameter|es|P1134 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1134
	}
}

COMMAND READ_P1134
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1134 }
	}
}

METHOD SET_PAR_NUMBER_1134
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1134;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1134 LIKE READ_P1134
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 110, P1134 }
		REPLY { }
	}
}

VARIABLE P1135
{
	LABEL "P1135 User Parameter|es|P1135 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1135
	}
}

COMMAND READ_P1135
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1135 }
	}
}

METHOD SET_PAR_NUMBER_1135
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1135;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1135 LIKE READ_P1135
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 111, P1135 }
		REPLY { }
	}
}

VARIABLE P1136
{
	LABEL "P1136 User Parameter|es|P1136 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1136
	}
}

COMMAND READ_P1136
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1136 }
	}
}

METHOD SET_PAR_NUMBER_1136
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1136;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1136 LIKE READ_P1136
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 112, P1136 }
		REPLY { }
	}
}

VARIABLE P1137
{
	LABEL "P1137 User Parameter|es|P1137 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1137
	}
}

COMMAND READ_P1137
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1137 }
	}
}

METHOD SET_PAR_NUMBER_1137
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1137;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1137 LIKE READ_P1137
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 113, P1137 }
		REPLY { }
	}
}

VARIABLE P1138
{
	LABEL "P1138 User Parameter|es|P1138 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1138
	}
}

COMMAND READ_P1138
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1138 }
	}
}

METHOD SET_PAR_NUMBER_1138
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1138;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1138 LIKE READ_P1138
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 114, P1138 }
		REPLY { }
	}
}

VARIABLE P1139
{
	LABEL "P1139 User Parameter|es|P1139 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1139
	}
}

COMMAND READ_P1139
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1139 }
	}
}

METHOD SET_PAR_NUMBER_1139
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1139;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1139 LIKE READ_P1139
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 115, P1139 }
		REPLY { }
	}
}

VARIABLE P1140
{
	LABEL "P1140 User Parameter|es|P1140 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1140
	}
}

COMMAND READ_P1140
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1140 }
	}
}

METHOD SET_PAR_NUMBER_1140
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1140;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1140 LIKE READ_P1140
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 116, P1140 }
		REPLY { }
	}
}

VARIABLE P1141
{
	LABEL "P1141 User Parameter|es|P1141 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1141
	}
}

COMMAND READ_P1141
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1141 }
	}
}

METHOD SET_PAR_NUMBER_1141
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1141;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1141 LIKE READ_P1141
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 117, P1141 }
		REPLY { }
	}
}

VARIABLE P1142
{
	LABEL "P1142 User Parameter|es|P1142 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1142
	}
}

COMMAND READ_P1142
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1142 }
	}
}

METHOD SET_PAR_NUMBER_1142
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1142;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1142 LIKE READ_P1142
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 118, P1142 }
		REPLY { }
	}
}

VARIABLE P1143
{
	LABEL "P1143 User Parameter|es|P1143 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1143
	}
}

COMMAND READ_P1143
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1143 }
	}
}

METHOD SET_PAR_NUMBER_1143
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1143;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1143 LIKE READ_P1143
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 119, P1143 }
		REPLY { }
	}
}

VARIABLE P1144
{
	LABEL "P1144 User Parameter|es|P1144 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1144
	}
}

COMMAND READ_P1144
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1144 }
	}
}

METHOD SET_PAR_NUMBER_1144
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1144;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1144 LIKE READ_P1144
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 120, P1144 }
		REPLY { }
	}
}

VARIABLE P1145
{
	LABEL "P1145 User Parameter|es|P1145 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1145
	}
}

COMMAND READ_P1145
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1145 }
	}
}

METHOD SET_PAR_NUMBER_1145
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1145;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1145 LIKE READ_P1145
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 121, P1145 }
		REPLY { }
	}
}

VARIABLE P1146
{
	LABEL "P1146 User Parameter|es|P1146 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1146
	}
}

COMMAND READ_P1146
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1146 }
	}
}

METHOD SET_PAR_NUMBER_1146
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1146;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1146 LIKE READ_P1146
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 122, P1146 }
		REPLY { }
	}
}

VARIABLE P1147
{
	LABEL "P1147 User Parameter|es|P1147 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1147
	}
}

COMMAND READ_P1147
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1147 }
	}
}

METHOD SET_PAR_NUMBER_1147
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1147;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1147 LIKE READ_P1147
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 123, P1147 }
		REPLY { }
	}
}

VARIABLE P1148
{
	LABEL "P1148 User Parameter|es|P1148 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1148
	}
}

COMMAND READ_P1148
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1148 }
	}
}

METHOD SET_PAR_NUMBER_1148
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1148;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1148 LIKE READ_P1148
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 124, P1148 }
		REPLY { }
	}
}

VARIABLE P1149
{
	LABEL "P1149 User Parameter|es|P1149 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1149
	}
}

COMMAND READ_P1149
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1149 }
	}
}

METHOD SET_PAR_NUMBER_1149
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1149;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1149 LIKE READ_P1149
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 125, P1149 }
		REPLY { }
	}
}

VARIABLE P1150
{
	LABEL "P1150 User Parameter|es|P1150 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1150
	}
}

COMMAND READ_P1150
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1150 }
	}
}

METHOD SET_PAR_NUMBER_1150
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1150;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1150 LIKE READ_P1150
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 126, P1150 }
		REPLY { }
	}
}

VARIABLE P1151
{
	LABEL "P1151 User Parameter|es|P1151 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1151
	}
}

COMMAND READ_P1151
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1151 }
	}
}

METHOD SET_PAR_NUMBER_1151
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1151;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1151 LIKE READ_P1151
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 127, P1151 }
		REPLY { }
	}
}

VARIABLE P1152
{
	LABEL "P1152 User Parameter|es|P1152 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1152
	}
}

COMMAND READ_P1152
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1152 }
	}
}

METHOD SET_PAR_NUMBER_1152
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1152;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1152 LIKE READ_P1152
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 128, P1152 }
		REPLY { }
	}
}

VARIABLE P1153
{
	LABEL "P1153 User Parameter|es|P1153 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1153
	}
}

COMMAND READ_P1153
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1153 }
	}
}

METHOD SET_PAR_NUMBER_1153
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1153;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1153 LIKE READ_P1153
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 129, P1153 }
		REPLY { }
	}
}

VARIABLE P1154
{
	LABEL "P1154 User Parameter|es|P1154 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1154
	}
}

COMMAND READ_P1154
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1154 }
	}
}

METHOD SET_PAR_NUMBER_1154
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1154;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1154 LIKE READ_P1154
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 130, P1154 }
		REPLY { }
	}
}

VARIABLE P1155
{
	LABEL "P1155 User Parameter|es|P1155 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1155
	}
}

COMMAND READ_P1155
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1155 }
	}
}

METHOD SET_PAR_NUMBER_1155
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1155;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1155 LIKE READ_P1155
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 131, P1155 }
		REPLY { }
	}
}

VARIABLE P1156
{
	LABEL "P1156 User Parameter|es|P1156 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1156
	}
}

COMMAND READ_P1156
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1156 }
	}
}

METHOD SET_PAR_NUMBER_1156
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1156;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1156 LIKE READ_P1156
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 132, P1156 }
		REPLY { }
	}
}

VARIABLE P1157
{
	LABEL "P1157 User Parameter|es|P1157 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1157
	}
}

COMMAND READ_P1157
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1157 }
	}
}

METHOD SET_PAR_NUMBER_1157
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1157;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1157 LIKE READ_P1157
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 133, P1157 }
		REPLY { }
	}
}

VARIABLE P1158
{
	LABEL "P1158 User Parameter|es|P1158 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1158
	}
}

COMMAND READ_P1158
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1158 }
	}
}

METHOD SET_PAR_NUMBER_1158
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1158;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1158 LIKE READ_P1158
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 134, P1158 }
		REPLY { }
	}
}

VARIABLE P1159
{
	LABEL "P1159 User Parameter|es|P1159 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1159
	}
}

COMMAND READ_P1159
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1159 }
	}
}

METHOD SET_PAR_NUMBER_1159
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1159;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1159 LIKE READ_P1159
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 135, P1159 }
		REPLY { }
	}
}

VARIABLE P1160
{
	LABEL "P1160 User Parameter|es|P1160 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1160
	}
}

COMMAND READ_P1160
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1160 }
	}
}

METHOD SET_PAR_NUMBER_1160
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1160;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1160 LIKE READ_P1160
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 136, P1160 }
		REPLY { }
	}
}

VARIABLE P1161
{
	LABEL "P1161 User Parameter|es|P1161 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1161
	}
}

COMMAND READ_P1161
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1161 }
	}
}

METHOD SET_PAR_NUMBER_1161
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1161;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1161 LIKE READ_P1161
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 137, P1161 }
		REPLY { }
	}
}

VARIABLE P1162
{
	LABEL "P1162 User Parameter|es|P1162 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1162
	}
}

COMMAND READ_P1162
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1162 }
	}
}

METHOD SET_PAR_NUMBER_1162
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1162;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1162 LIKE READ_P1162
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 138, P1162 }
		REPLY { }
	}
}

VARIABLE P1163
{
	LABEL "P1163 User Parameter|es|P1163 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1163
	}
}

COMMAND READ_P1163
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1163 }
	}
}

METHOD SET_PAR_NUMBER_1163
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1163;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1163 LIKE READ_P1163
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 139, P1163 }
		REPLY { }
	}
}

VARIABLE P1164
{
	LABEL "P1164 User Parameter|es|P1164 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1164
	}
}

COMMAND READ_P1164
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1164 }
	}
}

METHOD SET_PAR_NUMBER_1164
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1164;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1164 LIKE READ_P1164
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 140, P1164 }
		REPLY { }
	}
}

VARIABLE P1165
{
	LABEL "P1165 User Parameter|es|P1165 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1165
	}
}

COMMAND READ_P1165
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1165 }
	}
}

METHOD SET_PAR_NUMBER_1165
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1165;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1165 LIKE READ_P1165
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 141, P1165 }
		REPLY { }
	}
}

VARIABLE P1166
{
	LABEL "P1166 User Parameter|es|P1166 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1166
	}
}

COMMAND READ_P1166
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1166 }
	}
}

METHOD SET_PAR_NUMBER_1166
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1166;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1166 LIKE READ_P1166
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 142, P1166 }
		REPLY { }
	}
}

VARIABLE P1167
{
	LABEL "P1167 User Parameter|es|P1167 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1167
	}
}

COMMAND READ_P1167
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1167 }
	}
}

METHOD SET_PAR_NUMBER_1167
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1167;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1167 LIKE READ_P1167
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 143, P1167 }
		REPLY { }
	}
}

VARIABLE P1168
{
	LABEL "P1168 User Parameter|es|P1168 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1168
	}
}

COMMAND READ_P1168
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1168 }
	}
}

METHOD SET_PAR_NUMBER_1168
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1168;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1168 LIKE READ_P1168
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 144, P1168 }
		REPLY { }
	}
}

VARIABLE P1169
{
	LABEL "P1169 User Parameter|es|P1169 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1169
	}
}

COMMAND READ_P1169
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1169 }
	}
}

METHOD SET_PAR_NUMBER_1169
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1169;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1169 LIKE READ_P1169
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 145, P1169 }
		REPLY { }
	}
}

VARIABLE P1170
{
	LABEL "P1170 User Parameter|es|P1170 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1170
	}
}

COMMAND READ_P1170
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1170 }
	}
}

METHOD SET_PAR_NUMBER_1170
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1170;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1170 LIKE READ_P1170
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 146, P1170 }
		REPLY { }
	}
}

VARIABLE P1171
{
	LABEL "P1171 User Parameter|es|P1171 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1171
	}
}

COMMAND READ_P1171
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1171 }
	}
}

METHOD SET_PAR_NUMBER_1171
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1171;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1171 LIKE READ_P1171
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 147, P1171 }
		REPLY { }
	}
}

VARIABLE P1172
{
	LABEL "P1172 User Parameter|es|P1172 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1172
	}
}

COMMAND READ_P1172
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1172 }
	}
}

METHOD SET_PAR_NUMBER_1172
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1172;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1172 LIKE READ_P1172
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 148, P1172 }
		REPLY { }
	}
}

VARIABLE P1173
{
	LABEL "P1173 User Parameter|es|P1173 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1173
	}
}

COMMAND READ_P1173
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1173 }
	}
}

METHOD SET_PAR_NUMBER_1173
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1173;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1173 LIKE READ_P1173
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 149, P1173 }
		REPLY { }
	}
}

VARIABLE P1174
{
	LABEL "P1174 User Parameter|es|P1174 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1174
	}
}

COMMAND READ_P1174
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1174 }
	}
}

METHOD SET_PAR_NUMBER_1174
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1174;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1174 LIKE READ_P1174
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 150, P1174 }
		REPLY { }
	}
}

VARIABLE P1175
{
	LABEL "P1175 User Parameter|es|P1175 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1175
	}
}

COMMAND READ_P1175
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1175 }
	}
}

METHOD SET_PAR_NUMBER_1175
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1175;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1175 LIKE READ_P1175
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 151, P1175 }
		REPLY { }
	}
}

VARIABLE P1176
{
	LABEL "P1176 User Parameter|es|P1176 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1176
	}
}

COMMAND READ_P1176
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1176 }
	}
}

METHOD SET_PAR_NUMBER_1176
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1176;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1176 LIKE READ_P1176
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 152, P1176 }
		REPLY { }
	}
}

VARIABLE P1177
{
	LABEL "P1177 User Parameter|es|P1177 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1177
	}
}

COMMAND READ_P1177
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1177 }
	}
}

METHOD SET_PAR_NUMBER_1177
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1177;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1177 LIKE READ_P1177
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 153, P1177 }
		REPLY { }
	}
}

VARIABLE P1178
{
	LABEL "P1178 User Parameter|es|P1178 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1178
	}
}

COMMAND READ_P1178
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1178 }
	}
}

METHOD SET_PAR_NUMBER_1178
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1178;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1178 LIKE READ_P1178
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 154, P1178 }
		REPLY { }
	}
}

VARIABLE P1179
{
	LABEL "P1179 User Parameter|es|P1179 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1179
	}
}

COMMAND READ_P1179
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1179 }
	}
}

METHOD SET_PAR_NUMBER_1179
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1179;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1179 LIKE READ_P1179
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 155, P1179 }
		REPLY { }
	}
}

VARIABLE P1180
{
	LABEL "P1180 User Parameter|es|P1180 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1180
	}
}

COMMAND READ_P1180
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1180 }
	}
}

METHOD SET_PAR_NUMBER_1180
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1180;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1180 LIKE READ_P1180
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 156, P1180 }
		REPLY { }
	}
}

VARIABLE P1181
{
	LABEL "P1181 User Parameter|es|P1181 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1181
	}
}

COMMAND READ_P1181
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1181 }
	}
}

METHOD SET_PAR_NUMBER_1181
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1181;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1181 LIKE READ_P1181
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 157, P1181 }
		REPLY { }
	}
}

VARIABLE P1182
{
	LABEL "P1182 User Parameter|es|P1182 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1182
	}
}

COMMAND READ_P1182
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1182 }
	}
}

METHOD SET_PAR_NUMBER_1182
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1182;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1182 LIKE READ_P1182
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 158, P1182 }
		REPLY { }
	}
}

VARIABLE P1183
{
	LABEL "P1183 User Parameter|es|P1183 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1183
	}
}

COMMAND READ_P1183
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1183 }
	}
}

METHOD SET_PAR_NUMBER_1183
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1183;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1183 LIKE READ_P1183
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 159, P1183 }
		REPLY { }
	}
}

VARIABLE P1184
{
	LABEL "P1184 User Parameter|es|P1184 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1184
	}
}

COMMAND READ_P1184
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1184 }
	}
}

METHOD SET_PAR_NUMBER_1184
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1184;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1184 LIKE READ_P1184
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 160, P1184 }
		REPLY { }
	}
}

VARIABLE P1185
{
	LABEL "P1185 User Parameter|es|P1185 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1185
	}
}

COMMAND READ_P1185
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1185 }
	}
}

METHOD SET_PAR_NUMBER_1185
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1185;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1185 LIKE READ_P1185
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 161, P1185 }
		REPLY { }
	}
}

VARIABLE P1186
{
	LABEL "P1186 User Parameter|es|P1186 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1186
	}
}

COMMAND READ_P1186
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1186 }
	}
}

METHOD SET_PAR_NUMBER_1186
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1186;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1186 LIKE READ_P1186
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 162, P1186 }
		REPLY { }
	}
}

VARIABLE P1187
{
	LABEL "P1187 User Parameter|es|P1187 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1187
	}
}

COMMAND READ_P1187
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1187 }
	}
}

METHOD SET_PAR_NUMBER_1187
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1187;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1187 LIKE READ_P1187
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 163, P1187 }
		REPLY { }
	}
}

VARIABLE P1188
{
	LABEL "P1188 User Parameter|es|P1188 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1188
	}
}

COMMAND READ_P1188
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1188 }
	}
}

METHOD SET_PAR_NUMBER_1188
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1188;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1188 LIKE READ_P1188
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 164, P1188 }
		REPLY { }
	}
}

VARIABLE P1189
{
	LABEL "P1189 User Parameter|es|P1189 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1189
	}
}

COMMAND READ_P1189
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1189 }
	}
}

METHOD SET_PAR_NUMBER_1189
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1189;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1189 LIKE READ_P1189
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 165, P1189 }
		REPLY { }
	}
}

VARIABLE P1190
{
	LABEL "P1190 User Parameter|es|P1190 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1190
	}
}

COMMAND READ_P1190
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1190 }
	}
}

METHOD SET_PAR_NUMBER_1190
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1190;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1190 LIKE READ_P1190
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 166, P1190 }
		REPLY { }
	}
}

VARIABLE P1191
{
	LABEL "P1191 User Parameter|es|P1191 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1191
	}
}

COMMAND READ_P1191
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1191 }
	}
}

METHOD SET_PAR_NUMBER_1191
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1191;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1191 LIKE READ_P1191
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 167, P1191 }
		REPLY { }
	}
}

VARIABLE P1192
{
	LABEL "P1192 User Parameter|es|P1192 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1192
	}
}

COMMAND READ_P1192
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1192 }
	}
}

METHOD SET_PAR_NUMBER_1192
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1192;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1192 LIKE READ_P1192
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 168, P1192 }
		REPLY { }
	}
}

VARIABLE P1193
{
	LABEL "P1193 User Parameter|es|P1193 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1193
	}
}

COMMAND READ_P1193
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1193 }
	}
}

METHOD SET_PAR_NUMBER_1193
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1193;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1193 LIKE READ_P1193
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 169, P1193 }
		REPLY { }
	}
}

VARIABLE P1194
{
	LABEL "P1194 User Parameter|es|P1194 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1194
	}
}

COMMAND READ_P1194
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1194 }
	}
}

METHOD SET_PAR_NUMBER_1194
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1194;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1194 LIKE READ_P1194
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 170, P1194 }
		REPLY { }
	}
}

VARIABLE P1195
{
	LABEL "P1195 User Parameter|es|P1195 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1195
	}
}

COMMAND READ_P1195
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1195 }
	}
}

METHOD SET_PAR_NUMBER_1195
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1195;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1195 LIKE READ_P1195
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 171, P1195 }
		REPLY { }
	}
}

VARIABLE P1196
{
	LABEL "P1196 User Parameter|es|P1196 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1196
	}
}

COMMAND READ_P1196
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1196 }
	}
}

METHOD SET_PAR_NUMBER_1196
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1196;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1196 LIKE READ_P1196
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 172, P1196 }
		REPLY { }
	}
}

VARIABLE P1197
{
	LABEL "P1197 User Parameter|es|P1197 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1197
	}
}

COMMAND READ_P1197
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1197 }
	}
}

METHOD SET_PAR_NUMBER_1197
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1197;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1197 LIKE READ_P1197
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 173, P1197 }
		REPLY { }
	}
}

VARIABLE P1198
{
	LABEL "P1198 User Parameter|es|P1198 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1198
	}
}

COMMAND READ_P1198
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1198 }
	}
}

METHOD SET_PAR_NUMBER_1198
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1198;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1198 LIKE READ_P1198
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 174, P1198 }
		REPLY { }
	}
}

VARIABLE P1199
{
	LABEL "P1199 User Parameter|es|P1199 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1199
	}
}

COMMAND READ_P1199
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1199 }
	}
}

METHOD SET_PAR_NUMBER_1199
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1199;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1199 LIKE READ_P1199
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 175, P1199 }
		REPLY { }
	}
}

VARIABLE P1200
{
	LABEL "P1200 User Parameter|es|P1200 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1200
	}
}

COMMAND READ_P1200
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1200 }
	}
}

METHOD SET_PAR_NUMBER_1200
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1200;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1200 LIKE READ_P1200
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 176, P1200 }
		REPLY { }
	}
}

VARIABLE P1201
{
	LABEL "P1201 User Parameter|es|P1201 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1201
	}
}

COMMAND READ_P1201
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1201 }
	}
}

METHOD SET_PAR_NUMBER_1201
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1201;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1201 LIKE READ_P1201
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 177, P1201 }
		REPLY { }
	}
}

VARIABLE P1202
{
	LABEL "P1202 User Parameter|es|P1202 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1202
	}
}

COMMAND READ_P1202
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1202 }
	}
}

METHOD SET_PAR_NUMBER_1202
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1202;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1202 LIKE READ_P1202
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 178, P1202 }
		REPLY { }
	}
}

VARIABLE P1203
{
	LABEL "P1203 User Parameter|es|P1203 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1203
	}
}

COMMAND READ_P1203
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1203 }
	}
}

METHOD SET_PAR_NUMBER_1203
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1203;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1203 LIKE READ_P1203
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 179, P1203 }
		REPLY { }
	}
}

VARIABLE P1204
{
	LABEL "P1204 User Parameter|es|P1204 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1204
	}
}

COMMAND READ_P1204
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1204 }
	}
}

METHOD SET_PAR_NUMBER_1204
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1204;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1204 LIKE READ_P1204
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 180, P1204 }
		REPLY { }
	}
}

VARIABLE P1205
{
	LABEL "P1205 User Parameter|es|P1205 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1205
	}
}

COMMAND READ_P1205
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1205 }
	}
}

METHOD SET_PAR_NUMBER_1205
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1205;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1205 LIKE READ_P1205
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 181, P1205 }
		REPLY { }
	}
}

VARIABLE P1206
{
	LABEL "P1206 User Parameter|es|P1206 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1206
	}
}

COMMAND READ_P1206
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1206 }
	}
}

METHOD SET_PAR_NUMBER_1206
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1206;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1206 LIKE READ_P1206
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 182, P1206 }
		REPLY { }
	}
}

VARIABLE P1207
{
	LABEL "P1207 User Parameter|es|P1207 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1207
	}
}

COMMAND READ_P1207
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1207 }
	}
}

METHOD SET_PAR_NUMBER_1207
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1207;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1207 LIKE READ_P1207
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 183, P1207 }
		REPLY { }
	}
}

VARIABLE P1208
{
	LABEL "P1208 User Parameter|es|P1208 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1208
	}
}

COMMAND READ_P1208
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1208 }
	}
}

METHOD SET_PAR_NUMBER_1208
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1208;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1208 LIKE READ_P1208
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 184, P1208 }
		REPLY { }
	}
}

VARIABLE P1209
{
	LABEL "P1209 User Parameter|es|P1209 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1209
	}
}

COMMAND READ_P1209
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1209 }
	}
}

METHOD SET_PAR_NUMBER_1209
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1209;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1209 LIKE READ_P1209
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 185, P1209 }
		REPLY { }
	}
}

VARIABLE P1210
{
	LABEL "P1210 User Parameter|es|P1210 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1210
	}
}

COMMAND READ_P1210
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1210 }
	}
}

METHOD SET_PAR_NUMBER_1210
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1210;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1210 LIKE READ_P1210
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 186, P1210 }
		REPLY { }
	}
}

VARIABLE P1211
{
	LABEL "P1211 User Parameter|es|P1211 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1211
	}
}

COMMAND READ_P1211
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1211 }
	}
}

METHOD SET_PAR_NUMBER_1211
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1211;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1211 LIKE READ_P1211
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 187, P1211 }
		REPLY { }
	}
}

VARIABLE P1212
{
	LABEL "P1212 User Parameter|es|P1212 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1212
	}
}

COMMAND READ_P1212
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1212 }
	}
}

METHOD SET_PAR_NUMBER_1212
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1212;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1212 LIKE READ_P1212
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 188, P1212 }
		REPLY { }
	}
}

VARIABLE P1213
{
	LABEL "P1213 User Parameter|es|P1213 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1213
	}
}

COMMAND READ_P1213
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1213 }
	}
}

METHOD SET_PAR_NUMBER_1213
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1213;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1213 LIKE READ_P1213
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 189, P1213 }
		REPLY { }
	}
}

VARIABLE P1214
{
	LABEL "P1214 User Parameter|es|P1214 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1214
	}
}

COMMAND READ_P1214
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1214 }
	}
}

METHOD SET_PAR_NUMBER_1214
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1214;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1214 LIKE READ_P1214
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 190, P1214 }
		REPLY { }
	}
}

VARIABLE P1215
{
	LABEL "P1215 User Parameter|es|P1215 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1215
	}
}

COMMAND READ_P1215
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1215 }
	}
}

METHOD SET_PAR_NUMBER_1215
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1215;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1215 LIKE READ_P1215
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 191, P1215 }
		REPLY { }
	}
}

VARIABLE P1216
{
	LABEL "P1216 User Parameter|es|P1216 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1216
	}
}

COMMAND READ_P1216
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1216 }
	}
}

METHOD SET_PAR_NUMBER_1216
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1216;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1216 LIKE READ_P1216
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 192, P1216 }
		REPLY { }
	}
}

VARIABLE P1217
{
	LABEL "P1217 User Parameter|es|P1217 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1217
	}
}

COMMAND READ_P1217
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1217 }
	}
}

METHOD SET_PAR_NUMBER_1217
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1217;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1217 LIKE READ_P1217
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 193, P1217 }
		REPLY { }
	}
}

VARIABLE P1218
{
	LABEL "P1218 User Parameter|es|P1218 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1218
	}
}

COMMAND READ_P1218
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1218 }
	}
}

METHOD SET_PAR_NUMBER_1218
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1218;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1218 LIKE READ_P1218
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 194, P1218 }
		REPLY { }
	}
}

VARIABLE P1219
{
	LABEL "P1219 User Parameter|es|P1219 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1219
	}
}

COMMAND READ_P1219
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1219 }
	}
}

METHOD SET_PAR_NUMBER_1219
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1219;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1219 LIKE READ_P1219
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 195, P1219 }
		REPLY { }
	}
}

VARIABLE P1220
{
	LABEL "P1220 User Parameter|es|P1220 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1220
	}
}

COMMAND READ_P1220
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1220 }
	}
}

METHOD SET_PAR_NUMBER_1220
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1220;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1220 LIKE READ_P1220
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 196, P1220 }
		REPLY { }
	}
}

VARIABLE P1221
{
	LABEL "P1221 User Parameter|es|P1221 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1221
	}
}

COMMAND READ_P1221
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1221 }
	}
}

METHOD SET_PAR_NUMBER_1221
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1221;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1221 LIKE READ_P1221
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 197, P1221 }
		REPLY { }
	}
}

VARIABLE P1222
{
	LABEL "P1222 User Parameter|es|P1222 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1222
	}
}

COMMAND READ_P1222
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1222 }
	}
}

METHOD SET_PAR_NUMBER_1222
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1222;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1222 LIKE READ_P1222
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 198, P1222 }
		REPLY { }
	}
}

VARIABLE P1223
{
	LABEL "P1223 User Parameter|es|P1223 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1223
	}
}

COMMAND READ_P1223
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1223 }
	}
}

METHOD SET_PAR_NUMBER_1223
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1223;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1223 LIKE READ_P1223
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 199, P1223 }
		REPLY { }
	}
}

VARIABLE P1224
{
	LABEL "P1224 User Parameter|es|P1224 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1224
	}
}

COMMAND READ_P1224
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1224 }
	}
}

METHOD SET_PAR_NUMBER_1224
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1224;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1224 LIKE READ_P1224
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 200, P1224 }
		REPLY { }
	}
}

VARIABLE P1225
{
	LABEL "P1225 User Parameter|es|P1225 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1225
	}
}

COMMAND READ_P1225
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1225 }
	}
}

METHOD SET_PAR_NUMBER_1225
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1225;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1225 LIKE READ_P1225
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 201, P1225 }
		REPLY { }
	}
}

VARIABLE P1226
{
	LABEL "P1226 User Parameter|es|P1226 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1226
	}
}

COMMAND READ_P1226
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1226 }
	}
}

METHOD SET_PAR_NUMBER_1226
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1226;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1226 LIKE READ_P1226
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 202, P1226 }
		REPLY { }
	}
}

VARIABLE P1227
{
	LABEL "P1227 User Parameter|es|P1227 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1227
	}
}

COMMAND READ_P1227
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1227 }
	}
}

METHOD SET_PAR_NUMBER_1227
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1227;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1227 LIKE READ_P1227
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 203, P1227 }
		REPLY { }
	}
}

VARIABLE P1228
{
	LABEL "P1228 User Parameter|es|P1228 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1228
	}
}

COMMAND READ_P1228
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1228 }
	}
}

METHOD SET_PAR_NUMBER_1228
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1228;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1228 LIKE READ_P1228
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 204, P1228 }
		REPLY { }
	}
}

VARIABLE P1229
{
	LABEL "P1229 User Parameter|es|P1229 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1229
	}
}

COMMAND READ_P1229
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1229 }
	}
}

METHOD SET_PAR_NUMBER_1229
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1229;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1229 LIKE READ_P1229
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 205, P1229 }
		REPLY { }
	}
}

VARIABLE P1230
{
	LABEL "P1230 User Parameter|es|P1230 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1230
	}
}

COMMAND READ_P1230
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1230 }
	}
}

METHOD SET_PAR_NUMBER_1230
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1230;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1230 LIKE READ_P1230
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 206, P1230 }
		REPLY { }
	}
}

VARIABLE P1231
{
	LABEL "P1231 User Parameter|es|P1231 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1231
	}
}

COMMAND READ_P1231
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1231 }
	}
}

METHOD SET_PAR_NUMBER_1231
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1231;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1231 LIKE READ_P1231
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 207, P1231 }
		REPLY { }
	}
}

VARIABLE P1232
{
	LABEL "P1232 User Parameter|es|P1232 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1232
	}
}

COMMAND READ_P1232
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1232 }
	}
}

METHOD SET_PAR_NUMBER_1232
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1232;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1232 LIKE READ_P1232
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 208, P1232 }
		REPLY { }
	}
}

VARIABLE P1233
{
	LABEL "P1233 User Parameter|es|P1233 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1233
	}
}

COMMAND READ_P1233
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1233 }
	}
}

METHOD SET_PAR_NUMBER_1233
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1233;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1233 LIKE READ_P1233
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 209, P1233 }
		REPLY { }
	}
}

VARIABLE P1234
{
	LABEL "P1234 User Parameter|es|P1234 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1234
	}
}

COMMAND READ_P1234
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1234 }
	}
}

METHOD SET_PAR_NUMBER_1234
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1234;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1234 LIKE READ_P1234
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 210, P1234 }
		REPLY { }
	}
}

VARIABLE P1235
{
	LABEL "P1235 User Parameter|es|P1235 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1235
	}
}

COMMAND READ_P1235
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1235 }
	}
}

METHOD SET_PAR_NUMBER_1235
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1235;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1235 LIKE READ_P1235
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 211, P1235 }
		REPLY { }
	}
}

VARIABLE P1236
{
	LABEL "P1236 User Parameter|es|P1236 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1236
	}
}

COMMAND READ_P1236
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1236 }
	}
}

METHOD SET_PAR_NUMBER_1236
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1236;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1236 LIKE READ_P1236
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 212, P1236 }
		REPLY { }
	}
}

VARIABLE P1237
{
	LABEL "P1237 User Parameter|es|P1237 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1237
	}
}

COMMAND READ_P1237
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1237 }
	}
}

METHOD SET_PAR_NUMBER_1237
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1237;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1237 LIKE READ_P1237
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 213, P1237 }
		REPLY { }
	}
}

VARIABLE P1238
{
	LABEL "P1238 User Parameter|es|P1238 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1238
	}
}

COMMAND READ_P1238
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1238 }
	}
}

METHOD SET_PAR_NUMBER_1238
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1238;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1238 LIKE READ_P1238
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 214, P1238 }
		REPLY { }
	}
}

VARIABLE P1239
{
	LABEL "P1239 User Parameter|es|P1239 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1239
	}
}

COMMAND READ_P1239
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1239 }
	}
}

METHOD SET_PAR_NUMBER_1239
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1239;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1239 LIKE READ_P1239
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 215, P1239 }
		REPLY { }
	}
}

VARIABLE P1240
{
	LABEL "P1240 User Parameter|es|P1240 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1240
	}
}

COMMAND READ_P1240
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1240 }
	}
}

METHOD SET_PAR_NUMBER_1240
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1240;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1240 LIKE READ_P1240
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 216, P1240 }
		REPLY { }
	}
}

VARIABLE P1241
{
	LABEL "P1241 User Parameter|es|P1241 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1241
	}
}

COMMAND READ_P1241
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1241 }
	}
}

METHOD SET_PAR_NUMBER_1241
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1241;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1241 LIKE READ_P1241
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 217, P1241 }
		REPLY { }
	}
}

VARIABLE P1242
{
	LABEL "P1242 User Parameter|es|P1242 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1242
	}
}

COMMAND READ_P1242
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1242 }
	}
}

METHOD SET_PAR_NUMBER_1242
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1242;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1242 LIKE READ_P1242
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 218, P1242 }
		REPLY { }
	}
}

VARIABLE P1243
{
	LABEL "P1243 User Parameter|es|P1243 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1243
	}
}

COMMAND READ_P1243
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1243 }
	}
}

METHOD SET_PAR_NUMBER_1243
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1243;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1243 LIKE READ_P1243
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 219, P1243 }
		REPLY { }
	}
}

VARIABLE P1244
{
	LABEL "P1244 User Parameter|es|P1244 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1244
	}
}

COMMAND READ_P1244
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1244 }
	}
}

METHOD SET_PAR_NUMBER_1244
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1244;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1244 LIKE READ_P1244
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 220, P1244 }
		REPLY { }
	}
}

VARIABLE P1245
{
	LABEL "P1245 User Parameter|es|P1245 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1245
	}
}

COMMAND READ_P1245
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1245 }
	}
}

METHOD SET_PAR_NUMBER_1245
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1245;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1245 LIKE READ_P1245
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 221, P1245 }
		REPLY { }
	}
}

VARIABLE P1246
{
	LABEL "P1246 User Parameter|es|P1246 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1246
	}
}

COMMAND READ_P1246
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1246 }
	}
}

METHOD SET_PAR_NUMBER_1246
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1246;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1246 LIKE READ_P1246
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 222, P1246 }
		REPLY { }
	}
}

VARIABLE P1247
{
	LABEL "P1247 User Parameter|es|P1247 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1247
	}
}

COMMAND READ_P1247
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1247 }
	}
}

METHOD SET_PAR_NUMBER_1247
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1247;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1247 LIKE READ_P1247
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 223, P1247 }
		REPLY { }
	}
}

VARIABLE P1248
{
	LABEL "P1248 User Parameter|es|P1248 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1248
	}
}

COMMAND READ_P1248
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1248 }
	}
}

METHOD SET_PAR_NUMBER_1248
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1248;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1248 LIKE READ_P1248
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 224, P1248 }
		REPLY { }
	}
}

VARIABLE P1249
{
	LABEL "P1249 User Parameter|es|P1249 Parmetros Del Usuario";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1249
	}
}

COMMAND READ_P1249
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1249 }
	}
}

METHOD SET_PAR_NUMBER_1249
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1249;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1249 LIKE READ_P1249
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 225, P1249 }
		REPLY { }
	}
}











